;; html-edit-check -- HTML checker

;; This library is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2, or (at your option)
;; any later version.

;; This library is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with library; see the file COPYING.  If not, write to the
;; Free Software Foundation, Inc., 59 Temple Place - Suite 330,
;; Boston, MA 02111-1307, USA.

(require 'html-edit-vars)
(require 'html-edit-chars)
(require 'html-edit-rule)

(defvar html-edit-check-charset-map
  '(("^iso-2022-jp"		. ("iso-2022-jp"))
    ("^junet"			. ("iso-2022-jp"))
    ("^japanese-iso-8bit"	. ("x-euc-jp" "euc-jp"))
    ("^euc-japan"		. ("x-euc-jp" "euc-jp"))
    ("^euc-jp"			. ("x-euc-jp" "euc-jp"))
    ("^japanese-shift-jis"	. ("shift_jis" "x-sjis"))
    ("^shift_jis"		. ("shift_jis" "x-sjis"))
    ("^sjis"			. ("shift_jis" "x-sjis"))))

(defvar html-edit-check-element-func nil
  " ( META Υå˻ȤäƤ)")

;; global variables for checker
(defvar html-edit-check-meta-content-type nil)
(defvar html-edit-check-meta-content-type-pos nil)
(defvar html-edit-check-main-buffer nil)
(defvar html-edit-check-php-asp-markers nil)
(defvar html-edit-check-meta-check nil)


(defun html-edit-check ()
  (interactive)
  (html-edit-check-region (point-min) (point-max)))

(defun html-edit-check-region (start end)
  (interactive "r")
  (when (< start end)
    (html-edit-check-progress-message "Checking HTML.")
    (setq html-edit-check-main-buffer (current-buffer))
    (setq html-edit-check-meta-content-type nil)
    (setq html-edit-check-php-asp-markers nil)

    (html-edit-check-region-transfer start end)
    (html-edit-check-progress-message "Checking HTML..")

    ;; ʹߡwork-buffer ѹʤΤǡphp, asp ΰ֥å
    ;; Ŭ
    (setq html-edit-check-php-asp-markers
	  (let ((mark-table (make-vector (1+ (buffer-size)) nil)))
	    (mapc #'(lambda (mark)
		      (aset mark-table (marker-position mark) t))
		  html-edit-check-php-asp-markers)
	    mark-table))
    (html-edit-check-progress-message "Checking HTML...")

    (html-edit-check-syntax)
    (html-edit-check-progress-message "Checking HTML....")
    (html-edit-check-element)
    (when html-edit-check-meta-content-type
      (html-edit-check-charset
       html-edit-check-meta-content-type-pos
       html-edit-check-meta-content-type
       ))
    (html-edit-check-progress-message "Checking HTML.....OK")

    (kill-buffer (current-buffer))
    (set-buffer html-edit-check-main-buffer)
    (setq html-edit-check-main-buffer nil)
    ))

(defun html-edit-check-progress-message (msg)
  (message msg)
  (sit-for 0))

(defun html-edit-error-report (pos form &rest args)
  (setq pos (html-edit-check-find-position pos))
  (set-buffer html-edit-check-main-buffer)
  (goto-char pos)
  (apply 'error form args)
  )

(defun html-edit-check-find-position (pos)
  (let (mark prop-pos)
    (if (setq mark (get-text-property pos 'html-edit-marker))
	mark
      (if (setq mark (get-text-property (1- pos) 'html-edit-marker))
	  (1+ mark)
	(setq prop-pos (1- (previous-single-property-change
			    pos 'html-edit-marker)))
	(if prop-pos
	    (+ (get-text-property prop-pos 'html-edit-marker)
	       (- pos prop-pos))
	  pos)))))

(defun html-edit-check-delete-region (start end)
  (when (< start end)
    (if (= end (point-max))
	(delete-region start end)
      (let ((mark (html-edit-check-find-position end)))
	(delete-region start end)
	(add-text-properties start (1+ start)
			     (list 'html-edit-marker mark
				   'front-sticky nil
				   'rear-nonsticky t))))))

(defun html-edit-check-region-transfer (start end)
  (let (pos pos2 delend text)
    ;; ΰ Work Buffer ˥ԡ롣
    (setq text (buffer-substring-no-properties (point-min) (point-max)))
    (set-buffer (get-buffer-create html-edit-work-buffer-name))
    (erase-buffer)
;    (insert-buffer-substring html-edit-check-main-buffer start end)
    (insert text)
    (add-text-properties (point-min) (1+ (point-min))
			 (list 'html-edit-marker start
			       'front-sticky nil
			       'rear-nonsticky t))

;    ;; "<", ">", "&" ξ򵭲
;    (goto-char (point-min))
;    (while (setq pos (re-search-forward "[<>&]" nil t))
;      (add-text-properties (1- pos) pos
;			   (list 'html-edit-marker (+ pos start -2)
;				 'front-sticky nil
;				 'rear-nonsticky t)))

    ;; DOCTYPE 롣
    ;; TODO: Check DOCTYPE
    (goto-char (point-min))
    (if (re-search-forward "<!DOCTYPE[^>]*>" nil t)
	(html-edit-check-delete-region (match-beginning 0) (match-end 0)))

    ;; PHP 
    (goto-char (point-min))
    (while (search-forward "<%" nil t)
      (setq pos (- (point) 2))
      (if (search-forward "%>" nil t)
	  (progn
	    (html-edit-check-delete-region pos (point))
	    (setq html-edit-check-php-asp-markers
		  (cons (set-marker (make-marker) pos)
			html-edit-check-php-asp-markers))
	    )
	(html-edit-error-report pos "Unbalanced PHP tag")))

    ;; ASP 
    (goto-char (point-min))
    (while (search-forward "<?" nil t)
      (setq pos (- (point) 2))
      (if (search-forward "?>" nil t)
	  (progn
	    (html-edit-check-delete-region pos (point))
	    (setq html-edit-check-php-asp-markers
		  (cons (set-marker (make-marker) pos)
			html-edit-check-php-asp-markers))
	    )
	(html-edit-error-report pos "Unbalanced ASP tag")))

    ;; Ȥ
    (goto-char (point-min))
    (while (search-forward "<!--" nil t)
      (setq pos (- (point) 4))
      (if (search-forward "-->" nil t)
	  (html-edit-check-delete-region pos (point))
	(html-edit-error-report pos "Unbalanced comment tag")))

    ;; <script>...</script> <style>...</style> ¦롣
    (goto-char (point-min))
    (while (re-search-forward "<script[> \t\r\n]" nil t)
      (setq pos (- (point) 8))
      (backward-char 1)
      (unless (search-forward ">" nil t)
	(html-edit-error-report pos "Unclosed <script> tag"))
      (setq pos2 (point))
      (unless (search-forward "</script>" nil t)
	(html-edit-error-report pos "Unbalanced <script> tag"))
      (html-edit-check-delete-region pos2 (- (point) 9)))
    (goto-char (point-min))
    (while (re-search-forward "<style[> \t\r\n]" nil t)
      (setq pos (- (point) 7))
      (backward-char 1)
      (unless (search-forward ">" nil t)
	(html-edit-error-report pos "Unclosed <style> tag"))
      (setq pos2 (point))
      (unless (search-forward "</style>" nil t)
	(html-edit-error-report pos "Unbalanced <style> tag"))
      (html-edit-check-delete-region pos2 (- (point) 8)))
    (current-buffer)))

(defun html-edit-check-syntax ()
  (let (pos pos2 entity)
    ;; [<>] νиå롣
    (goto-char (point-min))
    (while (setq pos (re-search-forward "[<>]" nil t))
      (when (= (char-before) ?>)
	(html-edit-error-report (1- pos)
				"\">\" shuld not apear here, or use &gt;"))
      (unless (looking-at "/?[a-z]")
	(html-edit-error-report (1- pos)
				"\"<\" shuld not apear here, or use &lt;"))

      (while (cond ((null (setq pos2 (re-search-forward "[<>\"]" nil t)))
		    nil)
		   ((= (char-before) ?>)
		    nil)
		   ((= (char-before) ?\")
		    (unless (re-search-forward "[<>\"]" nil t)
		      (html-edit-error-report (1- pos2)
					      "Unbalanced string"))
		    (when (= (char-before) ?<)
		      (html-edit-error-report
		       (1- (point))
		       "\"<\" shuld not apear in the tag, or use &lt;"))
		    (when (= (char-before) ?>)
		      (html-edit-error-report
		       (1- (point))
		       "\">\" shuld not apear in the tag, or use &gt;"))
		    t)
		   (t ; "<"
		    (html-edit-error-report
		     (1- pos2)
		     "\"<\" shuld not apear in the tag, or use &lt;"))))

      (unless pos2
	(html-edit-error-report (1- pos)
				"\"<\" miss match, or use &lt;")))

    ;; λȤΥå
    (when html-edit-check-char-entity
      (goto-char (point-min))
      (if (eq html-edit-check-char-entity 'name-only)
	  (while (setq pos (re-search-forward "&[a-z0-9]+;" nil t))
	    (when (not (assoc (match-string-no-properties 0)
			      html-edit-character-entities))
	      (html-edit-error-report (match-beginning 0)
				      "Invalid character entity")))
	(while (setq pos (search-forward "&" nil t))
	  (unless (cond ((looking-at "#\\([0-9]+\\|x[0-9a-f]+\\);")
			 t) ; ok
			((looking-at "[a-z0-9]+;")
			 (assoc (concat "&" (match-string-no-properties 0))
				html-edit-character-entities))
			(t nil))
	    (html-edit-error-report (1- pos)
				    "Invalid character entity")))))
    ))

;; ɤߤȤ롣
;; ϥξ硢ݥȤ̾ľ˰֤롣
;; λξ硢">" ľ˰֤롣
;; Ĥʤ nil Ǥʤ t ֤
(defun html-edit-check-read-tag ()
  (let (pos name endtag)
    (if (search-forward "<" nil t)
	(progn
	  (setq pos (1- (point)))
	  (if (looking-at "/\\([a-z0-9]+\\)")
	      (progn
		(setq name (upcase (match-string 1)))
		(goto-char (match-end 0))
		(unless (looking-at "[ \r\n\t]*>")
		  (html-edit-error-report pos "Syntax of close tag error"))
		(goto-char (match-end 0))
		(setq endtag t))
	    (skip-chars-forward "a-zA-Z0-9")
	    (setq name (upcase (buffer-substring (1+ pos) (point))))
	    (unless (looking-at "[ \r\n\t]+\\|>")
	      (html-edit-error-report pos "Syntax of start tag error"))
	    (setq endtag nil))
	  (list pos name endtag))
      nil)))

;; name, name=value, name="value"
;; ηɤߤȤꡢݥȤʤ롣
;; Ĥ tνλ nil ֤
;; value  ASP, PHP ǵҤƤ硢attr-value  t ꤵ롣
;; let (pos2 pos3 attr-name attr-value)
(defun html-edit-check-read-attr ()
  (let (pos2
	pos3
	attr-name
	attr-value)
    (skip-chars-forward " \r\n\t")
    (if (= (char-after) ?>)
	(progn
	  (forward-char)
	  nil)	; end of attribute
      (setq pos2 (point))
      (unless (looking-at "[a-z-]+")
	(html-edit-error-report pos2
				"Invalid element attribute"))
      (setq attr-name (downcase (match-string 0)))
      (goto-char (match-end 0))
      (if (looking-at "[ \r\n\t>]")
	  (progn
	    (setq pos3 pos2)
	    (setq attr-value attr-name))
	(if (/= (char-after) ?=)
	    (html-edit-error-report (point) "\"=\" is expected"))
	(forward-char)

	;; value 
	(if (/= (char-after) ?\")
	    ;; "" ǰϤޤƤʤ
	    (progn
	      (setq pos3 (point))
	      (if (aref html-edit-check-php-asp-markers (point))
		  (setq attr-value t)
		(unless (looking-at "[a-z0-9_:.-/]+")
		  (html-edit-error-report (point) "\" is expected"))
		(setq attr-value (downcase (match-string 0)))
		(goto-char (match-end 0))))
	  ;; "" ǰϤޤƤ
	  (forward-char)
	  (setq pos3 (point))
	  (unless (looking-at "\\([^\"]*\\)\"")
	    (html-edit-error-report (point) "\" is expected"))
	  (if (aref html-edit-check-php-asp-markers (point))
	      (setq attr-value t)
	    (setq attr-value (match-string 1)))
	  (goto-char (match-end 0))))
      (list pos2 pos3 attr-name	attr-value)
      )))

(defun html-edit-check-meta (attr-name attr-value)
  (setq html-edit-check-meta-check
	(cons (cons (downcase attr-name) (downcase attr-value))
	      html-edit-check-meta-check)))

(defun html-edit-check-begtag (stack elem pos)
  (let (pos2
	pos3
	attr-name
	attr-value
	attr-check
	attr
	)
    (while (setq attr (html-edit-check-read-attr))
      (setq pos2 (nth 0 attr)
	    pos3 (nth 1 attr)
	    attr-name (nth 2 attr)
	    attr-value (nth 3 attr))

      ;; °å
      (when html-edit-check-element-func
	(apply html-edit-check-element-func
	       (list attr-name attr-value)))

      ;; °å
      (setq attr-check (html-edit-get-attlist name attr-name))
      (cond ((null attr-check)
	     (html-edit-error-report pos2
				     "Unknown attribute"))
	    ((eq attr-value t)
	     t) ; skip atribute check

	    ((listp attr-check)
	     (unless (member (downcase attr-value) attr-check)
	       (html-edit-error-report pos3
				       "Invalid attribute value \"%s\""
				       attr-value)))

	    ((eq attr-check 'NUMBER)
	     (unless (string-match "^[0-9]+$" attr-value)
	       (html-edit-error-report pos3
				       "attribute value is not NUMBER: \"%s\""
				       attr-value)))

	    (t t)))

    ;; ǤǤʤС(elem endtag-require name pos) 򥹥åѤ
    (unless (eq (nth 2 elem) 'EMPTY)
      (let ((endtag-require (or (nth 1 elem)
				(member name
					html-edit-check-require-endtag))))
	(setq stack (cons (list elem endtag-require name pos) stack))))
    stack
    ))

(defun html-edit-check-mark-command (pos)
  (setq pos (html-edit-check-find-position pos))
  (save-excursion
    (set-buffer html-edit-check-main-buffer)
    (goto-char pos)
    (set-mark-command nil)))

(defun html-edit-check-endtag (stack elem pos)
  (let ((loop t)
	top)

    (while (and loop stack)
      (setq top (car stack))
      (cond ((eq elem (car top))	; 
	     (setq stack (cdr stack))
	     (setq loop nil))
	    ((null (nth 1 top))		; λξά
	     (setq stack (cdr stack)))
	    (t
	     (html-edit-check-mark-command pos)
	     (html-edit-error-report (nth 3 top)
				     "Unbalanced tag: \"%s\" (Unbalanced at position at %d, marked)"
				     (nth 2 top)
				     (html-edit-check-find-position pos)
				     ))))
    (when (and loop (null stack))
      (html-edit-error-report pos
			      "Unbalanced end tag: \"%s\"" name))
    stack
    ))

(defun html-edit-check-element ()
  (let (stack
	pos
	name
	endtag
	elem
	tag
	)
    (goto-char (point-min))
    (while (setq tag (html-edit-check-read-tag))
      (setq pos    (nth 0 tag)
	    name   (nth 1 tag)
	    endtag (nth 2 tag))
      (setq elem (html-edit-get-element name))

      (if (null elem)
	  (html-edit-error-report pos
				  "Unknown element name \"%s\"" name))

      ;; META Υå
      (setq html-edit-check-meta-check nil)
      (if (string= name "META")
	  (setq html-edit-check-element-func 'html-edit-check-meta)
	(setq html-edit-check-element-func nil))

      (if endtag
	  (setq stack (html-edit-check-endtag stack elem pos))
	(setq stack (html-edit-check-begtag stack elem pos))
	;; META Υå
	(and html-edit-check-meta-check
	     (equal (cdr (assoc "http-equiv" html-edit-check-meta-check))
		    "content-type")
	     (setq html-edit-check-meta-content-type
		   (cdr (assoc "content" html-edit-check-meta-check))
		   html-edit-check-meta-content-type-pos
		   pos
		   ))
	))

    ;; Ĥν
    (while stack
      (let (top)
	(setq top (car stack))
	(cond ((null (nth 1 top))		; λξά
	       (setq stack (cdr stack)))
	      (t
	       (html-edit-error-report (nth 3 top)
				       "End tag is not found \"%s\""
				       (nth 2 top))))))
    ))

(defun html-edit-check-parse-contnet-type (media-type)
  (if (not (string-match "^[a-z0-9.+-]+/[a-z0-9.+-]" media-type))
      nil
    (if (string-match ";[ \t]*charset=\\([a-z0-9_-]+\\)" media-type)
	(downcase (match-string 1 media-type))
      t)))
(defun html-edit-check-charset (pos contnet-type)
  (let ((charset (html-edit-check-parse-contnet-type contnet-type)))
    (unless charset
      (html-edit-error-report pos "Invalid Content-type: %s" contnet-type))
    (when (stringp charset)
      (let ((buffer-code
	     (save-excursion
	       (set-buffer html-edit-check-main-buffer)
	       (symbol-name buffer-file-coding-system)))
	    (charset-map html-edit-check-charset-map)
	    (available-charset nil)
	    )

	(while charset-map
	  (if (string-match (car (car charset-map)) buffer-code)
	      (progn
		(setq available-charset (cdr (car charset-map)))
		(setq charset-map nil))
	    (setq charset-map (cdr charset-map))))

	(when available-charset
	  (unless (member charset available-charset)
	    (html-edit-error-report pos "Charset does not match the buffer file coding system")))
	))))

(provide 'html-edit-check)
