;; html-edit-rule-h4t.el

;; This library is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2, or (at your option)
;; any later version.

;; This library is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with library; see the file COPYING.  If not, write to the
;; Free Software Foundation, Inc., 59 Temple Place - Suite 330,
;; Boston, MA 02111-1307, USA.

(require 'html-edit-rule)

;;
;; This is the HTML 4.01 Transitional DTD + Frameset
;;

(html-edit-def-entity "%ContentType" 'CDATA)

(html-edit-def-entity "%ContentTypes" 'CDATA)

(html-edit-def-entity "%Charset" 'CDATA)

(html-edit-def-entity "%Charsets" 'CDATA)

(html-edit-def-entity "%LanguageCode" 'NAME)

(html-edit-def-entity "%Character" 'CDATA)

(html-edit-def-entity "%LinkTypes" 'CDATA)

(html-edit-def-entity "%MediaDesc" 'CDATA)

(html-edit-def-entity "%URI" 'CDATA)

(html-edit-def-entity "%Datetime" 'CDATA)


(html-edit-def-entity "%Script" 'CDATA)

(html-edit-def-entity "%StyleSheet" 'CDATA)

(html-edit-def-entity "%FrameTarget" 'CDATA)


(html-edit-def-entity "%Text" 'CDATA)

(html-edit-def-entity "%Class" 'CDATA)
(html-edit-def-entity "%Name" 'CDATA)


;;
;; Parameter Entities
;;

(html-edit-def-entity "%head.misc" '("SCRIPT" "STYLE" "META" "LINK" "OBJECT"))

(html-edit-def-entity "%heading" '("H1" "H2" "H3" "H4" "H5" "H6"))

(html-edit-def-entity "%list" '("UL" "OL" "DIR" "MENU"))

(html-edit-def-entity "%preformatted" 'PRE)

(html-edit-def-entity "%Color" 'CDATA)

;;
;; There are also 16 widely known color names with their sRGB values:
;; Black  = #000000    Green  = #008000
;; Silver = #C0C0C0    Lime   = #00FF00
;; Gray   = #808080    Olive  = #808000
;; White  = #FFFFFF    Yellow = #FFFF00
;; Maroon = #800000    Navy   = #000080
;; Red    = #FF0000    Blue   = #0000FF
;; Purple = #800080    Teal   = #008080
;; Fuchsia= #FF00FF    Aqua   = #00FFFF
;;

(html-edit-def-entity "%bodycolors" 
	'(
	("bgcolor"	. "%Color")
	("text"	. "%Color")
	("link"	. "%Color")
	("vlink"	. "%Color")
	("alink"	. "%Color")
	))

;;
;; =================== Generic Attributes ===============================
;;

(html-edit-def-entity "%coreattrs" 
	'(
	("id"	. ID)
	("class"	. "%Class")
	("style"	. "%StyleSheet")
	("title"	. "%Text")
	))

(html-edit-def-entity "%i18n" 
	'(
	("lang"	. "%LanguageCode")
	("dir"	. ("ltr" "rtl"))
	))

(html-edit-def-entity "%events" 
	'(
	("onclick"	. "%Script")
	("ondblclick"	. "%Script")
	("onmousedown"	. "%Script")
	("onmouseup"	. "%Script")
	("onmouseover"	. "%Script")
	("onmousemove"	. "%Script")
	("onmouseout"	. "%Script")
	("onkeypress"	. "%Script")
	("onkeydown"	. "%Script")
	("onkeyup"	. "%Script")
	))

(html-edit-def-entity "%attrs" 
	'(
	"%coreattrs"
	"%i18n"
	"%events"
	))

(html-edit-def-entity "%align" 
	'(
	("align"	. ("left" "center" "right" "justify"))
	))

;;
;; =================== Text Markup ======================================
;;

(html-edit-def-entity "%fontstyle" '("TT" "I" "B" "U" "S" "STRIKE" "BIG" "SMALL"))

(html-edit-def-entity "%phrase" '("EM" "STRONG" "DFN" "CODE" "SAMP" "KBD" "VAR" "CITE" "ABBR" "ACRONYM"))

(html-edit-def-entity "%special" '("A" "IMG" "APPLET" "OBJECT" "FONT" "BASEFONT" "BR" "SCRIPT" "MAP" "Q" "SUB" "SUP" "SPAN" "BDO" "IFRAME"))

(html-edit-def-entity "%formctrl" '("INPUT" "SELECT" "TEXTAREA" "LABEL" "BUTTON"))

;;
;; %inline; covers inline or "text-level" elements
;;
(html-edit-def-entity "%inline" '(PCDATA "%fontstyle" "%phrase" "%special" "%formctrl"))

(html-edit-def-element '("%fontstyle" "%phrase") t t '("%inline") nil)
(html-edit-def-attlist '("%fontstyle" "%phrase")
	'(
	"%attrs"
	))

(html-edit-def-element '("SUB" "SUP") t t '("%inline") nil)
(html-edit-def-attlist '("SUB" "SUP")
	'(
	"%attrs"
	))

(html-edit-def-element "SPAN" t t '("%inline") nil)
(html-edit-def-attlist "SPAN"
	'(
	"%attrs"
	))

(html-edit-def-element "BDO" t t '("%inline") nil)
(html-edit-def-attlist "BDO"
	'(
	"%coreattrs"
	("lang"	. "%LanguageCode")
	("dir"	. ("ltr" "rtl"))
	))

(html-edit-def-element "BASEFONT" t nil 'EMPTY nil)
(html-edit-def-attlist "BASEFONT"
	'(
	("id"	. ID)
	("size"	. CDATA)
	("color"	. "%Color")
	("face"	. CDATA)
	))

(html-edit-def-element "FONT" t t '("%inline") nil)
(html-edit-def-attlist "FONT"
	'(
	"%coreattrs"
	"%i18n"
	("size"	. CDATA)
	("color"	. "%Color")
	("face"	. CDATA)
	))

(html-edit-def-element "BR" t nil 'EMPTY nil)
(html-edit-def-attlist "BR"
	'(
	"%coreattrs"
	("clear"	. ("left" "all" "right" "none"))
	))

;;
;; ================== HTML content models ===============================
;;

;;
;; HTML has two basic content models:
;; %inline;     character level elements and text strings
;; %block;      block-like elements e.g. paragraphs and lists
;;

(html-edit-def-entity "%block" '("P" "%heading" "%list" "%preformatted" "DL" "DIV" "CENTER" "NOSCRIPT" "NOFRAMES" "BLOCKQUOTE" "FORM" "ISINDEX" "HR" "TABLE" "FIELDSET" "ADDRESS"))

(html-edit-def-entity "%flow" '("%block" "%inline"))

;;
;; =================== Document Body ====================================
;;

(html-edit-def-element "BODY" nil nil '("%flow" "INS" "DEL") nil)
(html-edit-def-attlist "BODY"
	'(
	"%attrs"
	("onload"	. "%Script")
	("onunload"	. "%Script")
	("background"	. "%URI")
	"%bodycolors"
	))

(html-edit-def-element "ADDRESS" t t '("%inline" "P") nil)
(html-edit-def-attlist "ADDRESS"
	'(
	"%attrs"
	))

(html-edit-def-element "DIV" t t '("%flow") nil)
(html-edit-def-attlist "DIV"
	'(
	"%attrs"
	"%align"
	))

(html-edit-def-element "CENTER" t t '("%flow") nil)
(html-edit-def-attlist "CENTER"
	'(
	"%attrs"
	))

;;
;; ================== The Anchor Element ================================
;;

(html-edit-def-entity "%Shape" '("rect" "circle" "poly" "default"))
(html-edit-def-entity "%Coords" 'CDATA)

(html-edit-def-element "A" t t '("%inline") '("A"))
(html-edit-def-attlist "A"
	'(
	"%attrs"
	("charset"	. "%Charset")
	("type"	. "%ContentType")
	("name"	. "%Name")
	("href"	. "%URI")
	("hreflang"	. "%LanguageCode")
	("target"	. "%FrameTarget")
	("rel"	. "%LinkTypes")
	("rev"	. "%LinkTypes")
	("accesskey"	. "%Character")
	("shape"	. "%Shape")
	("coords"	. "%Coords")
	("tabindex"	. NUMBER)
	("onfocus"	. "%Script")
	("onblur"	. "%Script")
	))

;;
;; ================== Client-side image maps ============================
;;

;;
;; These can be placed in the same document or grouped in a
;; separate document although this isn't yet widely supported
;;

(html-edit-def-element "MAP" t t '("%block" "AREA") nil)
(html-edit-def-attlist "MAP"
	'(
	"%attrs"
	("name"	. "%Name")
	))

(html-edit-def-element "AREA" t nil 'EMPTY nil)
(html-edit-def-attlist "AREA"
	'(
	"%attrs"
	("shape"	. "%Shape")
	("coords"	. "%Coords")
	("href"	. "%URI")
	("target"	. "%FrameTarget")
	("nohref"	. "nohref")
	("alt"	. "%Text")
	("tabindex"	. NUMBER)
	("accesskey"	. "%Character")
	("onfocus"	. "%Script")
	("onblur"	. "%Script")
	))

;;
;; ================== The LINK Element ==================================
;;

;;
;; Relationship values can be used in principle:
;; a) for document specific toolbars/menus when used
;; with the LINK element in document head e.g.
;; start, contents, previous, next, index, end, help
;; b) to link to a separate style sheet (rel=stylesheet)
;; c) to make a link to a script (rel=script)
;; d) by stylesheets to control how collections of
;; html nodes are rendered into printed documents
;; e) to make a link to a printable version of this document
;; e.g. a postscript or pdf version (rel=alternate media=print)
;;

(html-edit-def-element "LINK" t nil 'EMPTY nil)
(html-edit-def-attlist "LINK"
	'(
	"%attrs"
	("charset"	. "%Charset")
	("href"	. "%URI")
	("hreflang"	. "%LanguageCode")
	("type"	. "%ContentType")
	("rel"	. "%LinkTypes")
	("rev"	. "%LinkTypes")
	("media"	. "%MediaDesc")
	("target"	. "%FrameTarget")
	))

;;
;; =================== Images ===========================================
;;

;;
;; Length defined in strict DTD for cellpadding/cellspacing
;;
(html-edit-def-entity "%Length" 'CDATA)
(html-edit-def-entity "%MultiLength" 'CDATA)

(html-edit-def-entity "%MultiLengths" 'CDATA)

(html-edit-def-entity "%Pixels" 'CDATA)

(html-edit-def-entity "%IAlign" '("top" "middle" "bottom" "left" "right"))

;;
;; To avoid problems with text-only UAs as well as
;; to make image content understandable and navigable
;; to users of non-visual UAs, you need to provide
;; a description with ALT, and avoid server-side image maps
;;
(html-edit-def-element "IMG" t nil 'EMPTY nil)
(html-edit-def-attlist "IMG"
	'(
	"%attrs"
	("src"	. "%URI")
	("alt"	. "%Text")
	("longdesc"	. "%URI")
	("name"	. "%Name")
	("height"	. "%Length")
	("width"	. "%Length")
	("usemap"	. "%URI")
	("ismap"	. "ismap")
	("align"	. "%IAlign")
	("border"	. "%Pixels")
	("hspace"	. "%Pixels")
	("vspace"	. "%Pixels")
	))

;;
;; USEMAP points to a MAP element which may be in this document
;; or an external document, although the latter is not widely supported
;;

;;
;; ==================== OBJECT ======================================
;;
;;
;; OBJECT is used to embed objects as part of HTML pages
;; PARAM elements should precede other content. SGML mixed content
;; model technicality precludes specifying this formally ...
;;

(html-edit-def-element "OBJECT" t t '("PARAM" "%flow") nil)
(html-edit-def-attlist "OBJECT"
	'(
	"%attrs"
	("declare"	. "declare")
	("classid"	. "%URI")
	("codebase"	. "%URI")
	("data"	. "%URI")
	("type"	. "%ContentType")
	("codetype"	. "%ContentType")
	("archive"	. CDATA)
	("standby"	. "%Text")
	("height"	. "%Length")
	("width"	. "%Length")
	("usemap"	. "%URI")
	("name"	. "%Name")
	("tabindex"	. NUMBER)
	("align"	. "%IAlign")
	("border"	. "%Pixels")
	("hspace"	. "%Pixels")
	("vspace"	. "%Pixels")
	))

(html-edit-def-element "PARAM" t nil 'EMPTY nil)
(html-edit-def-attlist "PARAM"
	'(
	("id"	. ID)
	("name"	. "%Name")
	("value"	. CDATA)
	("valuetype"	. ("DATA" "REF" "OBJECT"))
	("type"	. "%ContentType")
	))

;;
;; =================== Java APPLET ==================================
;;
;;
;; One of code or object attributes must be present.
;; Place PARAM elements before other content.
;;
(html-edit-def-element "APPLET" t t '("PARAM" "%flow") nil)
(html-edit-def-attlist "APPLET"
	'(
	"%coreattrs"
	("codebase"	. "%URI")
	("archive"	. CDATA)
	("code"	. CDATA)
	("object"	. CDATA)
	("alt"	. "%Text")
	("name"	. "%Name")
	("width"	. "%Length")
	("height"	. "%Length")
	("align"	. "%IAlign")
	("hspace"	. "%Pixels")
	("vspace"	. "%Pixels")
	))

;;
;; =================== Horizontal Rule ==================================
;;

(html-edit-def-element "HR" t nil 'EMPTY nil)
(html-edit-def-attlist "HR"
	'(
	"%attrs"
	("align"	. ("left" "center" "right"))
	("noshade"	. "noshade")
	("size"	. "%Pixels")
	("width"	. "%Length")
	))

;;
;; =================== Paragraphs =======================================
;;

(html-edit-def-element "P" t nil '("%inline") nil)
(html-edit-def-attlist "P"
	'(
	"%attrs"
	"%align"
	))

;;
;; =================== Headings =========================================
;;

;;
;; There are six levels of headings from H1 (the most important)
;; to H6 (the least important).
;;

(html-edit-def-element '("%heading") t t '("%inline") nil)
(html-edit-def-attlist '("%heading")
	'(
	"%attrs"
	"%align"
	))

;;
;; =================== Preformatted Text ================================
;;

;;
;; excludes markup for images and changes in font size
;;
(html-edit-def-entity "%pre.exclusion" '("IMG" "OBJECT" "APPLET" "BIG" "SMALL" "SUB" "SUP" "FONT" "BASEFONT"))

(html-edit-def-element "PRE" t t '("%inline") '("%pre.exclusion"))
(html-edit-def-attlist "PRE"
	'(
	"%attrs"
	("width"	. NUMBER)
	))

;;
;; ===================== Inline Quotes ==================================
;;

(html-edit-def-element "Q" t t '("%inline") nil)
(html-edit-def-attlist "Q"
	'(
	"%attrs"
	("cite"	. "%URI")
	))

;;
;; =================== Block-like Quotes ================================
;;

(html-edit-def-element "BLOCKQUOTE" t t '("%flow") nil)
(html-edit-def-attlist "BLOCKQUOTE"
	'(
	"%attrs"
	("cite"	. "%URI")
	))

;;
;; =================== Inserted/Deleted Text ============================
;;


;;
;; INS/DEL are handled by inclusion on BODY
;;
(html-edit-def-element '("INS" "DEL") t t '("%flow") nil)
(html-edit-def-attlist '("INS" "DEL")
	'(
	"%attrs"
	("cite"	. "%URI")
	("datetime"	. "%Datetime")
	))

;;
;; =================== Lists ============================================
;;

;;
;; definition lists - DT for term, DD for its definition
;;

(html-edit-def-element "DL" t t '("DT" "DD") nil)
(html-edit-def-attlist "DL"
	'(
	"%attrs"
	("compact"	. "compact")
	))

(html-edit-def-element "DT" t nil '("%inline") nil)
(html-edit-def-element "DD" t nil '("%flow") nil)
(html-edit-def-attlist '("DT" "DD")
	'(
	"%attrs"
	))

;;
;; Ordered lists (OL) Numbering style
;; 1   arablic numbers     1, 2, 3, ...
;; a   lower alpha         a, b, c, ...
;; A   upper alpha         A, B, C, ...
;; i   lower roman         i, ii, iii, ...
;; I   upper roman         I, II, III, ...
;; The style is applied to the sequence number which by default
;; is reset to 1 for the first list item in an ordered list.
;; This can't be expressed directly in SGML due to case folding.
;;

(html-edit-def-entity "%OLStyle" 'CDATA)

(html-edit-def-element "OL" t t '("LI") nil)
(html-edit-def-attlist "OL"
	'(
	"%attrs"
	("type"	. "%OLStyle")
	("compact"	. "compact")
	("start"	. NUMBER)
	))

;;
;; Unordered Lists (UL) bullet styles
;;
(html-edit-def-entity "%ULStyle" '("disc" "square" "circle"))

(html-edit-def-element "UL" t t '("LI") nil)
(html-edit-def-attlist "UL"
	'(
	"%attrs"
	("type"	. "%ULStyle")
	("compact"	. "compact")
	))

(html-edit-def-element '("DIR" "MENU") t t '("LI") '("%block"))
(html-edit-def-attlist "DIR"
	'(
	"%attrs"
	("compact"	. "compact")
	))
(html-edit-def-attlist "MENU"
	'(
	"%attrs"
	("compact"	. "compact")
	))

(html-edit-def-entity "%LIStyle" 'CDATA)

(html-edit-def-element "LI" t nil '("%flow") nil)
(html-edit-def-attlist "LI"
	'(
	"%attrs"
	("type"	. "%LIStyle")
	("value"	. NUMBER)
	))

;;
;; ================ Forms ===============================================
;;
(html-edit-def-element "FORM" t t '("%flow") '("FORM"))
(html-edit-def-attlist "FORM"
	'(
	"%attrs"
	("action"	. "%URI")
	("method"	. ("GET" "POST"))
	("enctype"	. "%ContentType")
	("accept"	. "%ContentTypes")
	("name"	. "%Name")
	("onsubmit"	. "%Script")
	("onreset"	. "%Script")
	("target"	. "%FrameTarget")
	("accept-charset"	. "%Charsets")
	))

;;
;; Each label must not contain more than ONE field
;;
(html-edit-def-element "LABEL" t t '("%inline") '("LABEL"))
(html-edit-def-attlist "LABEL"
	'(
	"%attrs"
	("for"	. IDREF)
	("accesskey"	. "%Character")
	("onfocus"	. "%Script")
	("onblur"	. "%Script")
	))

(html-edit-def-entity "%InputType" '("TEXT" "PASSWORD" "CHECKBOX" "RADIO" "SUBMIT" "RESET" "FILE" "HIDDEN" "IMAGE" "BUTTON"))

;;
;; attribute name required for all but submit and reset
;;
(html-edit-def-element "INPUT" t nil 'EMPTY nil)
(html-edit-def-attlist "INPUT"
	'(
	"%attrs"
	("type"	. "%InputType")
	("name"	. "%Name")
	("value"	. CDATA)
	("checked"	. "checked")
	("disabled"	. "disabled")
	("readonly"	. "readonly")
	("size"	. CDATA)
	("maxlength"	. NUMBER)
	("src"	. "%URI")
	("alt"	. CDATA)
	("usemap"	. "%URI")
	("ismap"	. "ismap")
	("tabindex"	. NUMBER)
	("accesskey"	. "%Character")
	("onfocus"	. "%Script")
	("onblur"	. "%Script")
	("onselect"	. "%Script")
	("onchange"	. "%Script")
	("accept"	. "%ContentTypes")
	("align"	. "%IAlign")
	))

(html-edit-def-element "SELECT" t t '("OPTGROUP" "OPTION") nil)
(html-edit-def-attlist "SELECT"
	'(
	"%attrs"
	("name"	. "%Name")
	("size"	. NUMBER)
	("multiple"	. "multiple")
	("disabled"	. "disabled")
	("tabindex"	. NUMBER)
	("onfocus"	. "%Script")
	("onblur"	. "%Script")
	("onchange"	. "%Script")
	))

(html-edit-def-element "OPTGROUP" t t '("OPTION") nil)
(html-edit-def-attlist "OPTGROUP"
	'(
	"%attrs"
	("disabled"	. "disabled")
	("label"	. "%Text")
	))

(html-edit-def-element "OPTION" t nil '("PCDATA") nil)
(html-edit-def-attlist "OPTION"
	'(
	"%attrs"
	("selected"	. "selected")
	("disabled"	. "disabled")
	("label"	. "%Text")
	("value"	. CDATA)
	))

(html-edit-def-element "TEXTAREA" t t '("PCDATA") nil)
(html-edit-def-attlist "TEXTAREA"
	'(
	"%attrs"
	("name"	. "%Name")
	("rows"	. NUMBER)
	("cols"	. NUMBER)
	("disabled"	. "disabled")
	("readonly"	. "readonly")
	("tabindex"	. NUMBER)
	("accesskey"	. "%Character")
	("onfocus"	. "%Script")
	("onblur"	. "%Script")
	("onselect"	. "%Script")
	("onchange"	. "%Script")
	))

;;
;; #PCDATA is to solve the mixed content problem,
;; per specification only whitespace is allowed there!
;;
(html-edit-def-element "FIELDSET" t t '("PCDATA" "LEGEND" "%flow") nil)
(html-edit-def-attlist "FIELDSET"
	'(
	"%attrs"
	))

(html-edit-def-element "LEGEND" t t '("%inline") nil)
(html-edit-def-entity "%LAlign" '("top" "bottom" "left" "right"))

(html-edit-def-attlist "LEGEND"
	'(
	"%attrs"
	("accesskey"	. "%Character")
	("align"	. "%LAlign")
	))

(html-edit-def-element "BUTTON" t t '("%flow") '("A" "%formctrl" "FORM" "ISINDEX" "FIELDSET" "IFRAME"))
(html-edit-def-attlist "BUTTON"
	'(
	"%attrs"
	("name"	. "%Name")
	("value"	. CDATA)
	("type"	. ("button" "submit" "reset"))
	("disabled"	. "disabled")
	("tabindex"	. NUMBER)
	("accesskey"	. "%Character")
	("onfocus"	. "%Script")
	("onblur"	. "%Script")
	))

;;
;; ======================= Tables =======================================
;;

;;
;; IETF HTML table standard, see [RFC1942]
;;

;;
;; The BORDER attribute sets the thickness of the frame around the
;; table. The default units are screen pixels.
;; The FRAME attribute specifies which parts of the frame around
;; the table should be rendered. The values are not the same as
;; CALS to avoid a name clash with the VALIGN attribute.
;; The value "border" is included for backwards compatibility with
;; <TABLE BORDER> which yields frame=border and border=implied
;; For <TABLE BORDER=1> you get border=1 and frame=implied. In this
;; case, it is appropriate to treat this as frame=border for backwards
;; compatibility with deployed browsers.
;;
(html-edit-def-entity "%TFrame" '("void" "above" "below" "hsides" "lhs" "rhs" "vsides" "box" "border"))

;;
;; The RULES attribute defines which rules to draw between cells:
;; If RULES is absent then assume:
;; "none" if BORDER is absent or BORDER=0 otherwise "all"
;;

(html-edit-def-entity "%TRules" '("none" "groups" "rows" "cols" "all"))

;;
;; horizontal placement of table relative to document
;;
(html-edit-def-entity "%TAlign" '("left" "center" "right"))

;;
;; horizontal alignment attributes for cell contents
;;
(html-edit-def-entity "%cellhalign" 
	'(
	("align"	. ("left" "center" "right" "justify" "char"))
	("char"	. "%Character")
	("charoff"	. "%Length")
	))

;;
;; vertical alignment attributes for cell contents
;;
(html-edit-def-entity "%cellvalign" 
	'(
	("valign"	. ("top" "middle" "bottom" "baseline"))
	))

(html-edit-def-element "TABLE" t t '("CAPTION" "COL" "COLGROUP" "THEAD" "TFOOT" "TBODY") nil)
(html-edit-def-element "CAPTION" t t '("%inline") nil)
(html-edit-def-element "THEAD" t nil '("TR") nil)
(html-edit-def-element "TFOOT" t nil '("TR") nil)
(html-edit-def-element "TBODY" nil nil '("TR") nil)
(html-edit-def-element "COLGROUP" t nil '("COL") nil)
(html-edit-def-element "COL" t nil 'EMPTY nil)
(html-edit-def-element "TR" t nil '("TH" "TD") nil)
(html-edit-def-element '("TH" "TD") t nil '("%flow") nil)

(html-edit-def-attlist "TABLE"
	'(
	"%attrs"
	("summary"	. "%Text")
	("width"	. "%Length")
	("border"	. "%Pixels")
	("frame"	. "%TFrame")
	("rules"	. "%TRules")
	("cellspacing"	. "%Length")
	("cellpadding"	. "%Length")
	("align"	. "%TAlign")
	("bgcolor"	. "%Color")
	("datapagesize"	. CDATA)
	))

(html-edit-def-entity "%CAlign" '("top" "bottom" "left" "right"))

(html-edit-def-attlist "CAPTION"
	'(
	"%attrs"
	("align"	. "%CAlign")
	))

;;
;; COLGROUP groups a set of COL elements. It allows you to group
;; several semantically related columns together.
;;
(html-edit-def-attlist "COLGROUP"
	'(
	"%attrs"
	("span"	. NUMBER)
	("width"	. "%MultiLength")
	"%cellhalign"
	"%cellvalign"
	))

;;
;; COL elements define the alignment properties for cells in
;; one or more columns.
;; The WIDTH attribute specifies the width of the columns, e.g.
;; width=64        width in screen pixels
;; width=0.5*      relative width of 0.5
;; The SPAN attribute causes the attributes of one
;; COL element to apply to more than one column.
;;
(html-edit-def-attlist "COL"
	'(
	"%attrs"
	("span"	. NUMBER)
	("width"	. "%MultiLength")
	"%cellhalign"
	"%cellvalign"
	))

;;
;; Use THEAD to duplicate headers when breaking table
;; across page boundaries, or for static headers when
;; TBODY sections are rendered in scrolling panel.
;; Use TFOOT to duplicate footers when breaking table
;; across page boundaries, or for static footers when
;; TBODY sections are rendered in scrolling panel.
;; Use multiple TBODY sections when rules are needed
;; between groups of table rows.
;;
(html-edit-def-attlist '("THEAD" "TBODY" "TFOOT")
	'(
	"%attrs"
	"%cellhalign"
	"%cellvalign"
	))

(html-edit-def-attlist "TR"
	'(
	"%attrs"
	"%cellhalign"
	"%cellvalign"
	("bgcolor"	. "%Color")
	))



;;
;; Scope is simpler than headers attribute for common tables
;;
(html-edit-def-entity "%Scope" '("row" "col" "rowgroup" "colgroup"))

;;
;; TH is for headers, TD for data, but for cells acting as both use TD
;;
(html-edit-def-attlist '("TH" "TD")
	'(
	"%attrs"
	("abbr"	. "%Text")
	("axis"	. CDATA)
	("headers"	. IDREFS)
	("scope"	. "%Scope")
	("rowspan"	. NUMBER)
	("colspan"	. NUMBER)
	"%cellhalign"
	"%cellvalign"
	("nowrap"	. "nowrap")
	("bgcolor"	. "%Color")
	("width"	. "%Length")
	("height"	. "%Length")
	))

;;
;; ================== Document Frames ===================================
;;

;;
;; The content model for HTML documents depends on whether the HEAD is
;; followed by a FRAMESET or BODY element. The widespread omission of
;; the BODY start tag makes it impractical to define the content model
;; without the use of a marked section.
;;

(html-edit-def-element "FRAMESET" t t '("FRAMESET" "FRAME" "NOFRAMES") nil)
(html-edit-def-attlist "FRAMESET"
	'(
	"%coreattrs"
	("rows"	. "%MultiLengths")
	("cols"	. "%MultiLengths")
	("onload"	. "%Script")
	("onunload"	. "%Script")
	))

;;
;; reserved frame names start with "_" otherwise starts with letter
;;
(html-edit-def-element "FRAME" t nil 'EMPTY nil)
(html-edit-def-attlist "FRAME"
	'(
	"%coreattrs"
	("longdesc"	. "%URI")
	("name"	. "%Name")
	("src"	. "%URI")
	("frameborder"	. ("1" "0"))
	("marginwidth"	. "%Pixels")
	("marginheight"	. "%Pixels")
	("noresize"	. "noresize")
	("scrolling"	. ("yes" "no" "auto"))
	))

(html-edit-def-element "IFRAME" t t '("%flow") nil)
(html-edit-def-attlist "IFRAME"
	'(
	"%coreattrs"
	("longdesc"	. "%URI")
	("name"	. "%Name")
	("src"	. "%URI")
	("frameborder"	. ("1" "0"))
	("marginwidth"	. "%Pixels")
	("marginheight"	. "%Pixels")
	("scrolling"	. ("yes" "no" "auto"))
	("align"	. "%IAlign")
	("height"	. "%Length")
	("width"	. "%Length")
	))

(html-edit-def-entity "%noframes.content" '("%flow"))

(html-edit-def-element "NOFRAMES" t t '("%noframes.content") nil)
(html-edit-def-attlist "NOFRAMES"
	'(
	"%attrs"
	))

;;
;; ================ Document Head =======================================
;;
;;
;; %head.misc; defined earlier on as "SCRIPT|STYLE|META|LINK|OBJECT"
;;
(html-edit-def-entity "%head.content" '("TITLE" "ISINDEX" "BASE"))

(html-edit-def-element "HEAD" nil nil '("%head.content" "%head.misc") nil)
(html-edit-def-attlist "HEAD"
	'(
	"%i18n"
	("profile"	. "%URI")
	))

;;
;; The TITLE element is not considered part of the flow of text.
;; It should be displayed, for example as the page header or
;; window title. Exactly one title is required per document.
;;
(html-edit-def-element "TITLE" t t '("PCDATA") '("%head.misc"))
(html-edit-def-attlist "TITLE"
	'(
	"%i18n"
	))

(html-edit-def-element "ISINDEX" t nil 'EMPTY nil)
(html-edit-def-attlist "ISINDEX"
	'(
	"%coreattrs"
	"%i18n"
	("prompt"	. "%Text")
	))

(html-edit-def-element "BASE" t nil 'EMPTY nil)
(html-edit-def-attlist "BASE"
	'(
	("href"	. "%URI")
	("target"	. "%FrameTarget")
	))

(html-edit-def-element "META" t nil 'EMPTY nil)
(html-edit-def-attlist "META"
	'(
	"%i18n"
	("http-equiv"	. NAME)
	("name"	. NAME)
	("content"	. CDATA)
	("scheme"	. CDATA)
	))

(html-edit-def-element "STYLE" t t '("%StyleSheet") nil)
(html-edit-def-attlist "STYLE"
	'(
	"%i18n"
	("type"	. "%ContentType")
	("media"	. "%MediaDesc")
	("title"	. "%Text")
	))

(html-edit-def-element "SCRIPT" t t '("%Script") nil)
(html-edit-def-attlist "SCRIPT"
	'(
	("charset"	. "%Charset")
	("type"	. "%ContentType")
	("language"	. CDATA)
	("src"	. "%URI")
	("defer"	. "defer")
	("event"	. CDATA)
	("for"	. "%URI")
	))

(html-edit-def-element "NOSCRIPT" t t '("%flow") nil)
(html-edit-def-attlist "NOSCRIPT"
	'(
	"%attrs"
	))

;;
;; ================ Document Structure ==================================
;;
(html-edit-def-entity "%html.content" '("HEAD" "FRAMESET" "BODY"))

(html-edit-def-element "HTML" nil nil '("%html.content") nil)
(html-edit-def-attlist "HTML"
	'(
	"%i18n"
	))
