;; html-edit-rule-ie.el

;; This library is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2, or (at your option)
;; any later version.

;; This library is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with library; see the file COPYING.  If not, write to the
;; Free Software Foundation, Inc., 59 Temple Place - Suite 330,
;; Boston, MA 02111-1307, USA.

(require 'html-edit-rule)
;;
;; ================== Imported Names =====================================
;;

(html-edit-def-entity "%ContentType" 'CDATA)

(html-edit-def-entity "%Character" 'CDATA)

(html-edit-def-entity "%Relation" 'CDATA)

(html-edit-def-entity "%LanguageCode" 'NAME)

(html-edit-def-entity "%HTTP-Method" '("GET" "POST"))

(html-edit-def-entity "%HTTP-Methods" 'CDATA)

(html-edit-def-entity "%URL" 'CDATA)

(html-edit-def-entity "%Script" 'CDATA)
(html-edit-def-entity "%StyleSheet" 'CDATA)
(html-edit-def-entity "%Language" '("JAVASCRIPT" "JSCRIPT" "VBSCRIPT" "VBS"))

(html-edit-def-entity "%Length" 'CDATA)
(html-edit-def-entity "%Pixels" 'NUMBER)

;;
;; ========= Common attributes ============================================
;;

(html-edit-def-entity "%attrs" 
	'(
	("id"	. ID)
	("class"	. NAMES)
	("title"	. CDATA)
	("lang"	. "%LanguageCode")
	("dir"	. ("LTR" "RTL"))
	("language"	. ("%Language"))
	("style"	. "%StyleSheet")
	))
(html-edit-def-entity "%access" 
	'(
	("accesskey"	. "%Character")
	("tabindex"	. NUMBER)
	))

(html-edit-def-entity "%selection.attrs" 
	'(
	("atomicselection"	. ("true" "false"))
	("unselectable"	. ("on" "off"))
	))

;;
;; ========= Color attribute ============================================
;;

(html-edit-def-entity "%color" 'CDATA)

;;
;; Parameter Entities
;;

(html-edit-def-entity "%heading" '("H1" "H2" "H3" "H4" "H5" "H6"))


;;
;; =================== Text Content =======================================
;;

(html-edit-def-entity "%font" '("TT" "I" "B" "U" "STRIKE" "BIG" "SMALL" "SUB" "SUP" "FONT" "S" "BLINK"))

(html-edit-def-entity "%phrase" '("EM" "STRONG" "DFN" "CODE" "SAMP" "KBD" "VAR" "CITE" "ACRONYM"))

(html-edit-def-entity "%break" '("BR" "NOBR" "WBR"))

(html-edit-def-entity "%special" '("A" "Q" "SPAN" "BDO"))

(html-edit-def-entity "%mmobjects" '("IMG" "APPLET" "SCRIPT" "MAP" "MARQUEE" "OBJECT" "EMBED"))

(html-edit-def-entity "%formctrl" '("INPUT" "SELECT" "TEXTAREA" "LABEL" "BUTTON"))

(html-edit-def-entity "%inline" '(PCDATA "COMMENT" "%font" "%phrase" "%break" "%special" "%mmobjects" "%formctrl" "RUBY"))

;;
;; =================== Flow Content =======================================
;;

(html-edit-def-entity "%list" '("UL" "OL" "DL" "DIR" "MENU"))

(html-edit-def-entity "%preformatted" '("PRE" "XMP" "LISTING"))

(html-edit-def-entity "%block" '("P" "%heading" "%list" "%preformatted" "DIV" "BLOCKQUOTE" "FORM" "ISINDEX" "NOSCRIPT" "NOFRAMES" "HR" "TABLE" "FIELDSET" "IFRAME" "CENTER"))

(html-edit-def-entity "%mixed.content" '("%inline" "%block" "ADDRESS" "BASEFONT"))

(html-edit-def-entity "%flow" '("%mixed.content"))

(html-edit-def-entity "%font.content" '("%mixed.content"))


;;
;; Text Elements
;;

(html-edit-def-element '("%font") t t '("%font.content") nil)
(html-edit-def-attlist '("TT" "I" "B" "U" "STRIKE" "BIG" "SMALL" "SUB" "SUP" "S" "BLINK")
	'(
	"%attrs"
	"%selection.attrs"
	("onblur"	. "%Script")
	("oncontextmenu"	. "%Script")
	("onfocus"	. "%Script")
	("onreadystatechange"	. "%Script")
	("onresize"	. "%Script")
	("onbeforecopy"	. "%Script")
	("onbeforecut"	. "%Script")
	("onbeforepaste"	. "%Script")
	("onclick"	. "%Script")
	("oncopy"	. "%Script")
	("oncut"	. "%Script")
	("ondblclick"	. "%Script")
	("ondrag"	. "%Script")
	("ondragend"	. "%Script")
	("ondragenter"	. "%Script")
	("ondragleave"	. "%Script")
	("ondragover"	. "%Script")
	("ondragstart"	. "%Script")
	("ondrop"	. "%Script")
	("onhelp"	. "%Script")
	("onkeydown"	. "%Script")
	("onkeypress"	. "%Script")
	("onkeyup"	. "%Script")
	("onlosecapture"	. "%Script")
	("onmousedown"	. "%Script")
	("onmousemove"	. "%Script")
	("onmouseout"	. "%Script")
	("onmouseover"	. "%Script")
	("onmouseup"	. "%Script")
	("onpaste"	. "%Script")
	("onpropertychange"	. "%Script")
	("onselectstart"	. "%Script")
	))
(html-edit-def-entity "%face" 'CDATA)
(html-edit-def-entity "%fsize" 'CDATA)
(html-edit-def-entity "%rsize" 'CDATA)
(html-edit-def-attlist "FONT"
	'(
	"%attrs"
	"%access"
	"%selection.attrs"
	("color"	. "%color")
	("face"	. "%face")
	("size"	. "%rsize")
	("onbeforecut"	. "%Script")
	("onbeforepaste"	. "%Script")
	("onblur"	. "%Script")
	("oncontextmenu"	. "%Script")
	("oncut"	. "%Script")
	("onfocus"	. "%Script")
	("onpaste"	. "%Script")
	("onreadystatechange"	. "%Script")
	("onclick"	. "%Script")
	("ondblclick"	. "%Script")
	("ondrag"	. "%Script")
	("ondragend"	. "%Script")
	("ondragenter"	. "%Script")
	("ondragleave"	. "%Script")
	("ondragover"	. "%Script")
	("ondragstart"	. "%Script")
	("ondrop"	. "%Script")
	("onhelp"	. "%Script")
	("onkeydown"	. "%Script")
	("onkeypress"	. "%Script")
	("onkeyup"	. "%Script")
	("onlosecapture"	. "%Script")
	("onmousedown"	. "%Script")
	("onmousemove"	. "%Script")
	("onmouseout"	. "%Script")
	("onmouseover"	. "%Script")
	("onmouseup"	. "%Script")
	("onpropertychange"	. "%Script")
	("onselectstart"	. "%Script")
	))


(html-edit-def-element '("%phrase") t t '("%inline") nil)
(html-edit-def-attlist "ACRONYM"
	'(
	"%attrs"
	"%access"
	"%selection.attrs"
	("onblur"	. "%Script")
	("onfocus"	. "%Script")
	("onreadystatechange"	. "%Script")
	("ondrag"	. "%Script")
	("ondragend"	. "%Script")
	("ondragenter"	. "%Script")
	("ondragleave"	. "%Script")
	("ondragover"	. "%Script")
	("ondragstart"	. "%Script")
	("ondrop"	. "%Script")
	("onkeydown"	. "%Script")
	("onkeypress"	. "%Script")
	("onkeyup"	. "%Script")
	("onselectstart"	. "%Script")
	))
(html-edit-def-attlist '("KBD" "VAR")
	'(
	"%attrs"
	"%access"
	"%selection.attrs"
	("onbeforecut"	. "%Script")
	("onbeforepaste"	. "%Script")
	("onblur"	. "%Script")
	("oncontextmenu"	. "%Script")
	("oncut"	. "%Script")
	("onfocus"	. "%Script")
	("onpaste"	. "%Script")
	("onreadystatechange"	. "%Script")
	("onresize"	. "%Script")
	("onclick"	. "%Script")
	("ondblclick"	. "%Script")
	("ondrag"	. "%Script")
	("ondragend"	. "%Script")
	("ondragenter"	. "%Script")
	("ondragleave"	. "%Script")
	("ondragover"	. "%Script")
	("ondragstart"	. "%Script")
	("ondrop"	. "%Script")
	("onhelp"	. "%Script")
	("onkeydown"	. "%Script")
	("onkeypress"	. "%Script")
	("onkeyup"	. "%Script")
	("onlosecapture"	. "%Script")
	("onmousedown"	. "%Script")
	("onmousemove"	. "%Script")
	("onmouseout"	. "%Script")
	("onmouseover"	. "%Script")
	("onmouseup"	. "%Script")
	("onpropertychange"	. "%Script")
	("onselectstart"	. "%Script")
	))
(html-edit-def-attlist '("EM" "STRONG" "DFN" "CODE" "SAMP" "CITE")
	'(
	"%attrs"
	"%access"
	"%selection.attrs"
	("onblur"	. "%Script")
	("oncontextmenu"	. "%Script")
	("onfocus"	. "%Script")
	("onreadystatechange"	. "%Script")
	("onresize"	. "%Script")
	("onbeforecopy"	. "%Script")
	("onbeforecut"	. "%Script")
	("onbeforepaste"	. "%Script")
	("onclick"	. "%Script")
	("oncopy"	. "%Script")
	("oncut"	. "%Script")
	("ondblclick"	. "%Script")
	("ondrag"	. "%Script")
	("ondragend"	. "%Script")
	("ondragenter"	. "%Script")
	("ondragleave"	. "%Script")
	("ondragover"	. "%Script")
	("ondragstart"	. "%Script")
	("ondrop"	. "%Script")
	("onhelp"	. "%Script")
	("onkeydown"	. "%Script")
	("onkeypress"	. "%Script")
	("onkeyup"	. "%Script")
	("onlosecapture"	. "%Script")
	("onmousedown"	. "%Script")
	("onmousemove"	. "%Script")
	("onmouseout"	. "%Script")
	("onmouseover"	. "%Script")
	("onmouseup"	. "%Script")
	("onpaste"	. "%Script")
	("onpropertychange"	. "%Script")
	("onselectstart"	. "%Script")
	))

(html-edit-def-element "SPAN" t t '("%inline") nil)
(html-edit-def-attlist "SPAN"
	'(
	"%attrs"
	"%access"
	"%selection.attrs"
	("dataformatas"	. ("html" "text"))
	("datafld"	. CDATA)
	("datasrc"	. CDATA)
	("onbeforeeditfocus"	. "%Script")
	("oncontextmenu"	. "%Script")
	("onreadystatechange"	. "%Script")
	("onresize"	. "%Script")
	("onbeforecopy"	. "%Script")
	("onbeforecut"	. "%Script")
	("onbeforepaste"	. "%Script")
	("onblur"	. "%Script")
	("onclick"	. "%Script")
	("oncopy"	. "%Script")
	("oncut"	. "%Script")
	("ondblclick"	. "%Script")
	("ondrag"	. "%Script")
	("ondragend"	. "%Script")
	("ondragenter"	. "%Script")
	("ondragleave"	. "%Script")
	("ondragover"	. "%Script")
	("ondragstart"	. "%Script")
	("ondrop"	. "%Script")
	("onfilterchange"	. "%Script")
	("onfocus"	. "%Script")
	("onhelp"	. "%Script")
	("onkeydown"	. "%Script")
	("onkeypress"	. "%Script")
	("onkeyup"	. "%Script")
	("onlosecapture"	. "%Script")
	("onmousedown"	. "%Script")
	("onmousemove"	. "%Script")
	("onmouseout"	. "%Script")
	("onmouseover"	. "%Script")
	("onmouseup"	. "%Script")
	("onpaste"	. "%Script")
	("onpropertychange"	. "%Script")
	("onselectstart"	. "%Script")
	))

(html-edit-def-element "BDO" t t '("%inline") nil)
(html-edit-def-attlist "BDO"
	'(
	"%attrs"
	"%access"
	"%selection.attrs"
	("onafterupdate"	. "%Script")
	("onbeforeupdate"	. "%Script")
	("onbeforecopy"	. "%Script")
	("onbeforecut"	. "%Script")
	("onbeforepaste"	. "%Script")
	("onblur"	. "%Script")
	("oncellchange"	. "%Script")
	("onclick"	. "%Script")
	("oncontextmenu"	. "%Script")
	("oncopy"	. "%Script")
	("oncut"	. "%Script")
	("ondblclick"	. "%Script")
	("ondrag"	. "%Script")
	("ondragend"	. "%Script")
	("ondragenter"	. "%Script")
	("ondragleave"	. "%Script")
	("ondragover"	. "%Script")
	("ondragstart"	. "%Script")
	("ondrop"	. "%Script")
	("onerrorupdate"	. "%Script")
	("onfilterchange"	. "%Script")
	("onfocus"	. "%Script")
	("onhelp"	. "%Script")
	("onkeydown"	. "%Script")
	("onkeypress"	. "%Script")
	("onkeyup"	. "%Script")
	("onlosecapture"	. "%Script")
	("onmousedown"	. "%Script")
	("onmousemove"	. "%Script")
	("onmouseout"	. "%Script")
	("onmouseover"	. "%Script")
	("onmouseup"	. "%Script")
	("onpaste"	. "%Script")
	("onpropertychange"	. "%Script")
	("onreadystatechange"	. "%Script")
	("onscroll"	. "%Script")
	("onselectstart"	. "%Script")
	))

(html-edit-def-element '("BR" "WBR") t nil 'EMPTY nil)
(html-edit-def-element "NOBR" t nil '("%inline") '("NOBR"))
(html-edit-def-attlist "BR"
	'(
	"%attrs"
	("clear"	. ("left" "all" "right" "none"))
	("onreadystatechange"	. "%Script")
	("onlosecapture"	. "%Script")
	))
(html-edit-def-attlist "WBR"
	'(
	))
(html-edit-def-attlist "NOBR"
	'(
	"%attrs"
	"%selection.attrs"
	("onbeforecopy"	. "%Script")
	("onbeforecut"	. "%Script")
	("onbeforepaste"	. "%Script")
	("onclick"	. "%Script")
	("oncontextmenu"	. "%Script")
	("oncopy"	. "%Script")
	("oncut"	. "%Script")
	("ondblclick"	. "%Script")
	("ondrag"	. "%Script")
	("ondragend"	. "%Script")
	("ondragenter"	. "%Script")
	("ondragleave"	. "%Script")
	("ondragover"	. "%Script")
	("ondragstart"	. "%Script")
	("ondrop"	. "%Script")
	("onhelp"	. "%Script")
	("onkeydown"	. "%Script")
	("onkeypress"	. "%Script")
	("onkeyup"	. "%Script")
	("onlosecapture"	. "%Script")
	("onmousemove"	. "%Script")
	("onmouseover"	. "%Script")
	("onmouseup"	. "%Script")
	("onpaste"	. "%Script")
	("onpropertychange"	. "%Script")
	("onreadystatechange"	. "%Script")
	("onselectstart"	. "%Script")
	))

(html-edit-def-element "COMMENT" t t '("CDATA") nil)
(html-edit-def-attlist "COMMENT"
	'(
	("id"	. ID)
	("lang"	. "%LanguageCode")
	("title"	. CDATA)
	("onpropertychange"	. "%Script")
	("onreadystatechange"	. "%Script")
	))

;;
;; =================== Document Body =====================================
;;

(html-edit-def-entity "%body.content" '("%mixed.content"))

(html-edit-def-entity "%body-color-attrs" 
	'(
	("bgcolor"	. "%color")
	("text"	. "%color")
	("link"	. "%color")
	("vlink"	. "%color")
	("alink"	. "%color")
	))

(html-edit-def-entity "%bgproperties" 'CDATA)

(html-edit-def-element "BODY" nil nil '("%body.content" "INS" "DEL") nil)
(html-edit-def-attlist "BODY"
	'(
	"%attrs"
	"%access"
	"%selection.attrs"
	("background"	. "%URL")
	"%body-color-attrs"
	("bgproperties"	. "%bgproperties")
	("bottommargin"	. "%Pixels")
	("leftmargin"	. "%Pixels")
	("rightmargin"	. "%Pixels")
	("topmargin"	. "%Pixels")
	("dataformatas"	. ("html" "text"))
	("datafld"	. CDATA)
	("datasrc"	. CDATA)
	("nowrap"	. ("nowrap" "true" "false"))
	("scroll"	. ("yes" "no"))
	("onafterprint"	. "%Script")
	("onbeforecut"	. "%Script")
	("onbeforepaste"	. "%Script")
	("onbeforeprint"	. "%Script")
	("oncontextmenu"	. "%Script")
	("oncut"	. "%Script")
	("onpaste"	. "%Script")
	("onreadystatechange"	. "%Script")
	("onafterupdate"	. "%Script")
	("onbeforeupdate"	. "%Script")
	("onclick"	. "%Script")
	("ondblclick"	. "%Script")
	("ondrag"	. "%Script")
	("ondragend"	. "%Script")
	("ondragenter"	. "%Script")
	("ondragleave"	. "%Script")
	("ondragover"	. "%Script")
	("ondragstart"	. "%Script")
	("ondrop"	. "%Script")
	("onfilterchange"	. "%Script")
	("onkeydown"	. "%Script")
	("onkeypress"	. "%Script")
	("onkeyup"	. "%Script")
	("onlosecapture"	. "%Script")
	("onmousedown"	. "%Script")
	("onmousemove"	. "%Script")
	("onmouseout"	. "%Script")
	("onmouseover"	. "%Script")
	("onmouseup"	. "%Script")
	("onpropertychange"	. "%Script")
	("onrowenter"	. "%Script")
	("onrowexit"	. "%Script")
	("onscroll"	. "%Script")
	("onselectstart"	. "%Script")
	("onblur"	. "%Script")
	("onfocus"	. "%Script")
	("onload"	. "%Script")
	("onunload"	. "%Script")
	))


(html-edit-def-entity "%address.content" '("%inline" "P" "CENTER"))

(html-edit-def-element "ADDRESS" t t '("%address.content") nil)
(html-edit-def-attlist "ADDRESS"
	'(
	"%attrs"
	"%access"
	"%selection.attrs"
	("onblur"	. "%Script")
	("oncontextmenu"	. "%Script")
	("onfocus"	. "%Script")
	("onreadystatechange"	. "%Script")
	("onresize"	. "%Script")
	("onbeforecopy"	. "%Script")
	("onbeforecut"	. "%Script")
	("onbeforepaste"	. "%Script")
	("onclick"	. "%Script")
	("oncopy"	. "%Script")
	("oncut"	. "%Script")
	("ondblclick"	. "%Script")
	("ondrag"	. "%Script")
	("ondragend"	. "%Script")
	("ondragenter"	. "%Script")
	("ondragleave"	. "%Script")
	("ondragover"	. "%Script")
	("ondragstart"	. "%Script")
	("ondrop"	. "%Script")
	("onhelp"	. "%Script")
	("onkeydown"	. "%Script")
	("onkeypress"	. "%Script")
	("onkeyup"	. "%Script")
	("onlosecapture"	. "%Script")
	("onmousedown"	. "%Script")
	("onmousemove"	. "%Script")
	("onmouseout"	. "%Script")
	("onmouseover"	. "%Script")
	("onmouseup"	. "%Script")
	("onpaste"	. "%Script")
	("onpropertychange"	. "%Script")
	("onselectstart"	. "%Script")
	))

(html-edit-def-element "DIV" t t '("%body.content") nil)
(html-edit-def-attlist "DIV"
	'(
	"%attrs"
	"%access"
	"%selection.attrs"
	("align"	. ("left" "center" "right" "justify"))
	("nowrap"	. ("nowrap" "true" "false"))
	("dataformatas"	. ("html" "text"))
	("datafld"	. CDATA)
	("datasrc"	. CDATA)
	("onbeforeeditfocus"	. "%Script")
	("oncontextmenu"	. "%Script")
	("onreadystatechange"	. "%Script")
	("onafterupdate"	. "%Script")
	("onbeforecopy"	. "%Script")
	("onbeforecut"	. "%Script")
	("onbeforepaste"	. "%Script")
	("onbeforeupdate"	. "%Script")
	("onblur"	. "%Script")
	("onclick"	. "%Script")
	("oncopy"	. "%Script")
	("oncut"	. "%Script")
	("ondblclick"	. "%Script")
	("ondrag"	. "%Script")
	("ondragend"	. "%Script")
	("ondragenter"	. "%Script")
	("ondragleave"	. "%Script")
	("ondragover"	. "%Script")
	("ondragstart"	. "%Script")
	("ondrop"	. "%Script")
	("onfilterchange"	. "%Script")
	("onfocus"	. "%Script")
	("onhelp"	. "%Script")
	("onkeydown"	. "%Script")
	("onkeypress"	. "%Script")
	("onkeyup"	. "%Script")
	("onlosecapture"	. "%Script")
	("onmousedown"	. "%Script")
	("onmousemove"	. "%Script")
	("onmouseout"	. "%Script")
	("onmouseover"	. "%Script")
	("onmouseup"	. "%Script")
	("onpaste"	. "%Script")
	("onpropertychange"	. "%Script")
	("onresize"	. "%Script")
	("onrowenter"	. "%Script")
	("onrowexit"	. "%Script")
	("onscroll"	. "%Script")
	("onselectstart"	. "%Script")
	))

;;
;; CENTER is a shorthand for DIV with ALIGN=CENTER
;;
(html-edit-def-element "CENTER" t t '("%mixed.content") nil)
(html-edit-def-attlist "CENTER"
	'(
	"%attrs"
	"%access"
	"%selection.attrs"
	("onblur"	. "%Script")
	("oncontextmenu"	. "%Script")
	("onfocus"	. "%Script")
	("onreadystatechange"	. "%Script")
	("onresize"	. "%Script")
	("onbeforecopy"	. "%Script")
	("onbeforecut"	. "%Script")
	("onbeforepaste"	. "%Script")
	("onclick"	. "%Script")
	("oncopy"	. "%Script")
	("oncut"	. "%Script")
	("ondblclick"	. "%Script")
	("ondrag"	. "%Script")
	("ondragend"	. "%Script")
	("ondragenter"	. "%Script")
	("ondragleave"	. "%Script")
	("ondragover"	. "%Script")
	("ondragstart"	. "%Script")
	("ondrop"	. "%Script")
	("onhelp"	. "%Script")
	("onkeydown"	. "%Script")
	("onkeypress"	. "%Script")
	("onkeyup"	. "%Script")
	("onlosecapture"	. "%Script")
	("onmousedown"	. "%Script")
	("onmousemove"	. "%Script")
	("onmouseout"	. "%Script")
	("onmouseover"	. "%Script")
	("onmouseup"	. "%Script")
	("onpaste"	. "%Script")
	("onpropertychange"	. "%Script")
	("onselectstart"	. "%Script")
	))

;;
;; ===================== Inline Quotes ==================================
;;

(html-edit-def-element "Q" t t '("%inline") nil)
(html-edit-def-attlist "Q"
	'(
	"%attrs"
	"%access"
	"%selection.attrs"
	("onblur"	. "%Script")
	("onfocus"	. "%Script")
	("onreadystatechange"	. "%Script")
	("ondrag"	. "%Script")
	("ondragend"	. "%Script")
	("ondragenter"	. "%Script")
	("ondragleave"	. "%Script")
	("ondragover"	. "%Script")
	("ondragstart"	. "%Script")
	("ondrop"	. "%Script")
	("onkeydown"	. "%Script")
	("onkeypress"	. "%Script")
	("onkeyup"	. "%Script")
	("onselectstart"	. "%Script")
	))

;;
;; ================== The Anchor Element =================================
;;

(html-edit-def-element "A" t t '("%inline") '("A"))
(html-edit-def-attlist "A"
	'(
	"%attrs"
	"%access"
	"%selection.attrs"
	("datafld"	. CDATA)
	("datasrc"	. CDATA)
	("href"	. "%URL")
	("methods"	. "%HTTP-Methods")
	("name"	. CDATA)
	("rel"	. "%Relation")
	("rev"	. "%Relation")
	("target"	. CDATA)
	("urn"	. CDATA)
	("onbeforecopy"	. "%Script")
	("onbeforecut"	. "%Script")
	("onbeforeeditfocus"	. "%Script")
	("onbeforepaste"	. "%Script")
	("onblur"	. "%Script")
	("onclick"	. "%Script")
	("oncontextmenu"	. "%Script")
	("oncopy"	. "%Script")
	("oncut"	. "%Script")
	("ondblclick"	. "%Script")
	("ondrag"	. "%Script")
	("ondragend"	. "%Script")
	("ondragenter"	. "%Script")
	("ondragleave"	. "%Script")
	("ondragover"	. "%Script")
	("ondragstart"	. "%Script")
	("ondrop"	. "%Script")
	("onerrorupdate"	. "%Script")
	("onfocus"	. "%Script")
	("onhelp"	. "%Script")
	("onkeydown"	. "%Script")
	("onkeypress"	. "%Script")
	("onkeyup"	. "%Script")
	("onlosecapture"	. "%Script")
	("onmousedown"	. "%Script")
	("onmousemove"	. "%Script")
	("onmouseout"	. "%Script")
	("onmouseover"	. "%Script")
	("onmouseup"	. "%Script")
	("onpaste"	. "%Script")
	("onpropertychange"	. "%Script")
	("onreadystatechange"	. "%Script")
	("onresize"	. "%Script")
	("onselectstart"	. "%Script")
	))

;;
;; ================== Client-side image maps ============================
;;

;;
;; These can be placed in the same document or grouped in a
;; separate document although this isn't yet widely supported
;;

(html-edit-def-entity "%SHAPE" '("rect" "rectangle" "circ" "circle" "poly" "polygon"))
(html-edit-def-entity "%COORDS" 'CDATA)

(html-edit-def-element "MAP" t t '("AREA") nil)
(html-edit-def-attlist "MAP"
	'(
	("name"	. CDATA)
	("onbeforecut"	. "%Script")
	("onbeforepaste"	. "%Script")
	("oncut"	. "%Script")
	("onpaste"	. "%Script")
	("onreadystatechange"	. "%Script")
	("onafterupdate"	. "%Script")
	("onbeforeupdate"	. "%Script")
	("onclick"	. "%Script")
	("ondblclick"	. "%Script")
	("ondrag"	. "%Script")
	("ondragend"	. "%Script")
	("ondragenter"	. "%Script")
	("ondragleave"	. "%Script")
	("ondragover"	. "%Script")
	("ondragstart"	. "%Script")
	("ondrop"	. "%Script")
	("onerrorupdate"	. "%Script")
	("onhelp"	. "%Script")
	("onkeydown"	. "%Script")
	("onkeypress"	. "%Script")
	("onkeyup"	. "%Script")
	("onlosecapture"	. "%Script")
	("onmousedown"	. "%Script")
	("onmousemove"	. "%Script")
	("onmouseout"	. "%Script")
	("onmouseover"	. "%Script")
	("onmouseup"	. "%Script")
	("onpropertychange"	. "%Script")
	("onrowenter"	. "%Script")
	("onrowexit"	. "%Script")
	("onscroll"	. "%Script")
	("onselectstart"	. "%Script")
	))

(html-edit-def-element "AREA" t nil 'EMPTY nil)
(html-edit-def-attlist "AREA"
	'(
	"%attrs"
	"%access"
	"%selection.attrs"
	("alt"	. CDATA)
	("coords"	. "%COORDS")
	("href"	. "%URL")
	("nohref"	. ("nohref" "true" "false"))
	("shape"	. "%SHAPE")
	("target"	. CDATA)
	("onbeforeeditfocus"	. "%Script")
	("oncontextmenu"	. "%Script")
	("onreadystatechange"	. "%Script")
	("onbeforecopy"	. "%Script")
	("onbeforecut"	. "%Script")
	("onbeforepaste"	. "%Script")
	("onblur"	. "%Script")
	("onclick"	. "%Script")
	("oncopy"	. "%Script")
	("oncut"	. "%Script")
	("ondblclick"	. "%Script")
	("ondrag"	. "%Script")
	("ondragend"	. "%Script")
	("ondragenter"	. "%Script")
	("ondragleave"	. "%Script")
	("ondragover"	. "%Script")
	("ondragstart"	. "%Script")
	("ondrop"	. "%Script")
	("onfocus"	. "%Script")
	("onhelp"	. "%Script")
	("onkeydown"	. "%Script")
	("onkeypress"	. "%Script")
	("onkeyup"	. "%Script")
	("onlosecapture"	. "%Script")
	("onmousedown"	. "%Script")
	("onmousemove"	. "%Script")
	("onmouseout"	. "%Script")
	("onmouseover"	. "%Script")
	("onmouseup"	. "%Script")
	("onpaste"	. "%Script")
	("onpropertychange"	. "%Script")
	("onselectstart"	. "%Script")
	))

;;
;; ================== The LINK Element ==================================
;;

(html-edit-def-entity "%Types" 'CDATA)

(html-edit-def-entity "%disabled" 
	'(
	("disabled"	. ("disabled" "true" "false"))
	))

(html-edit-def-element "LINK" t nil 'EMPTY nil)
(html-edit-def-attlist "LINK"
	'(
	("id"	. ID)
	("title"	. CDATA)
	("name"	. CDATA)
	"%disabled"
	("href"	. "%URL")
	("media"	. ("screen" "print" "all"))
	("rel"	. "%Relation")
	("rev"	. "%Relation")
	("onerror"	. "%Script")
	("onload"	. "%Script")
	("onreadystatechange"	. "%Script")
	))

;;
;; =================== Images ============================================
;;

;;
;; Suggested widths are used for negotiating image size
;; with the module responsible for painting the image.
;; align=left or right cause image to float to margin
;; and for subsequent text to wrap around image
;;

(html-edit-def-entity "%Align" '("absbottom" "absmiddle" "baseline" "bottom" "left" "middle" "right" "texttop" "top"))

(html-edit-def-entity "%Loop" 'CDATA)

(html-edit-def-element "IMG" t nil 'EMPTY nil)
(html-edit-def-attlist "IMG"
	'(
	"%attrs"
	"%access"
	"%selection.attrs"
	("datafld"	. CDATA)
	("datasrc"	. CDATA)
	("align"	. "%Align")
	("alt"	. CDATA)
	("border"	. "%Pixels")
	("dynsrc"	. "%URL")
	("lowsrc"	. "%URL")
	("src"	. "%URL")
	("height"	. "%Length")
	("width"	. "%Length")
	("hspace"	. "%Pixels")
	("vspace"	. "%Pixels")
	("loop"	. "%Loop")
	("ismap"	. ("ismap" "true" "false"))
	("usemap"	. "%URL")
	("name"	. CDATA)
	("oncontextmenu"	. "%Script")
	("onabort"	. "%Script")
	("onafterupdate"	. "%Script")
	("onbeforecopy"	. "%Script")
	("onbeforecut"	. "%Script")
	("onbeforepaste"	. "%Script")
	("onbeforeunload"	. "%Script")
	("onbeforeupdate"	. "%Script")
	("onblur"	. "%Script")
	("onclick"	. "%Script")
	("oncopy"	. "%Script")
	("oncut"	. "%Script")
	("ondblclick"	. "%Script")
	("ondrag"	. "%Script")
	("ondragend"	. "%Script")
	("ondragenter"	. "%Script")
	("ondragleave"	. "%Script")
	("ondragover"	. "%Script")
	("ondragstart"	. "%Script")
	("ondrop"	. "%Script")
	("onerror"	. "%Script")
	("onfilterchange"	. "%Script")
	("onfocus"	. "%Script")
	("onhelp"	. "%Script")
	("onload"	. "%Script")
	("onlosecapture"	. "%Script")
	("onmousedown"	. "%Script")
	("onmousemove"	. "%Script")
	("onmouseout"	. "%Script")
	("onmouseover"	. "%Script")
	("onmouseup"	. "%Script")
	("onpaste"	. "%Script")
	("onpropertychange"	. "%Script")
	("onreadystatechange"	. "%Script")
	("onresize"	. "%Script")
	("onrowenter"	. "%Script")
	("onrowexit"	. "%Script")
	("onselectstart"	. "%Script")
	("onunload"	. "%Script")
	))

;;
;; USEMAP points to a MAP element which may be in this document
;; or an external document, although the latter is not widely supported
;;

;;
;; =================== Java APPLET tag ===================================
;;

(html-edit-def-element "APPLET" t t '("PARAM" "%inline") nil)
(html-edit-def-attlist "APPLET"
	'(
	"%attrs"
	"%access"
	"%selection.attrs"
	("datafld"	. CDATA)
	("datasrc"	. CDATA)
	("align"	. "%Align")
	("alt"	. CDATA)
	("code"	. "%URL")
	("codebase"	. "%URL")
	("height"	. "%Pixels")
	("hspace"	. "%Pixels")
	("name"	. CDATA)
	("src"	. "%URL")
	("vspace"	. "%Pixels")
	("width"	. "%Pixels")
	("onbeforecut"	. "%Script")
	("onbeforepaste"	. "%Script")
	("oncontextmenu"	. "%Script")
	("oncut"	. "%Script")
	("onpaste"	. "%Script")
	("onafterupdate"	. "%Script")
	("onbeforeeditfocus"	. "%Script")
	("onbeforeupdate"	. "%Script")
	("onblur"	. "%Script")
	("oncellchange"	. "%Script")
	("onclick"	. "%Script")
	("ondataavailable"	. "%Script")
	("ondatasetchanged"	. "%Script")
	("ondatasetcomplete"	. "%Script")
	("ondblclick"	. "%Script")
	("onerrorupdate"	. "%Script")
	("onfocus"	. "%Script")
	("onhelp"	. "%Script")
	("onkeydown"	. "%Script")
	("onkeypress"	. "%Script")
	("onkeyup"	. "%Script")
	("onload"	. "%Script")
	("onlosecapture"	. "%Script")
	("onmousedown"	. "%Script")
	("onmousemove"	. "%Script")
	("onmouseout"	. "%Script")
	("onmouseover"	. "%Script")
	("onmouseup"	. "%Script")
	("onpropertychange"	. "%Script")
	("onreadystatechange"	. "%Script")
	("onresize"	. "%Script")
	("onrowenter"	. "%Script")
	("onrowexit"	. "%Script")
	("onrowsdelete"	. "%Script")
	("onrowsinserted"	. "%Script")
	("onscroll"	. "%Script")
	))


;;
;; =================== Horizontal Rule ===================================
;;

(html-edit-def-element "HR" t nil 'EMPTY nil)
(html-edit-def-attlist "HR"
	'(
	"%attrs"
	"%access"
	"%selection.attrs"
	("align"	. ("left" "right" "center"))
	("color"	. "%color")
	("noshade"	. ("noshade" "true" "false"))
	("size"	. "%Pixels")
	("width"	. "%Length")
	("onbeforecut"	. "%Script")
	("onbeforepaste"	. "%Script")
	("oncontextmenu"	. "%Script")
	("oncut"	. "%Script")
	("onpaste"	. "%Script")
	("onreadystatechange"	. "%Script")
	("onbeforeupdate"	. "%Script")
	("onblur"	. "%Script")
	("onclick"	. "%Script")
	("oncopy"	. "%Script")
	("ondblclick"	. "%Script")
	("ondrag"	. "%Script")
	("ondragend"	. "%Script")
	("ondragenter"	. "%Script")
	("ondragleave"	. "%Script")
	("ondragover"	. "%Script")
	("ondragstart"	. "%Script")
	("ondrop"	. "%Script")
	("onfocus"	. "%Script")
	("onhelp"	. "%Script")
	("onkeydown"	. "%Script")
	("onkeypress"	. "%Script")
	("onkeyup"	. "%Script")
	("onlosecapture"	. "%Script")
	("onmousedown"	. "%Script")
	("onmousemove"	. "%Script")
	("onmouseout"	. "%Script")
	("onmouseover"	. "%Script")
	("onmouseup"	. "%Script")
	("onpropertychange"	. "%Script")
	("onresize"	. "%Script")
	("onrowenter"	. "%Script")
	("onrowexit"	. "%Script")
	("onselectstart"	. "%Script")
	))

;;
;; =================== Paragraphs=========================================
;;

(html-edit-def-entity "%P.content" '("%inline" "CENTER"))

(html-edit-def-element "P" t nil '("%P.content") nil)
(html-edit-def-attlist "P"
	'(
	"%attrs"
	"%access"
	"%selection.attrs"
	("align"	. ("left" "center" "right" "justify"))
	("onblur"	. "%Script")
	("oncontextmenu"	. "%Script")
	("onfocus"	. "%Script")
	("onreadystatechange"	. "%Script")
	("onresize"	. "%Script")
	("onbeforecopy"	. "%Script")
	("onbeforecut"	. "%Script")
	("onbeforepaste"	. "%Script")
	("onclick"	. "%Script")
	("oncopy"	. "%Script")
	("oncut"	. "%Script")
	("ondblclick"	. "%Script")
	("ondrag"	. "%Script")
	("ondragend"	. "%Script")
	("ondragenter"	. "%Script")
	("ondragleave"	. "%Script")
	("ondragover"	. "%Script")
	("ondragstart"	. "%Script")
	("ondrop"	. "%Script")
	("onhelp"	. "%Script")
	("onkeydown"	. "%Script")
	("onkeypress"	. "%Script")
	("onkeyup"	. "%Script")
	("onlosecapture"	. "%Script")
	("onmousedown"	. "%Script")
	("onmousemove"	. "%Script")
	("onmouseout"	. "%Script")
	("onmouseover"	. "%Script")
	("onmouseup"	. "%Script")
	("onpaste"	. "%Script")
	("onpropertychange"	. "%Script")
	("onselectstart"	. "%Script")
	))


;;
;; =================== Base Font =========================================
;;

(html-edit-def-element "BASEFONT" t nil 'EMPTY nil)
(html-edit-def-attlist "BASEFONT"
	'(
	("id"	. ID)
	("class"	. NAMES)
	("lang"	. "%LanguageCode")
	("size"	. "%fsize")
	("face"	. "%face")
	("color"	. "%color")
	("onreadystatechange"	. "%Script")
	))

;;
;; =================== Background Sound =================================
;;

(html-edit-def-entity "%Balance" 'CDATA)

(html-edit-def-element "BGSOUND" t nil 'EMPTY nil)
(html-edit-def-attlist "BGSOUND"
	'(
	("id"	. ID)
	("class"	. NAMES)
	("lang"	. "%LanguageCode")
	("title"	. CDATA)
	("loop"	. "%Loop")
	("src"	. "%URL")
	("volume"	. NUMBER)
	("balance"	. "%Balance")
	("onreadystatechange"	. "%Script")
	))

;;
;; =================== Marquee =========================================
;;

(html-edit-def-element "MARQUEE" t nil '("%inline") nil)
(html-edit-def-attlist "MARQUEE"
	'(
	"%attrs"
	"%access"
	"%selection.attrs"
	("behavior"	. ("scroll" "slide" "alternate"))
	("bgcolor"	. "%color")
	("dataformatas"	. ("html" "text"))
	("datafld"	. CDATA)
	("datasrc"	. CDATA)
	("direction"	. ("left" "right" "up" "down"))
	("height"	. "%Length")
	("hspace"	. "%Pixels")
	("loop"	. "%Loop")
	("scrollamount"	. NUMBER)
	("scrolldelay"	. NUMBER)
	("truespeed"	. ("truespeed" "true" "false"))
	("vspace"	. "%Pixels")
	("width"	. "%Length")
	("onbeforecut"	. "%Script")
	("onbeforeeditfocus"	. "%Script")
	("onbeforepaste"	. "%Script")
	("oncontextmenu"	. "%Script")
	("oncut"	. "%Script")
	("onpaste"	. "%Script")
	("onreadystatechange"	. "%Script")
	("onafterupdate"	. "%Script")
	("onblur"	. "%Script")
	("onbounce"	. "%Script")
	("onclick"	. "%Script")
	("ondblclick"	. "%Script")
	("ondrag"	. "%Script")
	("ondragend"	. "%Script")
	("ondragenter"	. "%Script")
	("ondragleave"	. "%Script")
	("ondragover"	. "%Script")
	("ondragstart"	. "%Script")
	("ondrop"	. "%Script")
	("onfilterchange"	. "%Script")
	("onfinish"	. "%Script")
	("onfocus"	. "%Script")
	("onhelp"	. "%Script")
	("onkeydown"	. "%Script")
	("onkeypress"	. "%Script")
	("onkeyup"	. "%Script")
	("onlosecapture"	. "%Script")
	("onmousedown"	. "%Script")
	("onmousemove"	. "%Script")
	("onmouseout"	. "%Script")
	("onmouseover"	. "%Script")
	("onmouseup"	. "%Script")
	("onpropertychange"	. "%Script")
	("onresize"	. "%Script")
	("onrowenter"	. "%Script")
	("onrowexit"	. "%Script")
	("onscroll"	. "%Script")
	("onselectstart"	. "%Script")
	("onstart"	. "%Script")
	))

;;
;; =================== Headings ==========================================
;;

;;
;; There are six levels of headers from H1 (the most important)
;; to H6 (the least important).
;;

(html-edit-def-element '("%heading") t t '("%P.content") nil)
(html-edit-def-attlist '("%heading")
	'(
	"%attrs"
	"%access"
	"%selection.attrs"
	("align"	. ("left" "center" "right" "justify"))
	("onbeforecopy"	. "%Script")
	("onbeforecut"	. "%Script")
	("onbeforepaste"	. "%Script")
	("onblur"	. "%Script")
	("onclick"	. "%Script")
	("oncontextmenu"	. "%Script")
	("oncopy"	. "%Script")
	("oncut"	. "%Script")
	("ondblclick"	. "%Script")
	("ondrag"	. "%Script")
	("ondragend"	. "%Script")
	("ondragenter"	. "%Script")
	("ondragleave"	. "%Script")
	("ondragover"	. "%Script")
	("ondragstart"	. "%Script")
	("ondrop"	. "%Script")
	("onfocus"	. "%Script")
	("onhelp"	. "%Script")
	("onkeydown"	. "%Script")
	("onkeypress"	. "%Script")
	("onkeyup"	. "%Script")
	("onlosecapture"	. "%Script")
	("onmousedown"	. "%Script")
	("onmousemove"	. "%Script")
	("onmouseout"	. "%Script")
	("onmouseover"	. "%Script")
	("onmouseup"	. "%Script")
	("onpaste"	. "%Script")
	("onpropertychange"	. "%Script")
	("onreadystatechange"	. "%Script")
	("onresize"	. "%Script")
	("onselectstart"	. "%Script")
	))

;;
;; =================== Preformatted Text =================================
;;

;;
;; excludes images and changes in font size
;;

(html-edit-def-entity "%pre.exclusion" '("IMG" "BIG" "SMALL" "SUB" "SUP" "FONT"))

(html-edit-def-element "PRE" t t '("%inline") '("%pre.exclusion"))
(html-edit-def-attlist "PRE"
	'(
	"%attrs"
	"%access"
	"%selection.attrs"
	("onblur"	. "%Script")
	("oncontextmenu"	. "%Script")
	("onfocus"	. "%Script")
	("onreadystatechange"	. "%Script")
	("onresize"	. "%Script")
	("onbeforecopy"	. "%Script")
	("onbeforecut"	. "%Script")
	("onbeforepaste"	. "%Script")
	("onclick"	. "%Script")
	("oncopy"	. "%Script")
	("oncut"	. "%Script")
	("ondblclick"	. "%Script")
	("ondrag"	. "%Script")
	("ondragend"	. "%Script")
	("ondragenter"	. "%Script")
	("ondragleave"	. "%Script")
	("ondragover"	. "%Script")
	("ondragstart"	. "%Script")
	("ondrop"	. "%Script")
	("onhelp"	. "%Script")
	("onkeydown"	. "%Script")
	("onkeypress"	. "%Script")
	("onkeyup"	. "%Script")
	("onlosecapture"	. "%Script")
	("onmousedown"	. "%Script")
	("onmousemove"	. "%Script")
	("onmouseout"	. "%Script")
	("onmouseover"	. "%Script")
	("onmouseup"	. "%Script")
	("onpaste"	. "%Script")
	("onpropertychange"	. "%Script")
	("onselectstart"	. "%Script")
	))

(html-edit-def-entity "%literal" 'CDATA)

(html-edit-def-element '("XMP" "LISTING") t t '("%literal") nil)
(html-edit-def-attlist "XMP"
	'(
	"%attrs"
	"%access"
	"%selection.attrs"
	("onbeforecut"	. "%Script")
	("onbeforepaste"	. "%Script")
	("onblur"	. "%Script")
	("oncontextmenu"	. "%Script")
	("oncut"	. "%Script")
	("onfocus"	. "%Script")
	("onpaste"	. "%Script")
	("onreadystatechange"	. "%Script")
	("onresize"	. "%Script")
	("onclick"	. "%Script")
	("ondblclick"	. "%Script")
	("ondrag"	. "%Script")
	("ondragend"	. "%Script")
	("ondragenter"	. "%Script")
	("ondragleave"	. "%Script")
	("ondragover"	. "%Script")
	("ondragstart"	. "%Script")
	("ondrop"	. "%Script")
	("onhelp"	. "%Script")
	("onkeydown"	. "%Script")
	("onkeypress"	. "%Script")
	("onkeyup"	. "%Script")
	("onlosecapture"	. "%Script")
	("onmousedown"	. "%Script")
	("onmousemove"	. "%Script")
	("onmouseout"	. "%Script")
	("onmouseover"	. "%Script")
	("onmouseup"	. "%Script")
	("onpropertychange"	. "%Script")
	("onselectstart"	. "%Script")
	))
(html-edit-def-attlist "LISTING"
	'(
	"%attrs"
	"%access"
	"%selection.attrs"
	("onblur"	. "%Script")
	("oncontextmenu"	. "%Script")
	("onfocus"	. "%Script")
	("onreadystatechange"	. "%Script")
	("onresize"	. "%Script")
	("onbeforecopy"	. "%Script")
	("onbeforecut"	. "%Script")
	("onbeforepaste"	. "%Script")
	("onclick"	. "%Script")
	("oncopy"	. "%Script")
	("oncut"	. "%Script")
	("ondblclick"	. "%Script")
	("ondrag"	. "%Script")
	("ondragend"	. "%Script")
	("ondragenter"	. "%Script")
	("ondragleave"	. "%Script")
	("ondragover"	. "%Script")
	("ondragstart"	. "%Script")
	("ondrop"	. "%Script")
	("onhelp"	. "%Script")
	("onkeydown"	. "%Script")
	("onkeypress"	. "%Script")
	("onkeyup"	. "%Script")
	("onlosecapture"	. "%Script")
	("onmousedown"	. "%Script")
	("onmousemove"	. "%Script")
	("onmouseout"	. "%Script")
	("onmouseover"	. "%Script")
	("onmouseup"	. "%Script")
	("onpaste"	. "%Script")
	("onpropertychange"	. "%Script")
	("onselectstart"	. "%Script")
	))

(html-edit-def-element "PLAINTEXT" t nil '("%literal") nil)
(html-edit-def-attlist "PLAINTEXT"
	'(
	"%attrs"
	"%access"
	"%selection.attrs"
	("onblur"	. "%Script")
	("oncontextmenu"	. "%Script")
	("onfocus"	. "%Script")
	("onreadystatechange"	. "%Script")
	("onbeforecopy"	. "%Script")
	("onbeforecut"	. "%Script")
	("onbeforepaste"	. "%Script")
	("onclick"	. "%Script")
	("oncopy"	. "%Script")
	("oncut"	. "%Script")
	("ondblclick"	. "%Script")
	("ondrag"	. "%Script")
	("ondragend"	. "%Script")
	("ondragenter"	. "%Script")
	("ondragleave"	. "%Script")
	("ondragover"	. "%Script")
	("ondragstart"	. "%Script")
	("ondrop"	. "%Script")
	("onhelp"	. "%Script")
	("onkeydown"	. "%Script")
	("onkeypress"	. "%Script")
	("onkeyup"	. "%Script")
	("onlosecapture"	. "%Script")
	("onmousedown"	. "%Script")
	("onmousemove"	. "%Script")
	("onmouseout"	. "%Script")
	("onmouseover"	. "%Script")
	("onmouseup"	. "%Script")
	("onpaste"	. "%Script")
	("onpropertychange"	. "%Script")
	("onselectstart"	. "%Script")
	))

;;
;; =================== Block-like Quotes =================================
;;

(html-edit-def-element "BLOCKQUOTE" t t '("%body.content") nil)
(html-edit-def-attlist "BLOCKQUOTE"
	'(
	"%attrs"
	"%access"
	"%selection.attrs"
	("onblur"	. "%Script")
	("oncontextmenu"	. "%Script")
	("onfocus"	. "%Script")
	("onreadystatechange"	. "%Script")
	("onresize"	. "%Script")
	("onbeforecopy"	. "%Script")
	("onbeforecut"	. "%Script")
	("onbeforepaste"	. "%Script")
	("onclick"	. "%Script")
	("oncopy"	. "%Script")
	("oncut"	. "%Script")
	("ondblclick"	. "%Script")
	("ondrag"	. "%Script")
	("ondragend"	. "%Script")
	("ondragenter"	. "%Script")
	("ondragleave"	. "%Script")
	("ondragover"	. "%Script")
	("ondragstart"	. "%Script")
	("ondrop"	. "%Script")
	("onhelp"	. "%Script")
	("onkeydown"	. "%Script")
	("onkeypress"	. "%Script")
	("onkeyup"	. "%Script")
	("onlosecapture"	. "%Script")
	("onmousedown"	. "%Script")
	("onmousemove"	. "%Script")
	("onmouseout"	. "%Script")
	("onmouseover"	. "%Script")
	("onmouseup"	. "%Script")
	("onpaste"	. "%Script")
	("onpropertychange"	. "%Script")
	("onselectstart"	. "%Script")
	))

;;
;; =================== Inserted/Deleted Text ============================
;;

;;
;; INS/DEL are handled by inclusion on BODY
;;
(html-edit-def-element '("INS" "DEL") t t '("%flow") nil)
(html-edit-def-attlist '("INS" "DEL")
	'(
	"%attrs"
	"%access"
	"%selection.attrs"
	("onblur"	. "%Script")
	("onfocus"	. "%Script")
	("onreadystatechange"	. "%Script")
	("ondrag"	. "%Script")
	("ondragend"	. "%Script")
	("ondragenter"	. "%Script")
	("ondragleave"	. "%Script")
	("ondragover"	. "%Script")
	("ondragstart"	. "%Script")
	("ondrop"	. "%Script")
	("onkeydown"	. "%Script")
	("onkeypress"	. "%Script")
	("onkeyup"	. "%Script")
	("onselectstart"	. "%Script")
	))

;;
;; =================== Lists =============================================
;;

;;
;; HTML 3.2 allows you to control the sequence number for ordered lists.
;; You can set the sequence number with the START and VALUE attributes.
;; The TYPE attribute may be used to specify the rendering of ordered
;; and unordered lists.
;;

;;
;; definition lists - DT for term, DD for its definition
;;

(html-edit-def-element "DL" t t '("DT" "DD") nil)
(html-edit-def-attlist "DL"
	'(
	"%attrs"
	"%access"
	"%selection.attrs"
	("compact"	. ("compact" "true" "false"))
	("onblur"	. "%Script")
	("oncontextmenu"	. "%Script")
	("onfocus"	. "%Script")
	("onreadystatechange"	. "%Script")
	("onresize"	. "%Script")
	("onbeforecopy"	. "%Script")
	("onbeforecut"	. "%Script")
	("onbeforepaste"	. "%Script")
	("onclick"	. "%Script")
	("oncopy"	. "%Script")
	("oncut"	. "%Script")
	("ondblclick"	. "%Script")
	("ondrag"	. "%Script")
	("ondragend"	. "%Script")
	("ondragenter"	. "%Script")
	("ondragleave"	. "%Script")
	("ondragover"	. "%Script")
	("ondragstart"	. "%Script")
	("ondrop"	. "%Script")
	("onhelp"	. "%Script")
	("onlosecapture"	. "%Script")
	("onmousedown"	. "%Script")
	("onmousemove"	. "%Script")
	("onmouseout"	. "%Script")
	("onmouseover"	. "%Script")
	("onmouseup"	. "%Script")
	("onpaste"	. "%Script")
	("onpropertychange"	. "%Script")
	("onselectstart"	. "%Script")
	))

(html-edit-def-element "DT" t nil '("%inline") nil)
(html-edit-def-attlist "DT"
	'(
	"%attrs"
	"%access"
	"%selection.attrs"
	("nowrap"	. ("nowrap" "true" "false"))
	("onblur"	. "%Script")
	("oncontextmenu"	. "%Script")
	("onfocus"	. "%Script")
	("onreadystatechange"	. "%Script")
	("onresize"	. "%Script")
	("onbeforecopy"	. "%Script")
	("onbeforecut"	. "%Script")
	("onbeforepaste"	. "%Script")
	("onclick"	. "%Script")
	("oncopy"	. "%Script")
	("oncut"	. "%Script")
	("ondblclick"	. "%Script")
	("ondrag"	. "%Script")
	("ondragend"	. "%Script")
	("ondragenter"	. "%Script")
	("ondragleave"	. "%Script")
	("ondragover"	. "%Script")
	("ondragstart"	. "%Script")
	("ondrop"	. "%Script")
	("onhelp"	. "%Script")
	("onkeydown"	. "%Script")
	("onkeypress"	. "%Script")
	("onkeyup"	. "%Script")
	("onlosecapture"	. "%Script")
	("onmousedown"	. "%Script")
	("onmousemove"	. "%Script")
	("onmouseout"	. "%Script")
	("onmouseover"	. "%Script")
	("onmouseup"	. "%Script")
	("onpaste"	. "%Script")
	("onpropertychange"	. "%Script")
	("onselectstart"	. "%Script")
	))

(html-edit-def-element "DD" t nil '("%flow") nil)
(html-edit-def-attlist "DD"
	'(
	"%attrs"
	"%access"
	"%selection.attrs"
	("nowrap"	. ("nowrap" "true" "false"))
	("onblur"	. "%Script")
	("oncontextmenu"	. "%Script")
	("onfocus"	. "%Script")
	("onreadystatechange"	. "%Script")
	("onresize"	. "%Script")
	("onbeforecopy"	. "%Script")
	("onbeforecut"	. "%Script")
	("onbeforepaste"	. "%Script")
	("onclick"	. "%Script")
	("oncopy"	. "%Script")
	("oncut"	. "%Script")
	("ondblclick"	. "%Script")
	("ondrag"	. "%Script")
	("ondragend"	. "%Script")
	("ondragenter"	. "%Script")
	("ondragleave"	. "%Script")
	("ondragover"	. "%Script")
	("ondragstart"	. "%Script")
	("ondrop"	. "%Script")
	("onhelp"	. "%Script")
	("onkeydown"	. "%Script")
	("onkeypress"	. "%Script")
	("onkeyup"	. "%Script")
	("onlosecapture"	. "%Script")
	("onmousedown"	. "%Script")
	("onmousemove"	. "%Script")
	("onmouseout"	. "%Script")
	("onmouseover"	. "%Script")
	("onmouseup"	. "%Script")
	("onpaste"	. "%Script")
	("onpropertychange"	. "%Script")
	("onselectstart"	. "%Script")
	))
;;
;; Ordered lists OL, and unordered lists UL
;;
(html-edit-def-element '("OL" "UL") t t '("LI") nil)

;;
;; Numbering style
;; 1   arabic numbers      1, 2, 3, ...
;; a   lower alpha         a, b, c, ...
;; A   upper alpha         A, B, C, ...
;; i   lower roman         i, ii, iii, ...
;; I   upper roman         I, II, III, ...
;; The style is applied to the sequence number which by default
;; is reset to 1 for the first list item in an ordered list.
;; This can't be expressed directly in SGML due to case folding.
;;

(html-edit-def-entity "%OLStyle" 'CDATA)
(html-edit-def-entity "%ULStyle" '("disc" "square" "circle"))

(html-edit-def-attlist "OL"
	'(
	"%attrs"
	"%access"
	"%selection.attrs"
	("type"	. "%OLStyle")
	("start"	. NUMBER)
	("onblur"	. "%Script")
	("oncontextmenu"	. "%Script")
	("onfocus"	. "%Script")
	("onreadystatechange"	. "%Script")
	("onresize"	. "%Script")
	("onbeforecopy"	. "%Script")
	("onbeforecut"	. "%Script")
	("onbeforepaste"	. "%Script")
	("onclick"	. "%Script")
	("oncopy"	. "%Script")
	("oncut"	. "%Script")
	("ondblclick"	. "%Script")
	("ondrag"	. "%Script")
	("ondragend"	. "%Script")
	("ondragenter"	. "%Script")
	("ondragleave"	. "%Script")
	("ondragover"	. "%Script")
	("ondragstart"	. "%Script")
	("ondrop"	. "%Script")
	("onhelp"	. "%Script")
	("onkeydown"	. "%Script")
	("onkeypress"	. "%Script")
	("onkeyup"	. "%Script")
	("onlosecapture"	. "%Script")
	("onmousedown"	. "%Script")
	("onmousemove"	. "%Script")
	("onmouseout"	. "%Script")
	("onmouseover"	. "%Script")
	("onmouseup"	. "%Script")
	("onpaste"	. "%Script")
	("onpropertychange"	. "%Script")
	("onselectstart"	. "%Script")
	))

(html-edit-def-attlist "UL"
	'(
	"%attrs"
	"%access"
	"%selection.attrs"
	("type"	. "%ULStyle")
	("onblur"	. "%Script")
	("oncontextmenu"	. "%Script")
	("onfocus"	. "%Script")
	("onreadystatechange"	. "%Script")
	("onresize"	. "%Script")
	("onbeforecopy"	. "%Script")
	("onbeforecut"	. "%Script")
	("onbeforepaste"	. "%Script")
	("onclick"	. "%Script")
	("oncopy"	. "%Script")
	("oncut"	. "%Script")
	("ondblclick"	. "%Script")
	("ondrag"	. "%Script")
	("ondragend"	. "%Script")
	("ondragenter"	. "%Script")
	("ondragleave"	. "%Script")
	("ondragover"	. "%Script")
	("ondragstart"	. "%Script")
	("ondrop"	. "%Script")
	("onhelp"	. "%Script")
	("onkeydown"	. "%Script")
	("onkeypress"	. "%Script")
	("onkeyup"	. "%Script")
	("onlosecapture"	. "%Script")
	("onmousedown"	. "%Script")
	("onmousemove"	. "%Script")
	("onmouseout"	. "%Script")
	("onmouseover"	. "%Script")
	("onmouseup"	. "%Script")
	("onpaste"	. "%Script")
	("onpropertychange"	. "%Script")
	("onselectstart"	. "%Script")
	))

(html-edit-def-element '("DIR" "MENU") t t '("LI") '("%block"))
(html-edit-def-attlist '("DIR" "MENU")
	'(
	"%attrs"
	"%access"
	"%selection.attrs"
	("type"	. ("disk" "circle" "square"))
	("onblur"	. "%Script")
	("oncontextmenu"	. "%Script")
	("onfocus"	. "%Script")
	("onreadystatechange"	. "%Script")
	("onresize"	. "%Script")
	("onbeforecopy"	. "%Script")
	("onbeforecut"	. "%Script")
	("onbeforepaste"	. "%Script")
	("onclick"	. "%Script")
	("oncopy"	. "%Script")
	("oncut"	. "%Script")
	("ondblclick"	. "%Script")
	("ondrag"	. "%Script")
	("ondragend"	. "%Script")
	("ondragenter"	. "%Script")
	("ondragleave"	. "%Script")
	("ondragover"	. "%Script")
	("ondragstart"	. "%Script")
	("ondrop"	. "%Script")
	("onhelp"	. "%Script")
	("onkeydown"	. "%Script")
	("onkeypress"	. "%Script")
	("onkeyup"	. "%Script")
	("onlosecapture"	. "%Script")
	("onmousedown"	. "%Script")
	("onmousemove"	. "%Script")
	("onmouseout"	. "%Script")
	("onmouseover"	. "%Script")
	("onmouseup"	. "%Script")
	("onpaste"	. "%Script")
	("onpropertychange"	. "%Script")
	("onselectstart"	. "%Script")
	))

;;
;; The type attribute can be used to change the bullet style
;; in unordered lists and the numbering style in ordered lists
;;

(html-edit-def-entity "%LIStyle" 'CDATA)

(html-edit-def-element "LI" t nil '("%flow") nil)
(html-edit-def-attlist "LI"
	'(
	"%attrs"
	"%access"
	"%selection.attrs"
	("type"	. "%LIStyle")
	("value"	. NUMBER)
	("onblur"	. "%Script")
	("oncontextmenu"	. "%Script")
	("onfocus"	. "%Script")
	("onreadystatechange"	. "%Script")
	("onresize"	. "%Script")
	("onbeforecopy"	. "%Script")
	("onbeforecut"	. "%Script")
	("onbeforepaste"	. "%Script")
	("onclick"	. "%Script")
	("oncopy"	. "%Script")
	("oncut"	. "%Script")
	("ondblclick"	. "%Script")
	("ondrag"	. "%Script")
	("ondragend"	. "%Script")
	("ondragenter"	. "%Script")
	("ondragleave"	. "%Script")
	("ondragover"	. "%Script")
	("ondragstart"	. "%Script")
	("ondrop"	. "%Script")
	("onhelp"	. "%Script")
	("onkeydown"	. "%Script")
	("onkeypress"	. "%Script")
	("onkeyup"	. "%Script")
	("onlosecapture"	. "%Script")
	("onmousedown"	. "%Script")
	("onmousemove"	. "%Script")
	("onmouseout"	. "%Script")
	("onmouseover"	. "%Script")
	("onmouseup"	. "%Script")
	("onpaste"	. "%Script")
	("onpropertychange"	. "%Script")
	("onselectstart"	. "%Script")
	))

;;
;; ================ Forms ===============================================
;;

(html-edit-def-element "FORM" t t '("%body.content" "%formctrl") '("FORM"))
(html-edit-def-attlist "FORM"
	'(
	"%attrs"
	"%access"
	"%selection.attrs"
	("action"	. "%URL")
	("enctype"	. CDATA)
	("method"	. ("%HTTP-Method"))
	("name"	. CDATA)
	("target"	. CDATA)
	("autocomplete"	. ("on" "off"))
	("onblur"	. "%Script")
	("oncontextmenu"	. "%Script")
	("onfocus"	. "%Script")
	("onreadystatechange"	. "%Script")
	("onresize"	. "%Script")
	("onbeforecopy"	. "%Script")
	("onbeforecut"	. "%Script")
	("onbeforepaste"	. "%Script")
	("onclick"	. "%Script")
	("oncopy"	. "%Script")
	("oncut"	. "%Script")
	("ondblclick"	. "%Script")
	("ondrag"	. "%Script")
	("ondragend"	. "%Script")
	("ondragenter"	. "%Script")
	("ondragleave"	. "%Script")
	("ondragover"	. "%Script")
	("ondragstart"	. "%Script")
	("ondrop"	. "%Script")
	("onhelp"	. "%Script")
	("onkeydown"	. "%Script")
	("onkeypress"	. "%Script")
	("onkeyup"	. "%Script")
	("onlosecapture"	. "%Script")
	("onmousedown"	. "%Script")
	("onmousemove"	. "%Script")
	("onmouseout"	. "%Script")
	("onmouseover"	. "%Script")
	("onmouseup"	. "%Script")
	("onpaste"	. "%Script")
	("onpropertychange"	. "%Script")
	("onreset"	. "%Script")
	("onselectstart"	. "%Script")
	("onsubmit"	. "%Script")
	))

(html-edit-def-entity "%InputType" '("TEXT" "PASSWORD" "CHECKBOX" "RADIO" "SUBMIT" "RESET" "FILE" "HIDDEN" "IMAGE" "BUTTON"))

(html-edit-def-element "INPUT" t nil 'EMPTY nil)
(html-edit-def-attlist "INPUT"
	'(
	("type"	. "%InputType")
	"%attrs"
	"%access"
	"%selection.attrs"
	("align"	. ("center" "left" "right"))
	("alt"	. CDATA)
	("src"	. "%URL")
	("dynsrc"	. "%URL")
	("lowsrc"	. "%URL")
	("maxlength"	. NUMBER)
	("name"	. CDATA)
	"%disabled"
	("readonly"	. ("readonly" "true" "false"))
	("size"	. CDATA)
	("value"	. CDATA)
	("checked"	. "checked")
	("dataformatas"	. ("html" "text"))
	("datafld"	. CDATA)
	("datasrc"	. CDATA)
	("autocomplete"	. ("on" "off"))
	("vcard_name"	. CDATA)
	("onbeforecut"	. "%Script")
	("onbeforeeditfocus"	. "%Script")
	("onbeforepaste"	. "%Script")
	("oncontextmenu"	. "%Script")
	("oncut"	. "%Script")
	("onpaste"	. "%Script")
	("onreadystatechange"	. "%Script")
	("onresize"	. "%Script")
	("onchange"	. "%Script")
	("onerrorupdate"	. "%Script")
	("onselect"	. "%Script")
	("onafterupdate"	. "%Script")
	("onbeforeupdate"	. "%Script")
	("onblur"	. "%Script")
	("onclick"	. "%Script")
	("ondblclick"	. "%Script")
	("ondrag"	. "%Script")
	("ondragend"	. "%Script")
	("ondragenter"	. "%Script")
	("ondragleave"	. "%Script")
	("ondragover"	. "%Script")
	("ondragstart"	. "%Script")
	("ondrop"	. "%Script")
	("onfilterchange"	. "%Script")
	("onfocus"	. "%Script")
	("onhelp"	. "%Script")
	("onkeydown"	. "%Script")
	("onkeypress"	. "%Script")
	("onkeyup"	. "%Script")
	("onlosecapture"	. "%Script")
	("onmousedown"	. "%Script")
	("onmousemove"	. "%Script")
	("onmouseout"	. "%Script")
	("onmouseover"	. "%Script")
	("onmouseup"	. "%Script")
	("onpropertychange"	. "%Script")
	("onselectstart"	. "%Script")
	))

(html-edit-def-element "SELECT" t t '("OPTION") nil)
(html-edit-def-attlist "SELECT"
	'(
	"%attrs"
	"%access"
	"%selection.attrs"
	("datafld"	. CDATA)
	("datasrc"	. CDATA)
	("align"	. "%Align")
	"%disabled"
	("multiple"	. ("multiple" "true" "false"))
	("name"	. CDATA)
	("size"	. NUMBER)
	("onreadystatechange"	. "%Script")
	("onafterupdate"	. "%Script")
	("onbeforeupdate"	. "%Script")
	("onblur"	. "%Script")
	("onchange"	. "%Script")
	("onclick"	. "%Script")
	("ondblclick"	. "%Script")
	("ondrag"	. "%Script")
	("ondragend"	. "%Script")
	("ondragenter"	. "%Script")
	("ondragleave"	. "%Script")
	("ondragover"	. "%Script")
	("ondragstart"	. "%Script")
	("ondrop"	. "%Script")
	("onerrorupdate"	. "%Script")
	("onfocus"	. "%Script")
	("onhelp"	. "%Script")
	("onkeydown"	. "%Script")
	("onkeypress"	. "%Script")
	("onkeyup"	. "%Script")
	("onlosecapture"	. "%Script")
	("onmousedown"	. "%Script")
	("onmousemove"	. "%Script")
	("onmouseout"	. "%Script")
	("onmouseover"	. "%Script")
	("onmouseup"	. "%Script")
	("onpropertychange"	. "%Script")
	("onresize"	. "%Script")
	("onrowenter"	. "%Script")
	("onrowexit"	. "%Script")
	("onscroll"	. "%Script")
	("onselectstart"	. "%Script")
	))

(html-edit-def-element "OPTION" t nil '("PCDATA") nil)
(html-edit-def-attlist "OPTION"
	'(
	"%attrs"
	("selected"	. ("selected" "true" "false"))
	("value"	. CDATA)
	("onreadystatechange"	. "%Script")
	("onclick"	. "%Script")
	("ondrag"	. "%Script")
	("ondragend"	. "%Script")
	("ondragenter"	. "%Script")
	("ondragleave"	. "%Script")
	("ondragover"	. "%Script")
	("ondragstart"	. "%Script")
	("ondrop"	. "%Script")
	("onlosecapture"	. "%Script")
	("onpropertychange"	. "%Script")
	("onselectstart"	. "%Script")
	))

(html-edit-def-element "TEXTAREA" t t '("PCDATA") nil)
(html-edit-def-attlist "TEXTAREA"
	'(
	"%attrs"
	"%access"
	"%selection.attrs"
	("rows"	. NUMBER)
	("cols"	. NUMBER)
	("datafld"	. CDATA)
	("datasrc"	. CDATA)
	("name"	. CDATA)
	"%disabled"
	("readonly"	. ("readonly" "true" "false"))
	("wrap"	. ("off" "hard" "soft"))
	("type"	. "textarea")
	("onbeforeeditfocus"	. "%Script")
	("oncontextmenu"	. "%Script")
	("oncut"	. "%Script")
	("onpaste"	. "%Script")
	("onreadystatechange"	. "%Script")
	("onafterupdate"	. "%Script")
	("onbeforecopy"	. "%Script")
	("onbeforecut"	. "%Script")
	("onbeforepaste"	. "%Script")
	("onbeforeupdate"	. "%Script")
	("onblur"	. "%Script")
	("onchange"	. "%Script")
	("onclick"	. "%Script")
	("ondblclick"	. "%Script")
	("ondrag"	. "%Script")
	("ondragend"	. "%Script")
	("ondragenter"	. "%Script")
	("ondragleave"	. "%Script")
	("ondragover"	. "%Script")
	("ondragstart"	. "%Script")
	("ondrop"	. "%Script")
	("onerrorupdate"	. "%Script")
	("onfilterchange"	. "%Script")
	("onfocus"	. "%Script")
	("onhelp"	. "%Script")
	("onkeydown"	. "%Script")
	("onkeypress"	. "%Script")
	("onkeyup"	. "%Script")
	("onlosecapture"	. "%Script")
	("onmousedown"	. "%Script")
	("onmousemove"	. "%Script")
	("onmouseout"	. "%Script")
	("onmouseover"	. "%Script")
	("onmouseup"	. "%Script")
	("onpropertychange"	. "%Script")
	("onresize"	. "%Script")
	("onrowenter"	. "%Script")
	("onrowexit"	. "%Script")
	("onscroll"	. "%Script")
	("onselect"	. "%Script")
	("onselectstart"	. "%Script")
	))

(html-edit-def-element "FIELDSET" t t '("PCDATA" "LEGEND" "%flow") nil)
(html-edit-def-attlist "FIELDSET"
	'(
	"%attrs"
	"%access"
	"%selection.attrs"
	("align"	. "%Align")
	("onbeforeeditfocus"	. "%Script")
	("oncontextmenu"	. "%Script")
	("onafterupdate"	. "%Script")
	("onbeforecopy"	. "%Script")
	("onbeforecut"	. "%Script")
	("onbeforepaste"	. "%Script")
	("onbeforeupdate"	. "%Script")
	("onblur"	. "%Script")
	("onclick"	. "%Script")
	("oncopy"	. "%Script")
	("oncut"	. "%Script")
	("ondblclick"	. "%Script")
	("ondrag"	. "%Script")
	("ondragend"	. "%Script")
	("ondragenter"	. "%Script")
	("ondragleave"	. "%Script")
	("ondragover"	. "%Script")
	("ondragstart"	. "%Script")
	("ondrop"	. "%Script")
	("onfilterchange"	. "%Script")
	("onfocus"	. "%Script")
	("onhelp"	. "%Script")
	("onkeydown"	. "%Script")
	("onkeypress"	. "%Script")
	("onkeyup"	. "%Script")
	("onlosecapture"	. "%Script")
	("onmousedown"	. "%Script")
	("onmousemove"	. "%Script")
	("onmouseout"	. "%Script")
	("onmouseover"	. "%Script")
	("onmouseup"	. "%Script")
	("onpaste"	. "%Script")
	("onpropertychange"	. "%Script")
	("onreadystatechange"	. "%Script")
	("onresize"	. "%Script")
	("onselectstart"	. "%Script")
	))

(html-edit-def-element "LEGEND" t t '("%inline") nil)
(html-edit-def-attlist "LEGEND"
	'(
	"%attrs"
	"%access"
	"%selection.attrs"
	("align"	. ("bottom" "center" "left" "right" "top"))
	("onblur"	. "%Script")
	("oncontextmenu"	. "%Script")
	("onfocus"	. "%Script")
	("onreadystatechange"	. "%Script")
	("onresize"	. "%Script")
	("onbeforecopy"	. "%Script")
	("onbeforecut"	. "%Script")
	("onbeforepaste"	. "%Script")
	("onclick"	. "%Script")
	("oncopy"	. "%Script")
	("oncut"	. "%Script")
	("ondblclick"	. "%Script")
	("onhelp"	. "%Script")
	("onkeydown"	. "%Script")
	("onkeypress"	. "%Script")
	("onkeyup"	. "%Script")
	("onlosecapture"	. "%Script")
	("onmousedown"	. "%Script")
	("onmousemove"	. "%Script")
	("onmouseout"	. "%Script")
	("onmouseover"	. "%Script")
	("onmouseup"	. "%Script")
	("onpaste"	. "%Script")
	("onpropertychange"	. "%Script")
	))

(html-edit-def-element "BUTTON" t t '("%flow") '("A" "%formctrl" "FORM" "ISINDEX" "FIELDSET" "IFRAME"))
(html-edit-def-attlist "BUTTON"
	'(
	"%attrs"
	"%access"
	"%selection.attrs"
	("dataformatas"	. ("html" "text"))
	("datafld"	. CDATA)
	("datasrc"	. CDATA)
	"%disabled"
	("name"	. CDATA)
	("type"	. ("button" "submit" "reset"))
	("value"	. CDATA)
	("onbeforecut"	. "%Script")
	("onbeforeeditfocus"	. "%Script")
	("onbeforepaste"	. "%Script")
	("oncontextmenu"	. "%Script")
	("oncut"	. "%Script")
	("onpaste"	. "%Script")
	("onreadystatechange"	. "%Script")
	("onafterupdate"	. "%Script")
	("onbeforeupdate"	. "%Script")
	("onblur"	. "%Script")
	("onclick"	. "%Script")
	("ondblclick"	. "%Script")
	("ondrag"	. "%Script")
	("ondragend"	. "%Script")
	("ondragenter"	. "%Script")
	("ondragleave"	. "%Script")
	("ondragover"	. "%Script")
	("ondragstart"	. "%Script")
	("ondrop"	. "%Script")
	("onfilterchange"	. "%Script")
	("onfocus"	. "%Script")
	("onhelp"	. "%Script")
	("onkeydown"	. "%Script")
	("onkeypress"	. "%Script")
	("onkeyup"	. "%Script")
	("onlosecapture"	. "%Script")
	("onmousedown"	. "%Script")
	("onmousemove"	. "%Script")
	("onmouseout"	. "%Script")
	("onmouseover"	. "%Script")
	("onmouseup"	. "%Script")
	("onpropertychange"	. "%Script")
	("onresize"	. "%Script")
	("onrowenter"	. "%Script")
	("onrowexit"	. "%Script")
	("onselectstart"	. "%Script")
	))

(html-edit-def-element "LABEL" t t '("%inline") '("LABEL"))
(html-edit-def-attlist "LABEL"
	'(
	"%attrs"
	"%access"
	"%selection.attrs"
	("dataformatas"	. ("html" "text"))
	("datafld"	. CDATA)
	("datasrc"	. CDATA)
	("for"	. IDREF)
	("onblur"	. "%Script")
	("oncontextmenu"	. "%Script")
	("oncut"	. "%Script")
	("onfocus"	. "%Script")
	("onpaste"	. "%Script")
	("onreadystatechange"	. "%Script")
	("onresize"	. "%Script")
	("onbeforecopy"	. "%Script")
	("onbeforecut"	. "%Script")
	("onbeforepaste"	. "%Script")
	("onclick"	. "%Script")
	("ondblclick"	. "%Script")
	("ondrag"	. "%Script")
	("ondragend"	. "%Script")
	("ondragenter"	. "%Script")
	("ondragleave"	. "%Script")
	("ondragover"	. "%Script")
	("ondragstart"	. "%Script")
	("ondrop"	. "%Script")
	("onhelp"	. "%Script")
	("onkeydown"	. "%Script")
	("onkeypress"	. "%Script")
	("onkeyup"	. "%Script")
	("onlosecapture"	. "%Script")
	("onmousedown"	. "%Script")
	("onmousemove"	. "%Script")
	("onmouseout"	. "%Script")
	("onmouseover"	. "%Script")
	("onmouseup"	. "%Script")
	("onpropertychange"	. "%Script")
	("onselectstart"	. "%Script")
	))

;;
;; ======================= Tables ========================================
;;

(html-edit-def-element "TABLE" t t '("CAPTION" "COLGROUP" "COL" "THEAD" "TFOOT" "TBODY") nil)
(html-edit-def-element "CAPTION" t t '("%inline") nil)
(html-edit-def-element "THEAD" t nil '("TR") nil)
(html-edit-def-element "TFOOT" t nil '("TR") nil)
(html-edit-def-element "TBODY" nil nil '("TR") nil)
(html-edit-def-element "COLGROUP" t nil '("COL") nil)
(html-edit-def-element "COL" t nil 'EMPTY nil)
(html-edit-def-element "TR" t nil '("TH" "TD") nil)
(html-edit-def-element '("TH" "TD") t nil '("%body.content") nil)

(html-edit-def-entity "%border" 'CDATA)

(html-edit-def-attlist "TABLE"
	'(
	"%attrs"
	"%access"
	"%selection.attrs"
	("align"	. ("center" "left" "right"))
	("border"	. "%border")
	("background"	. "%URL")
	("bgcolor"	. "%color")
	("bordercolor"	. "%color")
	("bordercolordark"	. "%color")
	("bordercolorlight"	. "%color")
	("cellspacing"	. "%Pixels")
	("cellpadding"	. "%Pixels")
	("cols"	. NUMBER)
	("datapagesize"	. NUMBER)
	("datasrc"	. "%URL")
	("frame"	. ("ABOVE" "BELOW" "BORDER" "BOX" "INSIDES" "LHS" "RHS" "VOID" "VSIDES"))
	("height"	. "%Length")
	("width"	. "%Length")
	("rules"	. ("ALL" "COLS" "GROUPS" "NONE" "ROWS"))
	("onbeforecut"	. "%Script")
	("onbeforeeditfocus"	. "%Script")
	("onbeforepaste"	. "%Script")
	("oncontextmenu"	. "%Script")
	("oncut"	. "%Script")
	("onpaste"	. "%Script")
	("onreadystatechange"	. "%Script")
	("onafterupdate"	. "%Script")
	("onbeforeupdate"	. "%Script")
	("onblur"	. "%Script")
	("onclick"	. "%Script")
	("ondblclick"	. "%Script")
	("ondrag"	. "%Script")
	("ondragend"	. "%Script")
	("ondragenter"	. "%Script")
	("ondragleave"	. "%Script")
	("ondragover"	. "%Script")
	("ondragstart"	. "%Script")
	("ondrop"	. "%Script")
	("onfilterchange"	. "%Script")
	("onfocus"	. "%Script")
	("onhelp"	. "%Script")
	("onkeydown"	. "%Script")
	("onkeypress"	. "%Script")
	("onkeyup"	. "%Script")
	("onlosecapture"	. "%Script")
	("onmousedown"	. "%Script")
	("onmousemove"	. "%Script")
	("onmouseout"	. "%Script")
	("onmouseover"	. "%Script")
	("onmouseup"	. "%Script")
	("onpropertychange"	. "%Script")
	("onresize"	. "%Script")
	("onrowenter"	. "%Script")
	("onrowexit"	. "%Script")
	("onscroll"	. "%Script")
	("onselectstart"	. "%Script")
	))

(html-edit-def-attlist "CAPTION"
	'(
	"%attrs"
	"%access"
	"%selection.attrs"
	("align"	. ("bottom" "center" "left" "right" "top"))
	("valign"	. ("top" "bottom"))
	("onblur"	. "%Script")
	("oncontextmenu"	. "%Script")
	("onfocus"	. "%Script")
	("onreadystatechange"	. "%Script")
	("onafterupdate"	. "%Script")
	("onbeforecopy"	. "%Script")
	("onbeforecut"	. "%Script")
	("onbeforepaste"	. "%Script")
	("onbeforeupdate"	. "%Script")
	("onclick"	. "%Script")
	("oncopy"	. "%Script")
	("oncut"	. "%Script")
	("ondblclick"	. "%Script")
	("ondrag"	. "%Script")
	("ondragend"	. "%Script")
	("ondragenter"	. "%Script")
	("ondragleave"	. "%Script")
	("ondragover"	. "%Script")
	("ondragstart"	. "%Script")
	("ondrop"	. "%Script")
	("onhelp"	. "%Script")
	("onkeydown"	. "%Script")
	("onkeypress"	. "%Script")
	("onkeyup"	. "%Script")
	("onlosecapture"	. "%Script")
	("onmousedown"	. "%Script")
	("onmousemove"	. "%Script")
	("onmouseout"	. "%Script")
	("onmouseover"	. "%Script")
	("onmouseup"	. "%Script")
	("onpaste"	. "%Script")
	("onpropertychange"	. "%Script")
	("onresize"	. "%Script")
	("onrowenter"	. "%Script")
	("onrowexit"	. "%Script")
	("onselectstart"	. "%Script")
	))


(html-edit-def-attlist "COLGROUP"
	'(
	"%attrs"
	("align"	. ("left" "center" "right"))
	("valign"	. ("baseline" "bottom" "middle" "top" "center"))
	("span"	. NUMBER)
	("bgcolor"	. "%color")
	("width"	. "%Length")
	("onreadystatechange"	. "%Script")
	))

(html-edit-def-attlist "COL"
	'(
	"%attrs"
	("align"	. ("left" "center" "right"))
	("valign"	. ("baseline" "bottom" "middle" "top" "center"))
	("span"	. NUMBER)
	("bgcolor"	. "%color")
	("width"	. "%Length")
	("onreadystatechange"	. "%Script")
	))

;;
;; Use THEAD to duplicate headers when breaking table
;; across page boundaries, or for static headers when
;; body sections are rendered in scrolling panel.
;; Use TFOOT to duplicate footers when breaking table
;; across page boundaries, or for static footers when
;; body sections are rendered in scrolling panel.
;; Use multiple TBODY sections when rules are needed
;; between groups of table rows.
;;
(html-edit-def-attlist "TBODY"
	'(
	"%attrs"
	"%access"
	"%selection.attrs"
	("align"	. ("left" "center" "right"))
	("valign"	. ("baseline" "bottom" "middle" "top" "center"))
	("bgcolor"	. "%color")
	("onbeforecut"	. "%Script")
	("onbeforepaste"	. "%Script")
	("onblur"	. "%Script")
	("oncontextmenu"	. "%Script")
	("oncut"	. "%Script")
	("onfocus"	. "%Script")
	("onpaste"	. "%Script")
	("onreadystatechange"	. "%Script")
	("onclick"	. "%Script")
	("ondblclick"	. "%Script")
	("ondrag"	. "%Script")
	("ondragend"	. "%Script")
	("ondragenter"	. "%Script")
	("ondragleave"	. "%Script")
	("ondragover"	. "%Script")
	("ondragstart"	. "%Script")
	("ondrop"	. "%Script")
	("onhelp"	. "%Script")
	("onkeydown"	. "%Script")
	("onkeypress"	. "%Script")
	("onkeyup"	. "%Script")
	("onlosecapture"	. "%Script")
	("onmousedown"	. "%Script")
	("onmousemove"	. "%Script")
	("onmouseout"	. "%Script")
	("onmouseover"	. "%Script")
	("onmouseup"	. "%Script")
	("onpropertychange"	. "%Script")
	("onselectstart"	. "%Script")
	))
(html-edit-def-attlist '("THEAD" "TFOOT")
	'(
	"%attrs"
	"%access"
	"%selection.attrs"
	("align"	. ("left" "center" "right"))
	("valign"	. ("baseline" "bottom" "middle" "top" "center"))
	("bgcolor"	. "%color")
	("onbeforecut"	. "%Script")
	("onbeforepaste"	. "%Script")
	("onblur"	. "%Script")
	("oncontextmenu"	. "%Script")
	("oncut"	. "%Script")
	("onfocus"	. "%Script")
	("onpaste"	. "%Script")
	("onreadystatechange"	. "%Script")
	("onclick"	. "%Script")
	("ondblclick"	. "%Script")
	("ondragenter"	. "%Script")
	("ondragstart"	. "%Script")
	("onhelp"	. "%Script")
	("onkeydown"	. "%Script")
	("onkeypress"	. "%Script")
	("onkeyup"	. "%Script")
	("onlosecapture"	. "%Script")
	("onmousedown"	. "%Script")
	("onmousemove"	. "%Script")
	("onmouseout"	. "%Script")
	("onmouseover"	. "%Script")
	("onmouseup"	. "%Script")
	("onpropertychange"	. "%Script")
	("onselectstart"	. "%Script")
	))

(html-edit-def-attlist "TR"
	'(
	"%attrs"
	"%access"
	("align"	. ("left" "center" "right"))
	("valign"	. ("baseline" "bottom" "middle" "top" "center"))
	("bgcolor"	. "%color")
	("bordercolor"	. "%color")
	("bordercolorlight"	. "%color")
	("bordercolordark"	. "%color")
	("width"	. "%Length")
	("height"	. "%Length")
	("onbeforeeditfocus"	. "%Script")
	("oncontextmenu"	. "%Script")
	("onreadystatechange"	. "%Script")
	("onafterupdate"	. "%Script")
	("onbeforecopy"	. "%Script")
	("onbeforecut"	. "%Script")
	("onbeforepaste"	. "%Script")
	("onbeforeupdate"	. "%Script")
	("onblur"	. "%Script")
	("onclick"	. "%Script")
	("oncopy"	. "%Script")
	("oncut"	. "%Script")
	("ondblclick"	. "%Script")
	("ondrag"	. "%Script")
	("ondragend"	. "%Script")
	("ondragenter"	. "%Script")
	("ondragleave"	. "%Script")
	("ondragover"	. "%Script")
	("ondragstart"	. "%Script")
	("ondrop"	. "%Script")
	("onfilterchange"	. "%Script")
	("onfocus"	. "%Script")
	("onhelp"	. "%Script")
	("onkeydown"	. "%Script")
	("onkeypress"	. "%Script")
	("onkeyup"	. "%Script")
	("onlosecapture"	. "%Script")
	("onmousedown"	. "%Script")
	("onmousemove"	. "%Script")
	("onmouseout"	. "%Script")
	("onmouseover"	. "%Script")
	("onmouseup"	. "%Script")
	("onpaste"	. "%Script")
	("onpropertychange"	. "%Script")
	("onresize"	. "%Script")
	("onrowenter"	. "%Script")
	("onrowexit"	. "%Script")
	("onselectstart"	. "%Script")
	))

(html-edit-def-attlist '("TD" "TH")
	'(
	"%attrs"
	"%access"
	("align"	. ("left" "center" "right"))
	("valign"	. ("baseline" "bottom" "middle" "top" "center"))
	("background"	. "%URL")
	("bgcolor"	. "%color")
	("bordercolor"	. "%color")
	("bordercolorlight"	. "%color")
	("bordercolordark"	. "%color")
	("rowspan"	. NUMBER)
	("colspan"	. NUMBER)
	("nowrap"	. ("nowrap" "true" "false"))
	("width"	. "%Length")
	("height"	. "%Length")
	("onafterupdate"	. "%Script")
	("onbeforecopy"	. "%Script")
	("onbeforecut"	. "%Script")
	("onbeforeeditfocus"	. "%Script")
	("onbeforepaste"	. "%Script")
	("onbeforeupdate"	. "%Script")
	("onblur"	. "%Script")
	("onclick"	. "%Script")
	("oncontextmenu"	. "%Script")
	("oncopy"	. "%Script")
	("oncut"	. "%Script")
	("ondblclick"	. "%Script")
	("ondrag"	. "%Script")
	("ondragend"	. "%Script")
	("ondragenter"	. "%Script")
	("ondragleave"	. "%Script")
	("ondragover"	. "%Script")
	("ondragstart"	. "%Script")
	("ondrop"	. "%Script")
	("onfilterchange"	. "%Script")
	("onfocus"	. "%Script")
	("onhelp"	. "%Script")
	("onkeydown"	. "%Script")
	("onkeypress"	. "%Script")
	("onkeyup"	. "%Script")
	("onlosecapture"	. "%Script")
	("onmousedown"	. "%Script")
	("onmousemove"	. "%Script")
	("onmouseout"	. "%Script")
	("onmouseover"	. "%Script")
	("onmouseup"	. "%Script")
	("onpaste"	. "%Script")
	("onpropertychange"	. "%Script")
	("onreadystatechange"	. "%Script")
	("onresize"	. "%Script")
	("onrowenter"	. "%Script")
	("onrowexit"	. "%Script")
	("onselectstart"	. "%Script")
	))

;;
;; ================ Document Head ========================================
;;

(html-edit-def-entity "%head.misc" '("SCRIPT" "STYLE" "META" "LINK" "BGSOUND" "BASEFONT"))

(html-edit-def-entity "%head.content" '("TITLE" "ISINDEX" "BASE"))

(html-edit-def-element "HEAD" nil nil '("%head.content" "%head.misc") nil)
(html-edit-def-attlist "HEAD"
	'(
	("id"	. ID)
	("class"	. NAMES)
	("title"	. CDATA)
	("lang"	. "%LanguageCode")
	("onreadystatechange"	. "%Script")
	))

(html-edit-def-element "TITLE" t t '("PCDATA") '("%head.misc"))
(html-edit-def-attlist "TITLE"
	'(
	("id"	. ID)
	("lang"	. "%LanguageCode")
	("dir"	. ("LTR" "RTL"))
	("title"	. CDATA)
	("onreadystatechange"	. "%Script")
	))

(html-edit-def-element "ISINDEX" t nil 'EMPTY nil)
(html-edit-def-attlist "ISINDEX"
	'(
	"%attrs"
	"%access"
	"%selection.attrs"
	("action"	. "%URL")
	("prompt"	. CDATA)
	("onblur"	. "%Script")
	("onfocus"	. "%Script")
	("onreadystatechange"	. "%Script")
	("onresize"	. "%Script")
	))

(html-edit-def-element "BASE" t nil 'EMPTY nil)
(html-edit-def-attlist "BASE"
	'(
	("id"	. ID)
	("href"	. "%URL")
	("target"	. CDATA)
	("onreadystatechange"	. "%Script")
	))

(html-edit-def-element "META" t nil 'EMPTY nil)
(html-edit-def-attlist "META"
	'(
	("content"	. CDATA)
	("http-equiv"	. NAME)
	("name"	. CDATA)
	("title"	. CDATA)
	))


(html-edit-def-element "STYLE" t t '("CDATA") nil)
(html-edit-def-attlist "STYLE"
	'(
	"%disabled"
	("type"	. "%ContentType")
	("title"	. CDATA)
	("media"	. ("screen" "print" "all"))
	("onerror"	. "%Script")
	("onload"	. "%Script")
	("onreadystatechange"	. "%Script")
	))

(html-edit-def-element "SCRIPT" t t '("CDATA") nil)
(html-edit-def-attlist "SCRIPT"
	'(
	("id"	. ID)
	("class"	. NAMES)
	("title"	. CDATA)
	("lang"	. "%LanguageCode")
	("dir"	. ("LTR" "RTL"))
	("language"	. ("%Language"))
	("src"	. "%URL")
	("defer"	. ("defer" "true" "false"))
	("event"	. CDATA)
	("for"	. IDREF)
	("type"	. "%ContentType")
	("onpropertychange"	. "%Script")
	("onerror"	. "%Script")
	("onload"	. "%Script")
	("onreadystatechange"	. "%Script")
	))

(html-edit-def-element "NOSCRIPT" t t '("%flow") nil)
(html-edit-def-attlist "NOSCRIPT"
	'(
	("id"	. ID)
	("onreadystatechange"	. "%Script")
	))


;;
;; ================ Document Structure ===================================
;;

(html-edit-def-element "HTML" nil nil '("HEAD" "BODY" "FRAMESET" "PLAINTEXT") nil)
(html-edit-def-attlist "HTML"
	'(
	("id"	. ID)
	("class"	. NAMES)
	("title"	. CDATA)
	("onreadystatechange"	. "%Script")
	))

;;
;; Frames
;;

(html-edit-def-element "FRAMESET" t t '("FRAMESET" "FRAME" "NOFRAMES") nil)
(html-edit-def-attlist "FRAMESET"
	'(
	("id"	. ID)
	("class"	. NAMES)
	("lang"	. "%LanguageCode")
	("dir"	. ("LTR" "RTL"))
	("language"	. ("%Language"))
	("title"	. CDATA)
	("tabindex"	. NUMBER)
	("border"	. "%Pixels")
	("rows"	. CDATA)
	("cols"	. CDATA)
	("frameborder"	. ("yes" "no" "1" "0"))
	("framespacing"	. "%Pixels")
	("bordercolor"	. "%color")
	"%selection.attrs"
	("onafterprint"	. "%Script")
	("onbeforeprint"	. "%Script")
	("onbeforeunload"	. "%Script")
	("onblur"	. "%Script")
	("onfocus"	. "%Script")
	("onload"	. "%Script")
	("onunload"	. "%Script")
	))

(html-edit-def-element "FRAME" t nil 'EMPTY nil)
(html-edit-def-attlist "FRAME"
	'(
	("id"	. ID)
	("class"	. NAMES)
	("lang"	. "%LanguageCode")
	("language"	. ("%Language"))
	("title"	. CDATA)
	("datafld"	. CDATA)
	("datasrc"	. CDATA)
	("bordercolor"	. "%color")
	("frameborder"	. ("yes" "no" "1" "0"))
	("width"	. "%Length")
	("height"	. "%Length")
	("marginwidth"	. "%Pixels")
	("marginheight"	. "%Pixels")
	("name"	. CDATA)
	("noresize"	. ("noresize" "true" "false"))
	("scrolling"	. ("auto" "yes" "no"))
	("src"	. "%URL")
	("application"	. ("yes" "no"))
	"%selection.attrs"
	("onblur"	. "%Script")
	("onfocus"	. "%Script")
	("onbeforeunload"	. "%Script")
	("onload"	. "%Script")
	("onresize"	. "%Script")
	("onunload"	. "%Script")
	))

(html-edit-def-element "IFRAME" t t '("%flow") nil)
(html-edit-def-attlist "IFRAME"
	'(
	("id"	. ID)
	("class"	. NAMES)
	("lang"	. "%LanguageCode")
	("language"	. ("%Language"))
	("title"	. CDATA)
	("style"	. "%StyleSheet")
	("tabindex"	. NUMBER)
	("datafld"	. CDATA)
	("datasrc"	. CDATA)
	"%selection.attrs"
	("align"	. "%Align")
	("border"	. "%Pixels")
	("bordercolor"	. "%color")
	("frameborder"	. ("yes" "no" "1" "0"))
	("framespacing"	. "%Pixels")
	("hspace"	. "%Pixels")
	("vspace"	. "%Pixels")
	("width"	. "%Length")
	("height"	. "%Length")
	("marginwidth"	. "%Pixels")
	("marginheight"	. "%Pixels")
	("name"	. CDATA)
	("noresize"	. ("noresize" "true" "false"))
	("scrolling"	. ("auto" "yes" "no"))
	("src"	. "%URL")
	("application"	. ("yes" "no"))
	("onblur"	. "%Script")
	("onfocus"	. "%Script")
	))

(html-edit-def-element "NOFRAMES" t t '("%body.content" "INS" "DEL") nil)
(html-edit-def-attlist "NOFRAMES"
	'(
	("id"	. ID)
	("title"	. CDATA)
	("style"	. "%StyleSheet")
	("onreadystatechange"	. "%Script")
	))


;;
;; OBJECT is a character-like element for inserting objects
;;
(html-edit-def-element "OBJECT" t t '("PARAM" "%body.content") nil)
(html-edit-def-attlist "OBJECT"
	'(
	"%attrs"
	"%access"
	"%selection.attrs"
	("datafld"	. CDATA)
	("datasrc"	. CDATA)
	("align"	. "%Align")
	("classid"	. "%URL")
	("code"	. "%URL")
	("codebase"	. "%URL")
	("data"	. "%URL")
	("height"	. "%Pixels")
	("width"	. "%Pixels")
	("hspace"	. "%Length")
	("vspace"	. "%Length")
	("name"	. CDATA)
	("type"	. "%ContentType")
	("codetype"	. CDATA)
	("onbeforeeditfocus"	. "%Script")
	("onresize"	. "%Script")
	("onafterupdate"	. "%Script")
	("onbeforeupdate"	. "%Script")
	("onblur"	. "%Script")
	("oncellchange"	. "%Script")
	("onclick"	. "%Script")
	("ondataavailable"	. "%Script")
	("ondatasetchanged"	. "%Script")
	("ondatasetcomplete"	. "%Script")
	("ondblclick"	. "%Script")
	("ondrag"	. "%Script")
	("ondragend"	. "%Script")
	("ondragenter"	. "%Script")
	("ondragleave"	. "%Script")
	("ondragover"	. "%Script")
	("ondragstart"	. "%Script")
	("ondrop"	. "%Script")
	("onerror"	. "%Script")
	("onerrorupdate"	. "%Script")
	("onfocus"	. "%Script")
	("onkeydown"	. "%Script")
	("onkeypress"	. "%Script")
	("onkeyup"	. "%Script")
	("onload"	. "%Script")
	("onlosecapture"	. "%Script")
	("onpropertychange"	. "%Script")
	("onreadystatechange"	. "%Script")
	("onrowenter"	. "%Script")
	("onrowexit"	. "%Script")
	("onrowsdelete"	. "%Script")
	("onrowsinserted"	. "%Script")
	("onscroll"	. "%Script")
	("onselectstart"	. "%Script")
	))

(html-edit-def-element "PARAM" t nil 'EMPTY nil)
(html-edit-def-attlist "PARAM"
	'(
	("dataformatas"	. ("html" "text"))
	("datafld"	. CDATA)
	("datasrc"	. CDATA)
	("name"	. CDATA)
	("value"	. CDATA)
	))

(html-edit-def-element "EMBED" t t '("%body.content") nil)
(html-edit-def-attlist "EMBED"
	'(
	"%attrs"
	"%access"
	"%selection.attrs"
	("align"	. "%Align")
	("alt"	. CDATA)
	("code"	. "%URL")
	("height"	. "%Length")
	("width"	. "%Length")
	("hspace"	. "%Length")
	("vspace"	. "%Length")
	("name"	. CDATA)
	("src"	. "%URL")
	("units"	. ("px" "em"))
	("pluginspage"	. "%URL")
	("onbeforecut"	. "%Script")
	("onbeforepaste"	. "%Script")
	("oncontextmenu"	. "%Script")
	("oncut"	. "%Script")
	("onpaste"	. "%Script")
	("onafterupdate"	. "%Script")
	("onbeforeupdate"	. "%Script")
	("onblur"	. "%Script")
	("onclick"	. "%Script")
	("ondblclick"	. "%Script")
	("onfocus"	. "%Script")
	("onhelp"	. "%Script")
	("onload"	. "%Script")
	("onlosecapture"	. "%Script")
	("onmousedown"	. "%Script")
	("onmousemove"	. "%Script")
	("onmouseout"	. "%Script")
	("onmouseover"	. "%Script")
	("onmouseup"	. "%Script")
	("onpropertychange"	. "%Script")
	("onreadystatechange"	. "%Script")
	("onresize"	. "%Script")
	("onrowenter"	. "%Script")
	("onrowexit"	. "%Script")
	("onscroll"	. "%Script")
	))

;;
;; ======================= Ruby ==========================================
;;

(html-edit-def-entity "%ruby.content" '("%inline" "RUBY"))

(html-edit-def-element "RUBY" t t '("RB" "RP" "RT" "RP") nil)
(html-edit-def-element "RB" nil nil '("%inline") nil)
(html-edit-def-element "RT" t nil '("%ruby.content") nil)
(html-edit-def-element "RP" t nil '("PCDATA") nil)

(html-edit-def-attlist '("RUBY" "RB" "RT" "RP")
	'(
	"%attrs"
	"%access"
	"%selection.attrs"
	("name"	. CDATA)
	("onafterupdate"	. "%Script")
	("onbeforeupdate"	. "%Script")
	("onbeforecut"	. "%Script")
	("onbeforepaste"	. "%Script")
	("onblur"	. "%Script")
	("onclick"	. "%Script")
	("oncontextmenu"	. "%Script")
	("oncut"	. "%Script")
	("ondblclick"	. "%Script")
	("ondragstart"	. "%Script")
	("onerrorupdate"	. "%Script")
	("onfilterchange"	. "%Script")
	("onfocus"	. "%Script")
	("onhelp"	. "%Script")
	("onkeydown"	. "%Script")
	("onkeypress"	. "%Script")
	("onkeyup"	. "%Script")
	("onmousedown"	. "%Script")
	("onmousemove"	. "%Script")
	("onmouseout"	. "%Script")
	("onmouseover"	. "%Script")
	("onmouseup"	. "%Script")
	("onpaste"	. "%Script")
	("onreadystatechange"	. "%Script")
	("onselectstart"	. "%Script")
	))
