;; html-edit-rule-imode40.el

;; This library is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2, or (at your option)
;; any later version.

;; This library is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with library; see the file COPYING.  If not, write to the
;; Free Software Foundation, Inc., 59 Temple Place - Suite 330,
;; Boston, MA 02111-1307, USA.

(require 'html-edit-rule)

;;
;; ====================== NTT DoCoMo iMode 4.0 ===========================
;;

;;
;; ================== Imported Names =====================================
;;

(html-edit-def-entity "%Content-Type" 'CDATA)

(html-edit-def-entity "%HTTP-Method" '("GET" "POST"))

(html-edit-def-entity "%URL" 'CDATA)

;;
;; Parameter Entities
;;

(html-edit-def-entity "%heading" '("H1" "H2" "H3" "H4" "H5" "H6"))

(html-edit-def-entity "%list" '("UL" "OL" "DIR" "MENU"))

(html-edit-def-entity "%preformatted" '("PRE" "PLAINTEXT"))

;;
;; =================== Text Markup =======================================
;;

(html-edit-def-entity "%special" '("A" "IMG" "BR" "BLINK" "MARQUEE" "FONT" "OBJECT"))
(html-edit-def-entity "%fontstyle" '("I" "B"))

(html-edit-def-entity "%form" '("INPUT" "SELECT" "TEXTAREA"))

(html-edit-def-entity "%text" '(PCDATA "%special" "%form"))

(html-edit-def-entity "%br.attrs" 
	'(
	("clear"	. ("left" "all" "right"))
	))

(html-edit-def-element "BR" t nil 'EMPTY nil)
(html-edit-def-attlist "BR"
	'(
	"%br.attrs"
	))

;;
;; ================== HTML content models ================================
;;

(html-edit-def-entity "%block" '("P" "%list" "%preformatted" "DL" "DIV" "CENTER" "BLOCKQUOTE" "FORM" "HR"))

(html-edit-def-entity "%flow" '("%text" "%block"))

;;
;; =================== Document Body =====================================
;;

(html-edit-def-entity "%body.content" '("%heading" "%text" "%block"))

(html-edit-def-entity "%color" 'CDATA)

(html-edit-def-element "BODY" nil nil '("%body.content") nil)
(html-edit-def-attlist "BODY"
	'(
	("bgcolor"	. "%color")
	("text"	. "%color")
	("link"	. "%color")
	("alink"	. "%color")
	("vlink"	. "%color")
	))


(html-edit-def-element "DIV" t t '("%body.content") nil)
(html-edit-def-attlist "DIV"
	'(
	("align"	. ("left" "center" "right"))
	))

(html-edit-def-element "center" t t '("%body.content") nil)

;;
;; ================== The Anchor Element =================================
;;

(html-edit-def-entity "%Character" 'CDATA)
(html-edit-def-entity "%accesskey" 
	'(
	("accesskey"	. "%Character")
	))

(html-edit-def-entity "%CharacterCTI" 'CDATA)
(html-edit-def-entity "%a.attrs.20" 
	'(
	("cti"	. "%CharacterCTI")
	))


(html-edit-def-entity "%alphanum" 'CDATA)
(html-edit-def-entity "%hankana" 'CDATA)
(html-edit-def-entity "%a.attrs.30" 
	'(
	("ijam"	. IDREF)
	("subject"	. "%alphanum")
	("body"	. "%alphanum")
	("telbook"	. CDATA)
	("kana"	. "%hankana")
	("email"	. CDATA)
	))

(html-edit-def-entity "%a.attrs.40" 
	'(
	("ista"	. IDREF)
	))


(html-edit-def-entity "%utn" 
	'(
	("utn"	. "UTN")
	))

(html-edit-def-element "A" t t '("%text") '("A"))
(html-edit-def-attlist "A"
	'(
	("name"	. CDATA)
	("href"	. "%URL")
	"%accesskey"
	"%a.attrs.20"
	"%a.attrs.30"
	"%a.attrs.40"
	"%utn"
	))

;;
;; =================== Images ============================================
;;

(html-edit-def-entity "%Length" 'CDATA)
(html-edit-def-entity "%Pixels" 'NUMBER)

(html-edit-def-entity "%IAlign" '("top" "middle" "bottom" "left" "right"))
(html-edit-def-entity "%ImgAlign" '("top" "middle" "bottom" "left" "right" "center"))

(html-edit-def-element "IMG" t nil 'EMPTY nil)
(html-edit-def-attlist "IMG"
	'(
	("src"	. "%URL")
	("align"	. "%ImgAlign")
	("width"	. "%Length")
	("height"	. "%Length")
	("hspace"	. "%Pixels")
	("vspace"	. "%Pixels")
	("alt"	. CDATA)
	))

(html-edit-def-entity "%ObjectContents" '("PARAM"))

(html-edit-def-element "OBJECT" t t '("%ObjectContents") nil)
(html-edit-def-attlist "OBJECT"
	'(
	("declare"	. "declare")
	("id"	. ID)
	("data"	. "%URL")
	("type"	. CDATA)
	))

(html-edit-def-element "PARAM" t t 'EMPTY nil)
(html-edit-def-entity "%Name" 'CDATA)
(html-edit-def-attlist "PARAM"
	'(
	("name"	. "%Name")
	("value"	. CDATA)
	))

;;
;; =================== Marquee/Blink/Font ================================
;;

(html-edit-def-element "MARQUEE" t t '("%text") nil)
(html-edit-def-attlist "MARQUEE"
	'(
	("direction"	. ("left" "right"))
	("loop"	. NUMBER)
	("behavior"	. ("scroll" "slide" "alternate"))
	))

(html-edit-def-element "BLINK" t t '("%text") nil)

(html-edit-def-element "FONT" t t '("%text") nil)
(html-edit-def-attlist "FONT"
	'(
	("color"	. "%color")
	))

;;
;; =================== Horizontal Rule ===================================
;;

(html-edit-def-entity "%hr.color" 
	'(
	("color"	. "%color")
	))

(html-edit-def-element "HR" t nil 'EMPTY nil)
(html-edit-def-attlist "HR"
	'(
	("align"	. ("left" "right" "center"))
	("size"	. "%Pixels")
	("width"	. "%Length")
	"%hr.color"
	))

;;
;; =================== Paragraphs=========================================
;;

(html-edit-def-element "P" t nil '("%text") nil)
(html-edit-def-attlist "P"
	'(
	("align"	. ("left" "center" "right"))
	))

;;
;; =================== Headings ==========================================
;;

(html-edit-def-element '("%heading") t t '("%text") nil)
(html-edit-def-attlist '("%heading")
	'(
	("align"	. ("left" "center" "right"))
	))

;;
;; =================== Preformatted Text =================================
;;

(html-edit-def-entity "%pre.exclusion" 'IMG)

(html-edit-def-element "PRE" t t '("%text") '("%pre.exclusion"))

(html-edit-def-entity "%literal" 'CDATA)
(html-edit-def-element "PLAINTEXT" t t '("%literal") nil)

;;
;; =================== Block-like Quotes =================================
;;

(html-edit-def-element "BLOCKQUOTE" t t '("%body.content") nil)

;;
;; =================== Lists =============================================
;;

(html-edit-def-element "DL" t t '("DT" "DD") nil)
(html-edit-def-element "DT" t nil '("%text") nil)
(html-edit-def-element "DD" t nil '("%flow") nil)

(html-edit-def-element '("OL" "UL") t t '("LI") nil)

(html-edit-def-entity "%OLStyle" 'CDATA)
(html-edit-def-attlist "OL"
	'(
	("type"	. "%OLStyle")
	("start"	. NUMBER)
	))

(html-edit-def-element '("DIR" "MENU") t t '("LI") '("%block"))

(html-edit-def-element "LI" t nil '("%flow") nil)

(html-edit-def-entity "%LIStyle" 'CDATA)
(html-edit-def-attlist "LI"
	'(
	("type"	. "%LIStyle")
	("value"	. NUMBER)
	))

;;
;; ================ Forms ===============================================
;;

(html-edit-def-element "FORM" t t '("%body.content") '("FORM"))
(html-edit-def-attlist "FORM"
	'(
	("action"	. "%URL")
	("method"	. ("%HTTP-Method"))
	"%utn"
	))

(html-edit-def-entity "%InputType" '("TEXT" "PASSWORD" "CHECKBOX" "RADIO" "HIDDEN" "SUBMIT" "RESET"))

(html-edit-def-entity "%input.style" 
	'(
	("istyle"	. ("1" "2" "3" "4"))
	))
(html-edit-def-entity "%input.src" 
	'(
	("src"	. "%URL")
	))
(html-edit-def-entity "%input.align" 
	'(
	("align"	. "%IAlign")
	))

(html-edit-def-element "INPUT" t nil 'EMPTY nil)
(html-edit-def-attlist "INPUT"
	'(
	("type"	. "%InputType")
	("name"	. CDATA)
	("value"	. CDATA)
	("checked"	. "checked")
	("size"	. CDATA)
	("maxlength"	. NUMBER)
	"%input.src"
	"%input.align"
	"%accesskey"
	"%input.style"
	))

(html-edit-def-entity "%select.multiple" 
	'(
	("multiple"	. "multiple")
	))

(html-edit-def-element "SELECT" t t '("OPTION") nil)
(html-edit-def-attlist "SELECT"
	'(
	("name"	. CDATA)
	("size"	. NUMBER)
	"%select.multiple"
	))

(html-edit-def-element "OPTION" t nil '("PCDATA") nil)
(html-edit-def-attlist "OPTION"
	'(
	("selected"	. "selected")
	("value"	. CDATA)
	))

(html-edit-def-element "TEXTAREA" t t '("PCDATA") nil)
(html-edit-def-attlist "TEXTAREA"
	'(
	("name"	. CDATA)
	("rows"	. NUMBER)
	("cols"	. NUMBER)
	"%input.style"
	))

;;
;; ================ Document Head ========================================
;;

(html-edit-def-entity "%head.content" '("TITLE" "BASE"))
(html-edit-def-entity "%head.misc" "+(META)")

(html-edit-def-element "HEAD" nil nil '("%head.content" "%head.misc") nil)

(html-edit-def-element "TITLE" t t '("PCDATA") nil)

(html-edit-def-element "BASE" t nil 'EMPTY nil)
(html-edit-def-attlist "BASE"
	'(
	("href"	. "%URL")
	))

(html-edit-def-element "META" t nil 'EMPTY nil)
(html-edit-def-attlist "META"
	'(
	("http-equiv"	. NAME)
	("name"	. NAME)
	("content"	. CDATA)
	))

;;
;; ================ Document Structure ===================================
;;

(html-edit-def-entity "%html.content" '("HEAD" "BODY"))

(html-edit-def-element "HTML" nil nil '("%html.content") nil)
(html-edit-def-attlist "HTML"
	'(
	))

;;
;; ================ End of DTD ===========================================
;;
