;; html-edit-rule-nn.el

;; This library is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2, or (at your option)
;; any later version.

;; This library is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with library; see the file COPYING.  If not, write to the
;; Free Software Foundation, Inc., 59 Temple Place - Suite 330,
;; Boston, MA 02111-1307, USA.

(require 'html-edit-rule)
;;
;; ================== Imported Names =====================================
;;

(html-edit-def-entity "%Content-Type" 'CDATA)

(html-edit-def-entity "%HTTP-Method" '("GET" "POST"))

(html-edit-def-entity "%MIMEType" 'CDATA)

(html-edit-def-entity "%URL" 'CDATA)

(html-edit-def-entity "%URLwithName" 'CDATA)

;;
;; Parameter Entities
;;

(html-edit-def-entity "%head.misc" '("SCRIPT" "SERVER" "STYLE" "META" "LINK"))

(html-edit-def-entity "%heading" '("H1" "H2" "H3" "H4" "H5" "H6"))

(html-edit-def-entity "%list" '("UL" "OL" "DIR" "MENU"))

(html-edit-def-entity "%preformatted" '("PRE" "XMP" "LISTING"))

(html-edit-def-entity "%Script" 'CDATA)
(html-edit-def-entity "%StyleSheet" 'CDATA)

;;
;; =================== Generic Attributes ===============================
;;

(html-edit-def-entity "%Lang" 'NAME)

(html-edit-def-entity "%coreattrs" 
	'(
	("id"	. ID)
	("class"	. CDATA)
	("style"	. "%StyleSheet")
	))

(html-edit-def-entity "%i18n" 
	'(
	("lang"	. "%Lang")
	))

(html-edit-def-entity "%attrs" 
	'(
	"%coreattrs"
	"%i18n"
	))

;;
;; =================== Text Markup =======================================
;;

(html-edit-def-entity "%font" '("TT" "I" "B" "BIG" "SMALL" "SUB" "SUP" "BLINK" "STRIKE" "S" "U"))

(html-edit-def-entity "%phrase" '("EM" "STRONG" "CODE" "SAMP" "KBD" "VAR" "CITE"))

(html-edit-def-entity "%special" '("A" "IMG" "HYPE" "APPLET" "EMBED" "OBJECT" "FONT" "BASEFONT" "BR" "WBR" "NOBR" "SCRIPT" "SERVER" "NOSCRIPT" "MAP" "SPACER" "LAYER" "ILAYER" "NOLAYER" "SPAN"))

(html-edit-def-entity "%form" '("INPUT" "SELECT" "TEXTAREA" "KEYGEN"))

(html-edit-def-entity "%text" '(PCDATA "%font" "%phrase" "%special"))

(html-edit-def-element '("%font" "%phrase") t t '("%text") nil)
(html-edit-def-attlist '("%font" "%phrase")
	'(
	"%attrs"
	))

;;
;; there are also 16 widely known color names although
;; the resulting colors are implementation dependent:
;; aqua, black, blue, fuchsia, gray, green, lime, maroon,
;; navy, olive, purple, red, silver, teal, white, and yellow
;; These colors were originally picked as being the standard
;; 16 colors supported with the Windows VGA palette.
;;

(html-edit-def-entity "%rsize" 'CDATA)
(html-edit-def-entity "%fsize" 'CDATA)
(html-edit-def-entity "%face" 'CDATA)
(html-edit-def-entity "%point" 'CDATA)
(html-edit-def-entity "%color" 'CDATA)

(html-edit-def-entity "%font-attrs" 
	'(
	("face"	. "%face")
	("point-size"	. "%point")
	("weight"	. NUMBER)
	))

(html-edit-def-element "FONT" t t '("%text") nil)
(html-edit-def-attlist "FONT"
	'(
	"%attrs"
	("size"	. "%rsize")
	("color"	. "%color")
	"%font-attrs"
	))

(html-edit-def-element "BASEFONT" t nil '("%text") nil)
(html-edit-def-attlist "BASEFONT"
	'(
	"%attrs"
	("size"	. "%fsize")
	))

(html-edit-def-element '("BR" "WBR") t nil 'EMPTY nil)
(html-edit-def-attlist "BR"
	'(
	"%attrs"
	("clear"	. ("left" "all" "right"))
	))
(html-edit-def-attlist "WBR"
	'(
	))

(html-edit-def-element "NOBR" t nil '("%text") '("NOBR"))
(html-edit-def-attlist "NOBR"
	'(
	"%attrs"
	))

;;
;; ================== HTML content models ================================
;;
;;
;; HTML has three basic content models:
;; %text;       character level elements and text strings
;; %flow;       block-like elements e.g. paragraphs and lists
;; %bodytext;   as %flow plus headers H1-H6 and ADDRESS
;;

(html-edit-def-entity "%block" '("P" "%list" "%preformatted" "DL" "DIV" "CENTER" "BLOCKQUOTE" "FORM" "ISINDEX" "HR" "TABLE" "ADDRESS" "MULTICOL"))

(html-edit-def-entity "%block.content" '("%heading" "%text" "%block"))

;;
;; %flow is used for DD and LI
;;

(html-edit-def-entity "%flow" '("%text" "%block"))

;;
;; =================== Document Body =====================================
;;

(html-edit-def-entity "%body.content" '("%heading" "%text" "%block"))

(html-edit-def-entity "%body-color-attrs" 
	'(
	("bgcolor"	. "%color")
	("text"	. "%color")
	("link"	. "%color")
	("vlink"	. "%color")
	("alink"	. "%color")
	))

(html-edit-def-entity "%Length" 'CDATA)
(html-edit-def-entity "%Pixels" 'NUMBER)

(html-edit-def-entity "%body-margin-attrs" 
	'(
	("marginwidth"	. "%Pixels")
	("marginheight"	. "%Pixels")
	))

(html-edit-def-element "BODY" nil nil '("%body.content") nil)
(html-edit-def-attlist "BODY"
	'(
	"%attrs"
	("background"	. "%URL")
	"%body-color-attrs"
	"%body-margin-attrs"
	("onblur"	. "%Script")
	("onfocus"	. "%Script")
	("onload"	. "%Script")
	("onunload"	. "%Script")
	))

(html-edit-def-entity "%address.content" '("%text" "P"))

(html-edit-def-element "ADDRESS" t t '("%address.content") nil)
(html-edit-def-attlist "ADDRESS"
	'(
	"%attrs"
	))

(html-edit-def-element "DIV" t t '("%body.content") nil)
(html-edit-def-attlist "DIV"
	'(
	"%attrs"
	("align"	. ("left" "center" "right"))
	))

;;
;; CENTER is a shorthand for DIV with ALIGN=CENTER
;;
(html-edit-def-element "CENTER" t t '("%body.content") nil)
(html-edit-def-attlist "CENTER"
	'(
	"%attrs"
	))

;;
;; ================== The Anchor Element =================================
;;

(html-edit-def-element "A" t t '("%text") '("A"))
(html-edit-def-attlist "A"
	'(
	"%attrs"
	("name"	. CDATA)
	("href"	. "%URL")
	("onclick"	. "%Script")
	("onmouseout"	. "%Script")
	("onmouseover"	. "%Script")
	("target"	. CDATA)
	))

;;
;; ================== Client-side image maps ============================
;;

;;
;; These can be placed in the same document or grouped in a
;; separate document although this isn't yet widely supported
;;

(html-edit-def-entity "%SHAPE" '("rect" "circle" "poly" "default"))
(html-edit-def-entity "%COORDS" 'CDATA)

(html-edit-def-element "MAP" t t '("AREA") nil)
(html-edit-def-attlist "MAP"
	'(
	("name"	. CDATA)
	))

(html-edit-def-element "AREA" t nil 'EMPTY nil)
(html-edit-def-attlist "AREA"
	'(
	"%attrs"
	("coords"	. "%COORDS")
	("shape"	. "%SHAPE")
	("href"	. "%URL")
	("nohref"	. "nohref")
	("alt"	. CDATA)
	("target"	. CDATA)
	("onmouseout"	. "%Script")
	("onmouseover"	. "%Script")
	))

;;
;; =================== Images ============================================
;;

;;
;; Suggested widths are used for negotiating image size
;; with the module responsible for painting the image.
;; align=left or right cause image to float to margin
;; and for subsequent text to wrap around image
;;

(html-edit-def-entity "%img-attrs" 
	'(
	("suppress"	. ("true" "false"))
	("nosave"	. "nosave")
	))
(html-edit-def-entity "%IAlign" '("top" "bottom" "left" "right" "absmiddle" "absbottom" "texttop" "middle" "baseline"))


(html-edit-def-element "IMG" t nil 'EMPTY nil)
(html-edit-def-attlist "IMG"
	'(
	"%attrs"
	("src"	. "%URL")
	("lowsrc"	. "%URL")
	("alt"	. CDATA)
	("align"	. "%IAlign")
	("border"	. "%Pixels")
	("height"	. "%Length")
	("width"	. "%Length")
	("hspace"	. "%Pixels")
	("vspace"	. "%Pixels")
	("ismap"	. "ismap")
	("usemap"	. "%URLwithName")
	("name"	. CDATA)
	("onabort"	. "%Script")
	("onerror"	. "%Script")
	("onload"	. "%Script")
	"%img-attrs"
	))

(html-edit-def-element "HYPE" t nil 'EMPTY nil)

;;
;; USEMAP points to a MAP element which may be in this document
;; or an external document, although the latter is not widely supported
;;

;;
;; =================== Embedding =========================================
;;

(html-edit-def-entity "%time" 'CDATA)
(html-edit-def-entity "%volume" 'CDATA)
(html-edit-def-entity "%border" 'CDATA)

(html-edit-def-element "EMBED" t t '("NOEMBED" "%body.content") nil)
(html-edit-def-attlist "EMBED"
	'(
	("ALIGN"	. ("left" "right" "top" "bottom"))
	("BORDER"	. "%border")
	("FRAMEBORDER"	. "NO")
	("HEIGHT"	. "%Pixels")
	("WIDTH"	. "%Pixels")
	("UNITS"	. "%Pixels")
	("HIDDEN"	. ("TRUE" "FALSE"))
	("NAME"	. CDATA)
	("PALETTE"	. ("FOREGROUND" "BACKGROUND"))
	("PLUGINSPAGE"	. "%URL")
	("PLUGINURL"	. "%URL")
	("SRC"	. "%URL")
	("TYPE"	. "%MIMEType")
	("HSPACE"	. "%Pixels")
	("VSPACE"	. "%Pixels")
	))

(html-edit-def-element "NOEMBED" t t '("PCDATA") '("NOEMBED"))
(html-edit-def-attlist "NOEMBED"
	'(
	"%attrs"
	))

(html-edit-def-element "OBJECT" t t '("PARAM" "%flow") nil)
(html-edit-def-attlist "OBJECT"
	'(
	("CLASSID"	. "%URL")
	("DATA"	. "%URL")
	("CODEBASE"	. "%URL")
	("TYPE"	. "%MIMEType")
	("ALIGN"	. ("left" "right" "top" "bottom"))
	("HEIGHT"	. "%Pixels")
	("WIDTH"	. "%Pixels")
	("ID"	. ID)
	))

;;
;; =================== Java APPLET tag ===================================
;;
;;
;; This tag is supported by all Java enabled browsers. Applet resources
;; (including their classes) are normally loaded relative to the document
;; URL (or <BASE> element if it is defined). The CODEBASE attribute is used
;; to change this default behavior. If the CODEBASE attribute is defined then
;; it specifies a different location to find applet resources. The value
;; can be an absolute URL or a relative URL. The absolute URL is used as is
;; without modification and is not effected by the documents <BASE> element.
;; When the codebase attribute is relative, then it is relative to the
;; document URL (or <BASE> tag if defined).
;;

(html-edit-def-entity "%applet-attrs" 
	'(
	("archive"	. "%URL")
	("mayscript"	. "mayscript")
	))

(html-edit-def-element "APPLET" t t '("PARAM" "%text") nil)
(html-edit-def-attlist "APPLET"
	'(
	"%attrs"
	("code"	. "%URL")
	("codebase"	. "%URL")
	("name"	. CDATA)
	("width"	. "%Length")
	("height"	. "%Length")
	("align"	. "%IAlign")
	("hspace"	. "%Pixels")
	("vspace"	. "%Pixels")
	("alt"	. CDATA)
	"%applet-attrs"
	))

(html-edit-def-element "PARAM" t nil 'EMPTY nil)
(html-edit-def-attlist "PARAM"
	'(
	("name"	. NMTOKEN)
	("value"	. CDATA)
	))

;;
;; Here is an example:
;; <applet codebase="applets/NervousText"
;; code=NervousText.class
;; width=300
;; height=50>
;; <param name=text value="Java is Cool!">
;; <img src=sorry.gif alt="This looks better with Java support">
;; </applet>
;;

;;
;; =================== Horizontal Rule ===================================
;;

(html-edit-def-element "HR" t nil 'EMPTY nil)
(html-edit-def-attlist "HR"
	'(
	"%attrs"
	("align"	. ("left" "right" "center"))
	("noshade"	. "noshade")
	("size"	. "%Pixels")
	("width"	. "%Length")
	))

(html-edit-def-element "SPACER" t nil 'EMPTY nil)
(html-edit-def-attlist "SPACER"
	'(
	("ALIGN"	. "%IAlign")
	("HEIGHT"	. "%Pixels")
	("WIDTH"	. "%Pixels")
	("SIZE"	. "%Pixels")
	("TYPE"	. ("horizontal" "vertical" "block"))
	))

;;
;; =================== Paragraphs =========================================
;;

(html-edit-def-element "P" t nil '("%text") nil)
(html-edit-def-attlist "P"
	'(
	"%attrs"
	("align"	. ("left" "center" "right"))
	))

;;
;; =================== Headings ==========================================
;;

;;
;; There are six levels of headers from H1 (the most important)
;; to H6 (the least important).
;;

(html-edit-def-element '("%heading") t t '("%text") nil)
(html-edit-def-attlist '("%heading")
	'(
	"%attrs"
	("align"	. ("left" "center" "right"))
	))

;;
;; =================== Preformatted Text =================================
;;

;;
;; excludes images and changes in font size
;;

(html-edit-def-entity "%pre.exclusion" '("IMG" "APPLET" "OBJECT" "HYPE" "BIG" "SMALL" "SUB" "SUP" "FONT" "EMBED"))

(html-edit-def-element "PRE" t t '("%text") '("%pre.exclusion"))
(html-edit-def-attlist "PRE"
	'(
	"%attrs"
	("cols"	. NUMBER)
	("wrap"	. "wrap")
	))


(html-edit-def-entity "%literal" 'CDATA)

(html-edit-def-element "XMP" t t '("%literal") nil)
(html-edit-def-attlist "XMP"
	'(
	"%attrs"
	))

(html-edit-def-element "LISTING" t t '("%literal") nil)
(html-edit-def-attlist "LISTING"
	'(
	"%attrs"
	))
(html-edit-def-element "PLAINTEXT" t nil '("%literal") nil)
(html-edit-def-attlist "PLAINTEXT"
	'(
	"%attrs"
	))

;;
;; =================== Block-like Quotes =================================
;;

(html-edit-def-element "BLOCKQUOTE" t t '("%body.content") nil)
(html-edit-def-attlist "BLOCKQUOTE"
	'(
	"%attrs"
	))

;;
;; =================== Lists =============================================
;;

;;
;; HTML 3.2 allows you to control the sequence number for ordered lists.
;; You can set the sequence number with the START and VALUE attributes.
;; The TYPE attribute may be used to specify the rendering of ordered
;; and unordered lists.
;;

;;
;; definition lists - DT for term, DD for its definition
;;

(html-edit-def-element "DL" t t '("DT" "DD") nil)
(html-edit-def-attlist "DL"
	'(
	"%attrs"
	("compact"	. "compact")
	))

(html-edit-def-element "DT" t nil '("%text") nil)
(html-edit-def-element "DD" t nil '("%flow") nil)
(html-edit-def-attlist '("DT" "DD")
	'(
	"%attrs"
	))

;;
;; Ordered lists OL, and unordered lists UL
;;
(html-edit-def-element '("OL" "UL") t t '("LI") nil)

;;
;; Numbering style
;; 1   Arabic numbers      1, 2, 3, ...
;; a   lower alpha         a, b, c, ...
;; A   upper alpha         A, B, C, ...
;; i   lower Roman         i, ii, iii, ...
;; I   upper Roman         I, II, III, ...
;; The style is applied to the sequence number which by default
;; is reset to 1 for the first list item in an ordered list.
;; This can't be expressed directly in SGML due to case folding.
;;

(html-edit-def-entity "%OLStyle" '("1" "a" "A" "i" "I"))

(html-edit-def-attlist "OL"
	'(
	"%attrs"
	("type"	. "%OLStyle")
	("start"	. NUMBER)
	))

;;
;; bullet styles
;;

(html-edit-def-entity "%ULStyle" '("disc" "square" "circle"))

(html-edit-def-attlist "UL"
	'(
	"%attrs"
	("type"	. ("%ULStyle"))
	))

(html-edit-def-entity "%DIRStyle" '("1" "a" "A" "i" "I" "disc" "square" "circle"))
(html-edit-def-entity "%dir-types" 
	'(
	("type"	. "%DIRStyle")
	))


(html-edit-def-element '("DIR" "MENU") t t '("LI") '("%block"))
(html-edit-def-attlist '("DIR" "MENU")
	'(
	"%attrs"
	"%dir-types"
	))

;;
;; <DIR>              Directory list
;;
;;
;; <DIR COMPACT>      Compact list style
;;
;;
;; <MENU>             Menu list
;;
;;
;; <MENU COMPACT>     Compact list style
;;

;;
;; The type attribute can be used to change the bullet style
;; in unordered lists and the numbering style in ordered lists
;;

(html-edit-def-entity "%LIStyle" 'CDATA)

(html-edit-def-element "LI" t nil '("%flow") nil)
(html-edit-def-attlist "LI"
	'(
	"%attrs"
	("type"	. "%LIStyle")
	("value"	. NUMBER)
	))

;;
;; ================ Forms ===============================================
;;

(html-edit-def-element "FORM" t t '("%body.content" "%form") '("FORM"))
(html-edit-def-attlist "FORM"
	'(
	"%attrs"
	("action"	. "%URL")
	("method"	. ("%HTTP-Method"))
	("enctype"	. "%Content-Type")
	("name"	. CDATA)
	("target"	. CDATA)
	("onreset"	. "%Script")
	("onsubmit"	. "%Script")
	))

(html-edit-def-entity "%InputType" '("BUTTON" "CHECKBOX" "FILE" "HIDDEN" "IMAGE" "PASSWORD" "RADIO" "RESET" "SUBMIT" "TEXT"))

(html-edit-def-element "INPUT" t nil 'EMPTY nil)
(html-edit-def-attlist "INPUT"
	'(
	"%attrs"
	("type"	. "%InputType")
	("name"	. CDATA)
	("value"	. CDATA)
	("checked"	. "checked")
	("size"	. "%Pixels")
	("maxlength"	. NUMBER)
	("src"	. "%URL")
	("align"	. "%IAlign")
	("onblur"	. "%Script")
	("onchange"	. "%Script")
	("onclick"	. "%Script")
	("onfocus"	. "%Script")
	("onselect"	. "%Script")
	("width"	. "%Length")
	("height"	. "%Length")
	("border"	. "%border")
	))

(html-edit-def-element "SELECT" t t '("OPTION") '("%form"))
(html-edit-def-attlist "SELECT"
	'(
	("name"	. CDATA)
	("size"	. "%Pixels")
	("multiple"	. "multiple")
	("onblur"	. "%Script")
	("onchange"	. "%Script")
	("onclick"	. "%Script")
	("onfocus"	. "%Script")
	))

(html-edit-def-element "OPTION" t nil '("PCDATA") nil)
(html-edit-def-attlist "OPTION"
	'(
	("selected"	. "selected")
	("value"	. CDATA)
	))

;;
;; Multi-line text input field.
;;

(html-edit-def-element "TEXTAREA" t t '("PCDATA") '("%form"))
(html-edit-def-attlist "TEXTAREA"
	'(
	"%attrs"
	("name"	. CDATA)
	("cols"	. NUMBER)
	("rows"	. NUMBER)
	("wrap"	. ("OFF" "HARD" "SOFT"))
	("onblur"	. "%Script")
	("onchange"	. "%Script")
	("onfocus"	. "%Script")
	("onselect"	. "%Script")
	))

(html-edit-def-element "KEYGEN" t nil 'EMPTY nil)
(html-edit-def-attlist "KEYGEN"
	'(
	("CHALLENGE"	. CDATA)
	("NAME"	. CDATA)
	))

;;
;; ======================= Tables ========================================
;;

;;
;; Widely deployed subset of the full table standard, see RFC 1942
;; e.g. at http://www.ics.uci.edu/pub/ietf/html/rfc1942.txt
;;

;;
;; horizontal placement of table relative to window
;;
(html-edit-def-entity "%Where" '("left" "center" "right"))

;;
;; horizontal alignment attributes for cell contents
;;
(html-edit-def-entity "%cell.halign" 
	'(
	("align"	. ("left" "center" "right"))
	))

;;
;; vertical alignment attributes for cell contents
;;
(html-edit-def-entity "%cell.valign" 
	'(
	("valign"	. ("top" "middle" "bottom" "baseline"))
	))

(html-edit-def-element "TABLE" t t '("CAPTION" "TR") nil)
(html-edit-def-element "TR" t nil '("TH" "TD") nil)
(html-edit-def-element '("TH" "TD") t nil '("%body.content") nil)

(html-edit-def-entity "%table-attrs" 
	'(
	("BACKGROUND"	. "%URL")
	("BGCOLOR"	. "%color")
	("BORDERCOLOR"	. "%color")
	("COLS"	. NUMBER)
	))

(html-edit-def-attlist "TABLE"
	'(
	"%attrs"
	("align"	. "%Where")
	("width"	. "%Length")
	("height"	. "%Pixels")
	("border"	. "%border")
	("cellspacing"	. "%Pixels")
	("cellpadding"	. "%Pixels")
	("hspace"	. "%Pixels")
	("vspace"	. "%Pixels")
	"%table-attrs"
	))

(html-edit-def-element "CAPTION" t t '("%text") nil)
(html-edit-def-attlist "CAPTION"
	'(
	"%attrs"
	("align"	. ("top" "bottom"))
	))

(html-edit-def-entity "%tr-attrs" 
	'(
	("BGCOLOR"	. "%color")
	))

(html-edit-def-attlist "TR"
	'(
	"%cell.halign"
	"%cell.valign"
	"%tr-attrs"
	))

(html-edit-def-entity "%tdth-attrs" 
	'(
	("BACKGROUND"	. "%URL")
	("BGCOLOR"	. "%color")
	))

(html-edit-def-attlist '("TH" "TD")
	'(
	"%attrs"
	("nowrap"	. "nowrap")
	("rowspan"	. NUMBER)
	("colspan"	. NUMBER)
	"%cell.halign"
	"%cell.valign"
	("width"	. "%Length")
	("height"	. "%Length")
	"%tdth-attrs"
	))

;;
;; ================== Multi Columns ====================================
;;

(html-edit-def-element "MULTICOL" t t '("%text") nil)
(html-edit-def-attlist "MULTICOL"
	'(
	"%attrs"
	("COLS"	. NUMBER)
	("GUTTER"	. "%Pixels")
	("WIDTH"	. "%Pixels")
	))

;;
;; ================== Document Frames ====================================
;;

(html-edit-def-entity "%frame-size" 'CDATA)

(html-edit-def-entity "%frame-attrs" 
	'(
	("BORDERCOLOR"	. "%color")
	("FRAMEBORDER"	. ("NO" "YES"))
	))
(html-edit-def-entity "%frameset-attrs" 
	'(
	"%frame-attrs"
	("ONBLUR"	. "%Script")
	("ONFOCUS"	. "%Script")
	("BORDER"	. "%border")
	))

(html-edit-def-element "FRAMESET" t t '("FRAMESET" "FRAME" "NOFRAMES") nil)
(html-edit-def-attlist "FRAMESET"
	'(
	"%attrs"
	("rows"	. "%frame-size")
	("cols"	. "%frame-size")
	("onLoad"	. "%Script")
	("onUnload"	. "%Script")
	"%frameset-attrs"
	))

;;
;; reserved frame names start with "_" otherwise starts with letter
;;
(html-edit-def-element "FRAME" t nil 'EMPTY nil)
(html-edit-def-attlist "FRAME"
	'(
	"%attrs"
	("name"	. CDATA)
	("src"	. "%URL")
	("marginwidth"	. "%Pixels")
	("marginheight"	. "%Pixels")
	("noresize"	. "noresize")
	("scrolling"	. ("yes" "no" "auto"))
	"%frame-attrs"
	))

(html-edit-def-element "NOFRAMES" t t '("BODY" "%body.content") '("NOFRAMES"))
(html-edit-def-attlist "NOFRAMES"
	'(
	))

;;
;; ================== Style Sheet ====================================
;;

(html-edit-def-element "STYLE" t t '("CDATA") nil)
(html-edit-def-attlist "STYLE"
	'(
	("TYPE"	. "%Content-Type")
	))

(html-edit-def-element '("LAYER" "ILAYER") t t '("%body.content") '("LAYER" "ILAYER" "NOLAYER"))
(html-edit-def-attlist '("LAYER" "ILAYER")
	'(
	"%attrs"
	("LEFT"	. "%point")
	("TOP"	. "%point")
	("PAGEX"	. "%Pixels")
	("PAGEY"	. "%Pixels")
	("SRC"	. "%URL")
	("NAME"	. CDATA)
	("Z-INDEX"	. NUMBER)
	("ABOVE"	. ID)
	("BELOW"	. ID)
	("WIDTH"	. "%Length")
	("HEIGHT"	. "%Length")
	("CLIP"	. "%COORDS")
	("VISIBILITY"	. ("SHOW" "HIDE" "INHERIT"))
	("BGCOLOR"	. "%color")
	("BACKGROUND"	. "%URL")
	("OnMouseOver"	. "%Script")
	("OnMouseOut"	. "%Script")
	("OnFocus"	. "%Script")
	("OnBlur"	. "%Script")
	("OnLoad"	. "%Script")
	))

(html-edit-def-element "NOLAYER" t t '("%body.content") '("LAYER" "ILAYER" "NOLAYER"))
(html-edit-def-attlist "NOLAYER"
	'(
	))

(html-edit-def-element "SPAN" t t '("%text") nil)
(html-edit-def-attlist "SPAN"
	'(
	"%attrs"
	("STYLE"	. "%StyleSheet")
	))

;;
;; ================== The LINK Element ==================================
;;

(html-edit-def-entity "%Types" 'CDATA)

(html-edit-def-element "LINK" t nil 'EMPTY nil)
(html-edit-def-attlist "LINK"
	'(
	("src"	. "%URL")
	("href"	. "%URL")
	("type"	. CDATA)
	("rel"	. "%Types")
	("rev"	. "%Types")
	))

;;
;; ================ Document Head ========================================
;;

;;
;; %head.misc defined earlier on as "SCRIPT|SERVER|NOSCRIPT|STYLE|META|LINK"
;;

(html-edit-def-entity "%head.content" '("TITLE" "ISINDEX" "BASE" "STYLE"))

(html-edit-def-element "HEAD" nil nil '("%head.content" "%head.misc") nil)
(html-edit-def-attlist "HEAD"
	'(
	))

(html-edit-def-element "TITLE" t t '("PCDATA") '("%head.misc"))
(html-edit-def-attlist "TITLE"
	'(
	))

(html-edit-def-element "ISINDEX" t nil 'EMPTY nil)
(html-edit-def-attlist "ISINDEX"
	'(
	"%attrs"
	("action"	. "%URL")
	("prompt"	. CDATA)
	))

;;
;; The BASE element gives an absolute URL for dereferencing relative
;; URLs, e.g.
;; <BASE href="http://foo.com/index.html">
;; ...
;; <IMG SRC="images/bar.gif">
;; The image is deferenced to
;; http://foo.com/images/bar.gif
;; In the absence of a BASE element the document URL should be used.
;; Note that this is not necessarily the same as the URL used to
;; request the document, as the base URL may be overridden by an HTTP
;; header accompanying the document.
;;

(html-edit-def-element "BASE" t nil 'EMPTY nil)
(html-edit-def-attlist "BASE"
	'(
	("href"	. "%URL")
	("target"	. CDATA)
	))

(html-edit-def-element "META" t nil 'EMPTY nil)
(html-edit-def-attlist "META"
	'(
	("http-equiv"	. NAME)
	("name"	. NAME)
	("content"	. CDATA)
	))

(html-edit-def-entity "%script-attrs" 
	'(
	("LANGUAGE"	. CDATA)
	("SRC"	. "%URL")
	))

(html-edit-def-element "SCRIPT" t t '("CDATA") nil)
(html-edit-def-attlist "SCRIPT"
	'(
	"%coreattrs"
	"%script-attrs"
	))

(html-edit-def-element "SERVER" t t '("CDATA") nil)
(html-edit-def-attlist "SERVER"
	'(
	))

(html-edit-def-element "NOSCRIPT" t t '("%body.content") '("SCRIPT" "NOSCRIPT"))
(html-edit-def-attlist "NOSCRIPT"
	'(
	))

;;
;; ================ Document Structure ===================================
;;

(html-edit-def-entity "%HTML.Version" "http://developer.netscape.com/library/documentation/htmlguid/index.htm")

(html-edit-def-entity "%version.attr" 
	'(
	("VERSION"	. CDATA)
	))

(html-edit-def-entity "%html.body" '("BODY" "FRAMESET"))

(html-edit-def-entity "%html.content" '("HEAD" "%html.body" "PLAINTEXT"))

(html-edit-def-entity "%html.content" '("HEAD" "%html.body"))

(html-edit-def-element "HTML" nil nil '("%html.content") nil)
(html-edit-def-attlist "HTML"
	'(
	"%attrs"
	))
