;; html-edit-rule.el

;; This library is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2, or (at your option)
;; any later version.

;; This library is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with library; see the file COPYING.  If not, write to the
;; Free Software Foundation, Inc., 59 Temple Place - Suite 330,
;; Boston, MA 02111-1307, USA.

(require 'html-edit-utils)

(defvar html-edit-element-obarray nil)
(defvar html-edit-attlist-obarray nil)
(defvar html-edit-entity-obarray nil)
(defvar html-edit-action-handler-obarray nil)
(defvar html-edit-expand-entity-list nil)

(defvar html-edit-attr-name-map
  '(("onabort"			. "onAbort")
    ("onafterprint"		. "onAfterPrint")
    ("onafterupdate"		. "onAfterUpdate")
    ("onbeforecopy"		. "onBeforeCopy")
    ("onbeforecut"		. "onBeforeCut")
    ("onbeforeeditfocus"	. "onBeforeEditFocus")
    ("onbeforepaste"		. "onBeforePaste")
    ("onbeforeprint"		. "onBeforePrint")
    ("onbeforeunload"		. "onBeforeUnload")
    ("onbeforeupdate"		. "onBeforeUpdate")
    ("onblur"			. "onBlur")
    ("onbounce"			. "onBounce")
    ("oncellchange"		. "onCellChange")
    ("onchange"			. "onChange")
    ("onclick"			. "onClick")
    ("oncontextmenu"		. "onContextMenu")
    ("oncopy"			. "onCopy")
    ("oncut"			. "onCut")
    ("ondataavailable"		. "onDataAvailable")
    ("ondatasetchanged"		. "onDataSetChanged")
    ("ondatasetcomplete"	. "onDataSetComplete")
    ("ondblclick"		. "onDblClick")
    ("ondrag"			. "onDrag")
    ("ondragend"		. "onDragEnd")
    ("ondragenter"		. "onDragEnter")
    ("ondragleave"		. "onDragLeave")
    ("ondragover"		. "onDragOver")
    ("ondragstart"		. "onDragStart")
    ("ondrop"			. "onDrop")
    ("onerror"			. "onError")
    ("onerrorupdate"		. "onErrorUpdate")
    ("onfilterchange"		. "onFilterChange")
    ("onfinish"			. "onFinish")
    ("onfocus"			. "onFocus")
    ("onhelp"			. "onHelp")
    ("onkeydown"		. "onKeyDown")
    ("onkeypress"		. "onKeyPress")
    ("onkeyup"			. "onKeyUp")
    ("onload"			. "onLoad")
    ("onlosecapture"		. "onLoseCapture")
    ("onmousedown"		. "onMouseDown")
    ("onmousemove"		. "onMouseMove")
    ("onmouseout"		. "onMouseOut")
    ("onmouseover"		. "onMouseOver")
    ("onmouseup"		. "onMouseUp")
    ("onpaste"			. "onPaste")
    ("onpropertychange"		. "onPropertyChange")
    ("onreadystatechange"	. "onReadyStateChange")
    ("onreset"			. "onReset")
    ("onresize"			. "onResize")
    ("onrowenter"		. "onRowEnter")
    ("onrowexit"		. "onRowExit")
    ("onrowsdelete"		. "onRowsDelete")
    ("onrowsinserted"		. "onRowsInserted")
    ("onscroll"			. "onScroll")
    ("onselect"			. "onSelect")
    ("onselectstart"		. "onSelectStart")
    ("onstart"			. "onStart")
    ("onsubmit"			. "onSubmit")
    ("onunload"			. "onUnload")))
(defun html-edit-attr-name-map (name)
  (mapcar #'(lambda (pair)
	      (let ((new-name (assoc-ignore-case (car pair)
						 html-edit-attr-name-map)))
		(if new-name
		    (cons (cdr new-name) (cdr pair))
		  pair)))
	  name))

(defun html-edit-clear-entify ()
  ;; DTDơ֥
  ;; "%name" => atom, list, assoc
  (setq html-edit-entity-obarray (make-vector 127 0)))

(defun html-edit-initialize-element ()
  ;; ǥơ֥
  ;; "ELEMENT" => (beg-tag end-tag include-elem exclude-elem)
  (setq html-edit-element-obarray (make-vector 257 0))

  ;; °ơ֥
  ;; "ELEMENT/attr" => value
  ;; "ELEMENT" => ((name . value) (name . value) ...)
  (setq html-edit-attlist-obarray (make-vector 8191 0))

  (html-edit-clear-entify)
  )

(defun html-edit-get-element (element)
  (symbol-value (intern-soft element html-edit-element-obarray)))

(defun html-edit-get-attlist (element &optional attr)
  (symbol-value (intern-soft (if attr (concat element "/" attr) element)
			     html-edit-attlist-obarray)))

;;
;; property:
;; 'read-handler
;;	<name attr="..."> °ͤɤ߹िΥϥɥ顼
;;	(read-handler elem-name attr-name dtd-value &optional initial-value)
;;	ȤǸƤӽФ롣
;;
(defun html-edit-set-attlist-property (element attr property value)
  (let* ((entry	(concat (concat element "/" attr)))
	 (sym	(intern-soft entry html-edit-attlist-obarray)))
    (and sym
	 (put sym property value))))
			     
(defun html-edit-get-attlist-property (element attr property)
  (let* ((entry	(concat (concat element "/" attr)))
	 (sym	(intern-soft entry html-edit-attlist-obarray)))
    (and sym
	 (get sym property))))

(defun html-edit-expand-entity-atom (value)
  (if (and (stringp value)
	   (= (string-to-char value) ?%))
      (symbol-value (intern value html-edit-entity-obarray))
    value))

(defun html-edit-element-expand-list2 (value)
  (if (listp value)
      (mapc #'html-edit-element-expand-list2 value)
    (setq html-edit-expand-entity-list
	  (cons value html-edit-expand-entity-list))))

(defun html-edit-expand-entity-list1 (value)
  (if (atom value)
      (html-edit-expand-entity-atom value)
    (mapcar #'html-edit-expand-entity-list1 value)))

(defun html-edit-expand-entity-list (value)
  (if (atom value)
      (html-edit-expand-entity-atom value)
    (setq html-edit-expand-entity-list nil)
    (html-edit-element-expand-list2
     (html-edit-expand-entity-list1 value))
    (nreverse html-edit-expand-entity-list)))

(defun html-edit-expand-entity (value)
  (setq value
	(if (atom value)
	    (html-edit-expand-entity-atom value)
	  (apply
	   #'append
	   (mapcar
	    #'(lambda (x)
		(cond ((atom x)
		       (setq x (html-edit-expand-entity-atom x))
		       (if (listp x) x (list x)))
		      ((listp x)
		       (list
			(cons (car x) (html-edit-expand-entity-list
				       (cdr x)))))
		      (t x)))
	    value))))
  value)

(defun html-edit-def-entity (name value)
  (or (intern-soft name html-edit-entity-obarray)
      (set (intern name html-edit-entity-obarray)
	   (html-edit-expand-entity value))))

(defun html-edit-def-element-add (name beg-tag end-tag
				       include-elem exclude-elem)
  (let ((old-value (html-edit-get-element name))
	beg end inc exc)
    (if (null old-value)
	(set (intern name html-edit-element-obarray)
	     (list beg-tag end-tag include-elem exclude-elem))
      (setq beg (and (nth 0 old-value) beg-tag))
      (setq end (and (nth 1 old-value) end-tag))
      (setq inc (nth 2 old-value))
      (setq exc (html-edit-intersection (nth 3 old-value) exclude-elem))

      (if (or (eq include-elem 'EMPTY) (eq inc 'EMPTY))
	  (progn
	    (setq end nil)
	    (setq inc (if (eq include-elem 'EMPTY)
			  inc
			include-elem)))
	(setq inc (html-edit-union (nth 2 old-value) include-elem)))

      (set (intern name html-edit-element-obarray)
	   (list beg end inc exc)))))

(defun html-edit-def-element (name beg-tag end-tag include-elem exclude-elem)
  (setq name (html-edit-expand-entity name))
  (unless (listp name)
    (setq name (list name)))
  (setq include-elem (html-edit-expand-entity include-elem)
	exclude-elem (html-edit-expand-entity exclude-elem))

  ;; ʸ
  (unless include-elem 'EMPTY
	  (setq include-elem (mapcar #'(lambda (elem) (if (stringp elem)
							  (upcase elem)
							elem)) include-elem)))
  (setq exclude-elem (mapcar #'(lambda (elem) (if (stringp elem)
						  (upcase elem)
						elem)) exclude-elem))

  ;; 󥿥ååѤΥǡϿ
  (mapc #'(lambda (elem)
	    (html-edit-def-element-add (upcase elem)
				       beg-tag end-tag
				       include-elem exclude-elem))
	name)
  name)

(defun html-edit-attlist-merge-value (v1 v2)
  (cond ((equal v1 v2) v1)
	((and (listp v1) (listp v2)) (html-edit-union v1 v2))
	(t 'CDATA)))

(defun html-edit-attlist-merge-assoc (attlist1 attlist2)
  (let ((attlist (nreverse (copy-alist attlist1)))
	data)
    (mapcar #'(lambda (pair)
		(setq data (assoc (car pair) attlist))
		(if (null data)
		    (setq attlist (cons pair attlist))
		  (setcdr data (html-edit-attlist-merge-value
				(cdr data) (cdr pair)))))
	    attlist2)
    (nreverse attlist)))

(defun html-edit-def-attlist-add (name attributes)
  (let ((old-attr (html-edit-get-attlist name)))
    (when old-attr
      (setq attributes (html-edit-attlist-merge-assoc old-attr attributes)))

    (set (intern name html-edit-attlist-obarray) attributes)
    (mapc #'(lambda (pair)
	      (set (intern (concat name "/" (car pair))
			   html-edit-attlist-obarray)
		   (cdr pair)))
	  attributes)))

(defun html-edit-def-attlist (name attributes)
  (setq name (html-edit-expand-entity name))
  (unless (listp name)
    (setq name (list name)))
  (setq attributes
	(mapcar #'(lambda (pair)
		    (cons (downcase (car pair))
			  (let ((v (cdr pair)))
			    (if (listp v)
				(mapcar #'downcase v)
			      v))))
		(html-edit-expand-entity attributes)))

  (mapc #'(lambda (elem)
	    (html-edit-def-attlist-add (upcase elem) attributes))
	name)
  name)

(provide 'html-edit-rule)
