;; html-edit-sexp.el

;; This library is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2, or (at your option)
;; any later version.

;; This library is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with library; see the file COPYING.  If not, write to the
;; Free Software Foundation, Inc., 59 Temple Place - Suite 330,
;; Boston, MA 02111-1307, USA.

(require 'html-edit-vars)
(require 'html-edit-utils)
(require 'html-edit-rule)

;; б륿ؤΰưؿ
;; html-edit-forward-sexp		-- ˰ư
;; html-edit-backward-sexp		-- ˰ư
(defun html-edit-forward-sexp ()
  (interactive)
  (html-edit-safe-scan
   (if (html-edit-move-to-beginning-tag) ;; ϥإݥ󥿤ư
       (html-edit-forward-sexp-element)
     (forward-sexp))))

(defun html-edit-backward-sexp ()
  (interactive)
  (html-edit-safe-scan
   (if (html-edit-move-to-end-tag) ;; λإݥ󥿤ư
       (html-edit-backward-sexp-element)
     (backward-sexp))))

;; <name ...>  "<name" ʬ˥ݥȤˡ
;; "<" ľ˥ݥȤư롣"<name" ʬ˥ݥȤʤ nil
(defun html-edit-move-to-beginning-tag ()
  (let (pos)
    (save-excursion
      (cond ((looking-at "<[a-z]")
	     (setq pos (1+ (point))))
	    ((looking-at "[a-z]")
	     (skip-chars-backward "a-zA-Z0-9")
	     (when (equal (char-before) ?<)
	       (setq pos (point))))))
    (if pos
	(goto-char pos)
      nil)))

;; ƤӽФ
;; "<name " ޤ "</name"  "<" ľʬ˥ݥ󥿤ʤФʤʤ
;; ֤: (endtag elem endtag-require name pos)
(defun html-edit-sexp-read-tag ()
  (let (endtag elem endtag-require name pos)
    (setq pos (point))

    (when (= (char-after) ?/)
      (setq endtag t))

    (looking-at "/?\\([a-z0-9]+\\)")
    (setq name (upcase (match-string-no-properties 1)))
    (setq elem (html-edit-get-element name))
    (when (null elem)
      (error "Unknown element name \"%s\"" name))

    (unless endtag
      (setq endtag-require (or (nth 1 elem)
			       (member name
				       html-edit-check-require-endtag))))

    (list endtag elem endtag-require name pos)))

(defun html-edit-check-omit-tag (paren child)
  (let* ((paren-elem (car paren))
	 (paren-inc  (nth 2 paren-elem))
	 (child-name (nth 2 child)))
    (if (nth 1 paren-elem)
	nil
      (not (member child-name paren-inc)))))

(defvar html-edit-forward-element-endtag-omit nil)
(defun html-edit-forward-sexp-element ()
  (let (tag
	;; ǥå (ϥ)
	;; ((elem endtag-require name pos) ... )
	stack
	endtag
	match
	pos
	stop
	)

    (setq html-edit-forward-element-endtag-omit nil)

    ;; ǽΥɤߤȤ롣
    (setq tag (cdr (html-edit-sexp-read-tag)))

    (unless (eq (nth 2 (car tag)) 'EMPTY)
      (setq stack (list tag)))

    (while stack
      ;; إ
      (if (null (html-edit-search-forward-tag nil t))
	  (progn
	    (mapc #'(lambda (tag)
		      (when (nth 1 tag)
			(goto-char (nth 3 tag))
			(error "end tag of \"%s\" is not found" (nth 2 tag))))
		  stack)
	    (when stack
	      (setq html-edit-forward-element-endtag-omit t))
	    (setq stack nil)
	    (setq endtag nil))

	;; ɤߤ
	(setq tag (html-edit-sexp-read-tag))
	(setq endtag (car tag))
	(setq tag (cdr tag))

	(if endtag ;; λ
	    (progn
	      (setq match nil)
	      ;; б볫ϥޤǥݥå
	      (while (and stack
			  (cond ((eq (car (car stack)) (car tag))
				 (setq match t)
				 (setq stack (cdr stack))
				 nil)
				((nth 1 (car stack))
				 nil)
				(t
				 ;(setq pos (nth 3 (car stack)))
				 (setq stack (cdr stack))
				 t))))

	      (unless match
		;; 顼
		(when stack	;; б볫ϥ¸ߤʤ
		  (setq tag (car stack))
		  (setq pos (point))
		  (set-mark-command nil)
		  (goto-char (nth 3 tag))
		  (error "Unbalanced tag: \"%s\" (Unbalanced at position at %d, marked)"
			 (nth 2 tag)
			 pos))

		(setq stop t)
		(backward-char 2)
		))

	  ;; ϥ
	  (unless (eq (nth 2 (car tag)) 'EMPTY)
	    (if (and stack
		     (html-edit-check-omit-tag (car stack) tag))
		(progn
		  (setq stack (cdr stack))
		  (html-edit-search-backward-tag)
		  (when (null stack)
		    (setq html-edit-forward-element-endtag-omit t)))
	      (setq stack (cons tag stack)))
	    )
	  )))

    (unless (or stop html-edit-forward-element-endtag-omit)
      (if endtag
	  (progn
	    (forward-char); skip "/"
	    (skip-chars-forward "a-zA-Z0-9 \r\n\t")
	    (if (/= (char-after) ?>)
		(error "End tag syntax error"))
	    (forward-char))
	(let ((loop t)
	      (found nil))
	  (while loop
	    (re-search-forward "[<>]")
	    (cond ((= (char-before) ?>)
		   (setq loop nil))
		  ((= (char-after) ?%)
		   (search-forward "%>"))
		  ((= (char-after) ??)
		   (search-forward "?>"))
		  ((= (char-after) ?!)
		   (search-forward "-->"))
		  (t
		   (error "Tag syntax error")))))))))

;; </name>  "</name" ʬ˥ݥȤˡ
;; "<" ľ˥ݥȤư롣"</name" ʬ˥ݥȤʤ nil
(defun html-edit-move-to-end-tag ()
  (let (pos)
    (save-excursion
      (cond ((looking-at "</[a-z]")
	     (setq pos (1+ (point))))
	    ((and (looking-at "/[a-z]")
		  (equal (char-before) ?<))
	     (setq pos (point)))
	    (t
	     (when (equal (char-before) ?>)
	       (backward-char))
	     (skip-chars-backward " \r\n\t")
	     (skip-chars-backward "a-zA-Z0-9")
	     (when (and (string= (html-edit-string-before 2) "</")
			(looking-at "[a-z]"))
	       (setq pos (1- (point)))))
	    ))
    (if pos
	(goto-char pos)
      nil)))

(defun html-edit-backward-sexp-element ()
  (let (tag
	;; ǥå (λ)
	;; ((elem endtag-require name pos) ... )
	stack
	top
	endtag
	)

    ;; ǽΥɤߤȤ롣
    (setq tag (cdr (html-edit-sexp-read-tag)))
    (backward-char)
    (setq stack (list tag))

    (while stack
;;      (message "## (%d) top %s" (length stack) (car stack)) (sit-for 3)
      ;; إ
      (when (null 
	     (html-edit-search-backward-tag nil t)
	     )
	(setq tag (car stack))
	(goto-char (nth 3 tag))
	(error "end tag of \"%s\" is not found" (nth 2 tag)))

      ;; ɤߤ
      (forward-char)
      (setq tag (html-edit-sexp-read-tag))
      (backward-char)
      (setq endtag (car tag))
      (setq tag (cdr tag))

      (if endtag ;; λ
	  (setq stack (cons tag stack))

	;; ϥ
	(setq top (car stack))
	(cond ((eq (car top) (car tag))
	       (setq stack (cdr stack)))
	      ((null (nth 1 tag)) t)
	      (t
	       (error "Unbalanced tag: \"%s\"" (nth 2 tag)))))
      )))

;;
;; <name foo bar>xxx</name>
;; ((elem-beg . elem-end)
;;  (attr-beg . attr-end)
;;  (content-beg . content-end))
(defun html-edit-element-positions ()
  (let (elem-beg
	elem-end
	attr-beg
	attr-end
	content-beg
	content-end)

    ;; Ǥγ˥
    (if (looking-at "</[a-z]")
	(html-edit-backward-sexp)
      (when (not (looking-at "<[a-z]"))
	(html-edit-search-backward-tag)
	(if (looking-at "</[a-z]")
	    (html-edit-backward-sexp))))

    ;; ǤγϤޡ
    (setq elem-beg (point))
    (forward-char)
    (looking-at "[a-z0-9]+")

    ;; °Ϥޡ
    (setq attr-beg (match-end 0))

    ;; °λ򸡺
    (if (= (char-after) ?>)
	(forward-char)
      (html-edit-search-forward-tag-stop)
      (setq attr-end (1- (point))))

    ;; ǤΥƥΰ򸡺
    (setq content-beg (point))
    (goto-char elem-beg)
    (html-edit-forward-sexp)
    (setq elem-end (point)) ; Ǥνλޡ

    (if html-edit-forward-element-endtag-omit
	  (setq content-end (point))
      (html-edit-search-backward-tag)
      ;; λ򸫤Ĥ˸¤ꡢƥΰޡ
      (if (/= (point) elem-beg)
	  (setq content-end (point))))

    ;; 
    (list
     (if (and elem-beg elem-end (< elem-beg elem-end))
	 (cons elem-beg elem-end)
       nil)

     (if (and attr-beg attr-end (< attr-beg attr-end))
	 (cons attr-beg attr-end)
       nil)

     (if (and content-beg content-end (< content-beg content-end))
	 (cons content-beg content-end)
       nil))))

(provide 'html-edit-sexp)
