;; html-edit-utils.el

;; This library is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2, or (at your option)
;; any later version.

;; This library is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with library; see the file COPYING.  If not, write to the
;; Free Software Foundation, Inc., 59 Temple Place - Suite 330,
;; Boston, MA 02111-1307, USA.


(defun html-edit-union (list1 list2)
  (cond ((null list1) list2)
	((null list2) list1)
	((equal list1 list2) list1)
	(t
	 (let ((new-elems))
	   (mapc #'(lambda (elem)
		     (unless (member elem list1)
		       (setq new-elems (cons elem new-elems))))
		 list2)
	   (append list1 (nreverse new-elems))))))

(defun html-edit-intersection (list1 list2)
  (and list1 list2
       (if (equal list1 list2)
	   list1
	 (let ((new-elems))
	   (mapc #'(lambda (elem)
		     (when (member elem list1)
		       (setq new-elems (cons elem new-elems))))
		 list2)
	   (nreverse new-elems)))))

;; uniq
(defun html-edit-list-to-set (list)
  (let (new-elems)
    (mapc #'(lambda (elem)
	      (unless (member elem new-elems)
		(setq new-elems (cons elem new-elems))))
	  list)
    (nreverse new-elems)))

(defun html-edit-completing-read (prompt collection
					 &optional require-match initial)
  (let (value)
    (if require-match
	(while (equal ""
		      (setq value
			    (completing-read prompt
					     collection nil t initial))))
      (setq value (completing-read prompt
				   collection nil nil initial)))
    value))

;;
;; ֤ΥݥȤΰưؿ
;; html-edit-search-forward-tag		-- ˸
;; html-edit-search-backward-tag	-- ˸
;; html-edit-search-inside-start	-- γʬ "<" ذư
;;
(defun html-edit-search-forward-tag (&optional limit noerror)
  (let ((save-point (point))
	found)
    (while (and (search-forward "<" limit t)
		(cond ((= (char-after) ?%)
		       (search-forward "%>" limit t)
		       t)
		      ((= (char-after) ??)
		       (search-forward "?>" limit t)
		       t)
		      ((= (char-after) ?!)
		       (if (looking-at "!--")
			   (search-forward "-->" limit t)
			 (search-forward ">" limit t))
		       t)
		      ((looking-at "/?[a-z]")
		       (setq found (point))
		       nil))))
    (if found
	(goto-char found)
      (if noerror
	  ;;nil
	  (progn (goto-char (point-max))
		 nil)
	(goto-char save-point)
	(error "Tag search failed")))))

(defun html-edit-search-backward-tag (&optional limit noerror)
  (let ((save-point (point))
	(loop t)
	found)
    (while (and loop
		(re-search-backward "[<>]" limit t))
      (if (= (char-after) ?>)
	  (cond ((= (char-before) ?%)
		 (search-backward "<%" limit t))
		((= (char-before) ??)
		 (search-backward "<?" limit t))
		((string= (html-edit-string-before 2) "--")
		 (search-backward "<!--" limit t))
		(t
		 (search-backward "<" limit t))))
      (when (looking-at "</?[a-z]")
	(setq found (point))
	(setq loop nil)))
    (if found
	(goto-char found)
      (if noerror
	  (progn (goto-char (point-min))
		 nil)
	(goto-char save-point)
	(error "Tag search failed")))))

(defun html-edit-search-inside-start (&optional limit noerror)
  (let ((loop t)
	found)
    (save-excursion
      (while (and loop
		  (re-search-backward "[<>]" limit t))
	(if (= (char-after) ?>)
	    (cond ((= (char-before) ?%)
		   (search-backward "<%" limit t))
		  ((= (char-before) ??)
		   (search-backward "<?" limit t))
		  ((string= (html-edit-string-before 2) "--")
		   (search-backward "<!--" limit t))
		  (t
		   (setq loop nil))))
	(when (and loop (looking-at "</?[a-z]")
		   (setq found (1+ (point)))
		   (setq loop nil)))))
    (if found
	(goto-char found)
      (if noerror
	  nil
	(error "Tag search failed")))))

;; νޤǥݥ󥿤ưΥݥȤ֤
;; ȥݥȤϡ ("<" .. ">") ˤʤФʤʤ
(defun html-edit-search-forward-tag-stop ()
  (while (and (re-search-forward "[<>]")
	      (cond ((= (char-before) ?>)
		     nil)
		    ((= (char-after) ?%)
		     (search-forward "%>")
		     t)
		    ((= (char-after) ??)
		     (search-forward "?>")
		     t)
		    ((looking-at "!--")
		     (search-forward "-->")
		     t)
		    (t (backward-char)
		       (error "\"<\" shuld not apear here, or use &lt;")))))
  (point))

;;
;; ˥ȥݥ󥿤뤫ɤå롣
;; ʤ nil,   "<" ֤Υݥ󥿤֤
(defun html-edit-check-in-the-tag (&optional limit)
  (let ((loop t)
	pos)
    (save-excursion
      (while loop
	(if (null (re-search-backward "[<>]" limit t))
	    (setq loop nil)
	  (cond ((looking-at "</?[[:alpha:]]")
		 ;; found
		 (setq pos (point))
		 (setq loop nil))
		((= (char-after) ?<)
		 (setq loop nil))
		((equal (char-before) ?%)
		 (unless (search-backward "<%" limit t)
		   (setq loop nil)))
		((equal (char-before) ??)
		 (unless (search-backward "<?" limit t)
		   (setq loop nil)))
		((string= (html-edit-string-before 2) "--")
		 (unless (search-backward "<!--" limit t)
		   (setq loop nil)))
		(t
		 (setq loop nil))))))
    pos))

(defun html-edit-delete-overlay-region (start end)
  (interactive "r")
  (mapc #'(lambda (overlay) (delete-overlay overlay))
	(overlays-in start end)))

;(defvar html-edit-display-begin-depth 0)
;(defvar html-edit-display-save-category nil)
;(defun html-edit-display-begin-edit ()
;  (setq html-edit-display-begin-depth (1+ html-edit-display-begin-depth))
;  (when (= html-edit-display-begin-depth 1)
;    (setq html-edit-display-save-category
;	  (mapcar #'(lambda (sym) (cons sym (symbol-plist sym)))
;		  '(html-edit-invisible html-edit-intangible)))
;    (setplist 'html-edit-invisible
;	      '(invisible t
;		rear-nonsticky t))
;    (setplist 'html-edit-intangible
;	      '(rear-nonsticky t))
;    ))
;(defun html-edit-display-end-edit ()
;  (setq html-edit-display-begin-depth (1- html-edit-display-begin-depth))
;  (when (= html-edit-display-begin-depth 0)
;    (mapcar #'(lambda (sym) (setplist (car sym) (cdr sym)))
;	    html-edit-display-save-category)))

(defmacro html-edit-safe-scan (&rest body)
  `(let ((inhibit-point-motion-hooks t)
	 (inhibit-read-only t))
     ,@body))
;  `(unwind-protect
;      (progn
;	(html-edit-display-begin-edit)
;	,@body
;	)
;     (html-edit-display-end-edit)))

(defun html-edit-string-before (len)
  "ȥݥȤ LEN ݥޤǤʸɤ߼"
  (let ((beg (- (point) len)))
    (when (< beg (point-min))
      (setq beg (point-min)))
    (buffer-substring-no-properties beg (point))))

(defun html-edit-read-chars-backward (character-set &optional limit)
  "ʸɤ߹"
  (let ((offset (skip-chars-backward character-set limit)))
    (if (< offset 0)
	(buffer-substring-no-properties (point) (- (point) offset))
      nil)))

(provide 'html-edit-utils)
